Class: Aws::AppConfig::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::AppConfig::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-appconfig/client.rb,
sig/client.rbs
Overview
An API client for AppConfig. To construct a client, you need to configure a :region and :credentials.
client = Aws::AppConfig::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _CreateApplicationResponseSuccess, _CreateConfigurationProfileResponseSuccess, _CreateDeploymentStrategyResponseSuccess, _CreateEnvironmentResponseSuccess, _CreateExperimentDefinitionResponseSuccess, _CreateExtensionAssociationResponseSuccess, _CreateExtensionResponseSuccess, _CreateHostedConfigurationVersionResponseSuccess, _GetAccountSettingsResponseSuccess, _GetApplicationResponseSuccess, _GetConfigurationProfileResponseSuccess, _GetConfigurationResponseSuccess, _GetDeploymentResponseSuccess, _GetDeploymentStrategyResponseSuccess, _GetEnvironmentResponseSuccess, _GetExperimentDefinitionResponseSuccess, _GetExperimentRunResponseSuccess, _GetExtensionAssociationResponseSuccess, _GetExtensionResponseSuccess, _GetHostedConfigurationVersionResponseSuccess, _ListApplicationsResponseSuccess, _ListConfigurationProfilesResponseSuccess, _ListDeploymentStrategiesResponseSuccess, _ListDeploymentsResponseSuccess, _ListEnvironmentsResponseSuccess, _ListExperimentDefinitionsResponseSuccess, _ListExperimentRunEventsResponseSuccess, _ListExperimentRunsResponseSuccess, _ListExtensionAssociationsResponseSuccess, _ListExtensionsResponseSuccess, _ListHostedConfigurationVersionsResponseSuccess, _ListTagsForResourceResponseSuccess, _StartDeploymentResponseSuccess, _StartExperimentRunResponseSuccess, _StopDeploymentResponseSuccess, _StopExperimentRunResponseSuccess, _UpdateAccountSettingsResponseSuccess, _UpdateApplicationResponseSuccess, _UpdateConfigurationProfileResponseSuccess, _UpdateDeploymentStrategyResponseSuccess, _UpdateEnvironmentResponseSuccess, _UpdateExperimentDefinitionResponseSuccess, _UpdateExperimentRunResponseSuccess, _UpdateExtensionAssociationResponseSuccess, _UpdateExtensionResponseSuccess
Constant Summary collapse
- Params =
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#create_application(params = {}) ⇒ Types::Application
Creates an application.
-
#create_configuration_profile(params = {}) ⇒ Types::ConfigurationProfile
Creates a configuration profile, which is information that enables AppConfig to access the configuration source.
-
#create_deployment_strategy(params = {}) ⇒ Types::DeploymentStrategy
Creates a deployment strategy that defines important criteria for rolling out your configuration to the designated targets.
-
#create_environment(params = {}) ⇒ Types::Environment
Creates an environment.
-
#create_experiment_definition(params = {}) ⇒ Types::ExperimentDefinition
Creates an experiment definition in AppConfig.
-
#create_extension(params = {}) ⇒ Types::Extension
Creates an AppConfig extension.
-
#create_extension_association(params = {}) ⇒ Types::ExtensionAssociation
When you create an extension or configure an Amazon Web Services authored extension, you associate the extension with an AppConfig application, environment, or configuration profile.
-
#create_hosted_configuration_version(params = {}) ⇒ Types::HostedConfigurationVersion
Creates a new configuration in the AppConfig hosted configuration store.
-
#delete_application(params = {}) ⇒ Struct
Deletes an application.
-
#delete_configuration_profile(params = {}) ⇒ Struct
Deletes a configuration profile.
-
#delete_deployment_strategy(params = {}) ⇒ Struct
Deletes a deployment strategy.
-
#delete_environment(params = {}) ⇒ Struct
Deletes an environment.
-
#delete_experiment_definition(params = {}) ⇒ Struct
Deletes an experiment definition.
-
#delete_extension(params = {}) ⇒ Struct
Deletes an AppConfig extension.
-
#delete_extension_association(params = {}) ⇒ Struct
Deletes an extension association.
-
#delete_hosted_configuration_version(params = {}) ⇒ Struct
Deletes a version of a configuration from the AppConfig hosted configuration store.
-
#get_account_settings(params = {}) ⇒ Types::AccountSettings
Returns information about the status of the
DeletionProtectionparameter. -
#get_application(params = {}) ⇒ Types::Application
Retrieves information about an application.
-
#get_configuration(params = {}) ⇒ Types::Configuration
(Deprecated) Retrieves the latest deployed configuration.
-
#get_configuration_profile(params = {}) ⇒ Types::ConfigurationProfile
Retrieves information about a configuration profile.
-
#get_deployment(params = {}) ⇒ Types::Deployment
Retrieves information about a configuration deployment.
-
#get_deployment_strategy(params = {}) ⇒ Types::DeploymentStrategy
Retrieves information about a deployment strategy.
-
#get_environment(params = {}) ⇒ Types::Environment
Retrieves information about an environment.
-
#get_experiment_definition(params = {}) ⇒ Types::ExperimentDefinition
Retrieves information about an experiment definition.
-
#get_experiment_run(params = {}) ⇒ Types::ExperimentRun
Retrieves information about an experiment run, including its status, start time, and exposure settings.
-
#get_extension(params = {}) ⇒ Types::Extension
Returns information about an AppConfig extension.
-
#get_extension_association(params = {}) ⇒ Types::ExtensionAssociation
Returns information about an AppConfig extension association.
-
#get_hosted_configuration_version(params = {}) ⇒ Types::HostedConfigurationVersion
Retrieves information about a specific configuration version.
-
#list_applications(params = {}) ⇒ Types::Applications
Lists all applications in your Amazon Web Services account.
-
#list_configuration_profiles(params = {}) ⇒ Types::ConfigurationProfiles
Lists the configuration profiles for an application.
-
#list_deployment_strategies(params = {}) ⇒ Types::DeploymentStrategies
Lists deployment strategies.
-
#list_deployments(params = {}) ⇒ Types::Deployments
Lists the deployments for an environment in descending deployment number order.
-
#list_environments(params = {}) ⇒ Types::Environments
Lists the environments for an application.
-
#list_experiment_definitions(params = {}) ⇒ Types::ExperimentDefinitions
Lists the experiment definitions for an account.
-
#list_experiment_run_events(params = {}) ⇒ Types::ExperimentRunEvents
Lists the events for a specified experiment run.
-
#list_experiment_runs(params = {}) ⇒ Types::ExperimentRuns
Lists the experiment runs for a specified experiment definition.
-
#list_extension_associations(params = {}) ⇒ Types::ExtensionAssociations
Lists all AppConfig extension associations in the account.
-
#list_extensions(params = {}) ⇒ Types::Extensions
Lists all custom and Amazon Web Services authored AppConfig extensions in the account.
-
#list_hosted_configuration_versions(params = {}) ⇒ Types::HostedConfigurationVersions
Lists configurations stored in the AppConfig hosted configuration store by version.
-
#list_tags_for_resource(params = {}) ⇒ Types::ResourceTags
Retrieves the list of key-value tags assigned to the resource.
-
#start_deployment(params = {}) ⇒ Types::Deployment
Starts a deployment.
-
#start_experiment_run(params = {}) ⇒ Types::ExperimentRun
Starts an experiment run for the specified experiment definition.
-
#stop_deployment(params = {}) ⇒ Types::Deployment
Stops a deployment.
-
#stop_experiment_run(params = {}) ⇒ Types::ExperimentRun
Stops a running experiment.
-
#tag_resource(params = {}) ⇒ Struct
Assigns metadata to an AppConfig resource.
-
#untag_resource(params = {}) ⇒ Struct
Deletes a tag key and value from an AppConfig resource.
-
#update_account_settings(params = {}) ⇒ Types::AccountSettings
Updates the value of the
DeletionProtectionparameter. -
#update_application(params = {}) ⇒ Types::Application
Updates an application.
-
#update_configuration_profile(params = {}) ⇒ Types::ConfigurationProfile
Updates a configuration profile.
-
#update_deployment_strategy(params = {}) ⇒ Types::DeploymentStrategy
Updates a deployment strategy.
-
#update_environment(params = {}) ⇒ Types::Environment
Updates an environment.
-
#update_experiment_definition(params = {}) ⇒ Types::ExperimentDefinition
Updates an experiment definition.
-
#update_experiment_run(params = {}) ⇒ Types::ExperimentRun
Updates a running experiment.
-
#update_extension(params = {}) ⇒ Types::Extension
Updates an AppConfig extension.
-
#update_extension_association(params = {}) ⇒ Types::ExtensionAssociation
Updates an association.
-
#validate_configuration(params = {}) ⇒ Struct
Uses the validators in a configuration profile to validate a configuration.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
-
#wait_until(waiter_name, params = {}, options = {}) {|w.waiter| ... } ⇒ Boolean
Polls an API operation until a resource enters a desired state.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-appconfig/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
5511 5512 5513 |
# File 'lib/aws-sdk-appconfig/client.rb', line 5511 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
5514 5515 5516 |
# File 'lib/aws-sdk-appconfig/client.rb', line 5514 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
5369 5370 5371 5372 5373 5374 5375 5376 5377 5378 5379 5380 5381 5382 5383 5384 5385 |
# File 'lib/aws-sdk-appconfig/client.rb', line 5369 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::AppConfig') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-appconfig' context[:gem_version] = '1.87.0' Seahorse::Client::Request.new(handlers, context) end |
#create_application(params = {}) ⇒ Types::Application
Creates an application. In AppConfig, an application is simply an organizational construct like a folder. This organizational construct has a relationship with some unit of executable code. For example, you could create an application called MyMobileApp to organize and manage configuration data for a mobile application installed by your users.
88 |
# File 'sig/client.rbs', line 88
def create_application: (
|
#create_configuration_profile(params = {}) ⇒ Types::ConfigurationProfile
Creates a configuration profile, which is information that enables AppConfig to access the configuration source. Valid configuration sources include the following:
-
Configuration data in YAML, JSON, and other formats stored in the AppConfig hosted configuration store
-
Configuration data stored as objects in an Amazon Simple Storage Service (Amazon S3) bucket
-
Pipelines stored in CodePipeline
-
Secrets stored in Secrets Manager
-
Standard and secure string parameters stored in Amazon Web Services Systems Manager Parameter Store
-
Configuration data in SSM documents stored in the Systems Manager document store
A configuration profile includes the following information:
-
The URI location of the configuration data.
-
The Identity and Access Management (IAM) role that provides access to the configuration data.
-
A validator for the configuration data. Available validators include either a JSON Schema or an Amazon Web Services Lambda function.
For more information, see Create a Configuration and a Configuration Profile in the AppConfig User Guide.
109 |
# File 'sig/client.rbs', line 109
def create_configuration_profile: (
|
#create_deployment_strategy(params = {}) ⇒ Types::DeploymentStrategy
Creates a deployment strategy that defines important criteria for rolling out your configuration to the designated targets. A deployment strategy includes the overall duration required, a percentage of targets to receive the deployment during each interval, an algorithm that defines how percentage grows, and bake time.
139 |
# File 'sig/client.rbs', line 139
def create_deployment_strategy: (
|
#create_environment(params = {}) ⇒ Types::Environment
Creates an environment. For each application, you define one or more
environments. An environment is a deployment group of AppConfig
targets, such as applications in a Beta or Production environment.
You can also define environments for application subcomponents such as
the Web, Mobile and Back-end components for your application.
You can configure Amazon CloudWatch alarms for each environment. The
system monitors alarms during a configuration deployment. If an alarm
is triggered, the system rolls back the configuration.
161 |
# File 'sig/client.rbs', line 161
def create_environment: (
|
#create_experiment_definition(params = {}) ⇒ Types::ExperimentDefinition
Creates an experiment definition in AppConfig. An experiment definition describes the purpose, scope, and operational configuration of an experiment, including the target audience, feature flag, and treatment configurations.
195 |
# File 'sig/client.rbs', line 195
def create_experiment_definition: (
|
#create_extension(params = {}) ⇒ Types::Extension
Creates an AppConfig extension. An extension augments your ability to inject logic or behavior at different points during the AppConfig workflow of creating or deploying a configuration.
You can create your own extensions or use the Amazon Web Services
authored extensions provided by AppConfig. For an AppConfig extension
that uses Lambda, you must create a Lambda function to perform any
computation and processing defined in the extension. If you plan to
create custom versions of the Amazon Web Services authored
notification extensions, you only need to specify an Amazon Resource
Name (ARN) in the Uri field for the new extension version.
-
For a custom EventBridge notification extension, enter the ARN of the EventBridge default events in the
Urifield. -
For a custom Amazon SNS notification extension, enter the ARN of an Amazon SNS topic in the
Urifield. -
For a custom Amazon SQS notification extension, enter the ARN of an Amazon SQS message queue in the
Urifield.
For more information about extensions, see Extending workflows in the AppConfig User Guide.
224 |
# File 'sig/client.rbs', line 224
def create_extension: (
|
#create_extension_association(params = {}) ⇒ Types::ExtensionAssociation
When you create an extension or configure an Amazon Web Services
authored extension, you associate the extension with an AppConfig
application, environment, or configuration profile. For example, you
can choose to run the AppConfig deployment events to Amazon SNS
Amazon Web Services authored extension and receive notifications on an
Amazon SNS topic anytime a configuration deployment is started for a
specific application. Defining which extension to associate with an
AppConfig resource is called an extension association. An extension
association is a specified relationship between an extension and an
AppConfig resource, such as an application or a configuration profile.
For more information about extensions and associations, see Extending
workflows in the AppConfig User Guide.
255 |
# File 'sig/client.rbs', line 255
def create_extension_association: (
|
#create_hosted_configuration_version(params = {}) ⇒ Types::HostedConfigurationVersion
Creates a new configuration in the AppConfig hosted configuration store. If you're creating a feature flag, we recommend you familiarize yourself with the JSON schema for feature flag data. For more information, see Type reference for AWS.AppConfig.FeatureFlags in the AppConfig User Guide.
276 |
# File 'sig/client.rbs', line 276
def create_hosted_configuration_version: (
|
#delete_application(params = {}) ⇒ Struct
Deletes an application.
288 |
# File 'sig/client.rbs', line 288
def delete_application: (
|
#delete_configuration_profile(params = {}) ⇒ Struct
Deletes a configuration profile.
To prevent users from unintentionally deleting actively-used configuration profiles, enable deletion protection.
294 |
# File 'sig/client.rbs', line 294
def delete_configuration_profile: (
|
#delete_deployment_strategy(params = {}) ⇒ Struct
Deletes a deployment strategy.
302 |
# File 'sig/client.rbs', line 302
def delete_deployment_strategy: (
|
#delete_environment(params = {}) ⇒ Struct
Deletes an environment.
To prevent users from unintentionally deleting actively-used environments, enable deletion protection.
308 |
# File 'sig/client.rbs', line 308
def delete_environment: (
|
#delete_experiment_definition(params = {}) ⇒ Struct
Deletes an experiment definition. You can archive the definition to hide it from the active list while preserving it for future reference, or permanently delete it along with all associated run history.
316 |
# File 'sig/client.rbs', line 316
def delete_experiment_definition: (
|
#delete_extension(params = {}) ⇒ Struct
Deletes an AppConfig extension. You must delete all associations to an extension before you delete the extension.
324 |
# File 'sig/client.rbs', line 324
def delete_extension: (
|
#delete_extension_association(params = {}) ⇒ Struct
Deletes an extension association. This action doesn't delete extensions defined in the association.
331 |
# File 'sig/client.rbs', line 331
def delete_extension_association: (
|
#delete_hosted_configuration_version(params = {}) ⇒ Struct
Deletes a version of a configuration from the AppConfig hosted configuration store.
337 |
# File 'sig/client.rbs', line 337
def delete_hosted_configuration_version: (
|
#get_account_settings(params = {}) ⇒ Types::AccountSettings
Returns information about the status of the DeletionProtection
parameter.
350 351 |
# File 'sig/client.rbs', line 350
def get_account_settings: () -> _GetAccountSettingsResponseSuccess
| (?Hash[Symbol, untyped] params, ?Hash[Symbol, untyped] options) -> _GetAccountSettingsResponseSuccess
|
#get_application(params = {}) ⇒ Types::Application
Retrieves information about an application.
360 |
# File 'sig/client.rbs', line 360
def get_application: (
|
#get_configuration(params = {}) ⇒ Types::Configuration
(Deprecated) Retrieves the latest deployed configuration.
Note the following important information.
-
This API action is deprecated. Calls to receive configuration data should use the StartConfigurationSession and GetLatestConfiguration APIs instead.
-
GetConfiguration is a priced call. For more information, see Pricing.
372 |
# File 'sig/client.rbs', line 372
def get_configuration: (
|
#get_configuration_profile(params = {}) ⇒ Types::ConfigurationProfile
Retrieves information about a configuration profile.
395 |
# File 'sig/client.rbs', line 395
def get_configuration_profile: (
|
#get_deployment(params = {}) ⇒ Types::Deployment
Retrieves information about a configuration deployment.
The following waiters are defined for this operation (see #wait_until for detailed usage):
* deployment_complete
427 |
# File 'sig/client.rbs', line 427
def get_deployment: (
|
#get_deployment_strategy(params = {}) ⇒ Types::DeploymentStrategy
Retrieves information about a deployment strategy. A deployment strategy defines important criteria for rolling out your configuration to the designated targets. A deployment strategy includes the overall duration required, a percentage of targets to receive the deployment during each interval, an algorithm that defines how percentage grows, and bake time.
446 |
# File 'sig/client.rbs', line 446
def get_deployment_strategy: (
|
#get_environment(params = {}) ⇒ Types::Environment
Retrieves information about an environment. An environment is a
deployment group of AppConfig applications, such as applications in a
Production environment or in an EU_Region environment. Each
configuration deployment targets an environment. You can enable one or
more Amazon CloudWatch alarms for an environment. If an alarm is
triggered during a deployment, AppConfig roles back the configuration.
The following waiters are defined for this operation (see #wait_until for detailed usage):
* environment_ready_for_deployment
461 |
# File 'sig/client.rbs', line 461
def get_environment: (
|
#get_experiment_definition(params = {}) ⇒ Types::ExperimentDefinition
Retrieves information about an experiment definition.
487 |
# File 'sig/client.rbs', line 487
def get_experiment_definition: (
|
#get_experiment_run(params = {}) ⇒ Types::ExperimentRun
Retrieves information about an experiment run, including its status, start time, and exposure settings.
509 |
# File 'sig/client.rbs', line 509
def get_experiment_run: (
|
#get_extension(params = {}) ⇒ Types::Extension
Returns information about an AppConfig extension.
527 |
# File 'sig/client.rbs', line 527
def get_extension: (
|
#get_extension_association(params = {}) ⇒ Types::ExtensionAssociation
Returns information about an AppConfig extension association. For more information about extensions and associations, see Extending workflows in the AppConfig User Guide.
543 |
# File 'sig/client.rbs', line 543
def get_extension_association: (
|
#get_hosted_configuration_version(params = {}) ⇒ Types::HostedConfigurationVersion
Retrieves information about a specific configuration version.
560 |
# File 'sig/client.rbs', line 560
def get_hosted_configuration_version: (
|
#list_applications(params = {}) ⇒ Types::Applications
Lists all applications in your Amazon Web Services account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
573 |
# File 'sig/client.rbs', line 573
def list_applications: (
|
#list_configuration_profiles(params = {}) ⇒ Types::ConfigurationProfiles
Lists the configuration profiles for an application.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
585 |
# File 'sig/client.rbs', line 585
def list_configuration_profiles: (
|
#list_deployment_strategies(params = {}) ⇒ Types::DeploymentStrategies
Lists deployment strategies.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
599 |
# File 'sig/client.rbs', line 599
def list_deployment_strategies: (
|
#list_deployments(params = {}) ⇒ Types::Deployments
Lists the deployments for an environment in descending deployment number order.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
611 |
# File 'sig/client.rbs', line 611
def list_deployments: (
|
#list_environments(params = {}) ⇒ Types::Environments
Lists the environments for an application.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
625 |
# File 'sig/client.rbs', line 625
def list_environments: (
|
#list_experiment_definitions(params = {}) ⇒ Types::ExperimentDefinitions
Lists the experiment definitions for an account. You can filter results by application, configuration profile, environment, or status.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
638 |
# File 'sig/client.rbs', line 638
def list_experiment_definitions: (
|
#list_experiment_run_events(params = {}) ⇒ Types::ExperimentRunEvents
Lists the events for a specified experiment run. Events provide a timeline of actions and state changes that occurred during the run.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
654 |
# File 'sig/client.rbs', line 654
def list_experiment_run_events: (
|
#list_experiment_runs(params = {}) ⇒ Types::ExperimentRuns
Lists the experiment runs for a specified experiment definition. You can filter by status.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
669 |
# File 'sig/client.rbs', line 669
def list_experiment_runs: (
|
#list_extension_associations(params = {}) ⇒ Types::ExtensionAssociations
Lists all AppConfig extension associations in the account. For more information about extensions and associations, see Extending workflows in the AppConfig User Guide.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
684 |
# File 'sig/client.rbs', line 684
def list_extension_associations: (
|
#list_extensions(params = {}) ⇒ Types::Extensions
Lists all custom and Amazon Web Services authored AppConfig extensions in the account. For more information about extensions, see Extending workflows in the AppConfig User Guide.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
699 |
# File 'sig/client.rbs', line 699
def list_extensions: (
|
#list_hosted_configuration_versions(params = {}) ⇒ Types::HostedConfigurationVersions
Lists configurations stored in the AppConfig hosted configuration store by version.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
712 |
# File 'sig/client.rbs', line 712
def list_hosted_configuration_versions: (
|
#list_tags_for_resource(params = {}) ⇒ Types::ResourceTags
Retrieves the list of key-value tags assigned to the resource.
726 |
# File 'sig/client.rbs', line 726
def list_tags_for_resource: (
|
#start_deployment(params = {}) ⇒ Types::Deployment
Starts a deployment.
757 |
# File 'sig/client.rbs', line 757
def start_deployment: (
|
#start_experiment_run(params = {}) ⇒ Types::ExperimentRun
Starts an experiment run for the specified experiment definition. An experiment run delivers treatments to the target audience and collects metrics. You can start multiple experiment runs from the same experiment definition.
787 |
# File 'sig/client.rbs', line 787
def start_experiment_run: (
|
#stop_deployment(params = {}) ⇒ Types::Deployment
Stops a deployment. This API action works only on deployments that
have a status of DEPLOYING, unless an AllowRevert parameter is
supplied. If the AllowRevert parameter is supplied, the status of an
in-progress deployment will be ROLLED_BACK. The status of a
completed deployment will be REVERTED. AppConfig only allows a
revert within 72 hours of deployment completion.
829 |
# File 'sig/client.rbs', line 829
def stop_deployment: (
|
#stop_experiment_run(params = {}) ⇒ Types::ExperimentRun
Stops a running experiment. Stopping an experiment run ends audience exposure and returns users to the currently deployed feature flag configuration.
853 |
# File 'sig/client.rbs', line 853
def stop_experiment_run: (
|
#tag_resource(params = {}) ⇒ Struct
Assigns metadata to an AppConfig resource. Tags help organize and categorize your AppConfig resources. Each tag consists of a key and an optional value, both of which you define. You can specify a maximum of 50 tags for a resource.
870 |
# File 'sig/client.rbs', line 870
def tag_resource: (
|
#untag_resource(params = {}) ⇒ Struct
Deletes a tag key and value from an AppConfig resource.
877 |
# File 'sig/client.rbs', line 877
def untag_resource: (
|
#update_account_settings(params = {}) ⇒ Types::AccountSettings
Updates the value of the DeletionProtection parameter.
889 |
# File 'sig/client.rbs', line 889
def update_account_settings: (
|
#update_application(params = {}) ⇒ Types::Application
Updates an application.
907 |
# File 'sig/client.rbs', line 907
def update_application: (
|
#update_configuration_profile(params = {}) ⇒ Types::ConfigurationProfile
Updates a configuration profile.
928 |
# File 'sig/client.rbs', line 928
def update_configuration_profile: (
|
#update_deployment_strategy(params = {}) ⇒ Types::DeploymentStrategy
Updates a deployment strategy.
956 |
# File 'sig/client.rbs', line 956
def update_deployment_strategy: (
|
#update_environment(params = {}) ⇒ Types::Environment
Updates an environment.
976 |
# File 'sig/client.rbs', line 976
def update_environment: (
|
#update_experiment_definition(params = {}) ⇒ Types::ExperimentDefinition
Updates an experiment definition. You can update treatments, the control, audience rules, and other properties. You cannot update an experiment definition while an experiment run is active.
1010 |
# File 'sig/client.rbs', line 1010
def update_experiment_definition: (
|
#update_experiment_run(params = {}) ⇒ Types::ExperimentRun
Updates a running experiment. Use this operation to increase audience exposure, modify treatment assignment overrides, or update the description of an active experiment run. Audience exposure can only be increased, not decreased.
1040 |
# File 'sig/client.rbs', line 1040
def update_experiment_run: (
|
#update_extension(params = {}) ⇒ Types::Extension
Updates an AppConfig extension. For more information about extensions, see Extending workflows in the AppConfig User Guide.
1067 |
# File 'sig/client.rbs', line 1067
def update_extension: (
|
#update_extension_association(params = {}) ⇒ Types::ExtensionAssociation
Updates an association. For more information about extensions and associations, see Extending workflows in the AppConfig User Guide.
1097 |
# File 'sig/client.rbs', line 1097
def update_extension_association: (
|
#validate_configuration(params = {}) ⇒ Struct
Uses the validators in a configuration profile to validate a configuration.
1104 |
# File 'sig/client.rbs', line 1104
def validate_configuration: (
|
#wait_until(waiter_name, params = {}, options = {}) {|w.waiter| ... } ⇒ Boolean
Polls an API operation until a resource enters a desired state.
Basic Usage
A waiter will call an API operation until:
- It is successful
- It enters a terminal state
- It makes the maximum number of attempts
In between attempts, the waiter will sleep.
# polls in a loop, sleeping between attempts
client.wait_until(waiter_name, params)
Configuration
You can configure the maximum number of polling attempts, and the delay (in seconds) between each polling attempt. You can pass configuration as the final arguments hash.
# poll for ~25 seconds
client.wait_until(waiter_name, params, {
max_attempts: 5,
delay: 5,
})
Callbacks
You can be notified before each polling attempt and before each
delay. If you throw :success or :failure from these callbacks,
it will terminate the waiter.
started_at = Time.now
client.wait_until(waiter_name, params, {
# disable max attempts
max_attempts: nil,
# poll for 1 hour, instead of a number of attempts
before_wait: -> (attempts, response) do
throw :failure if Time.now - started_at > 3600
end
})
Handling Errors
When a waiter is unsuccessful, it will raise an error. All of the failure errors extend from Waiters::Errors::WaiterFailed.
begin
client.wait_until(...)
rescue Aws::Waiters::Errors::WaiterFailed
# resource did not enter the desired state in time
end
Valid Waiters
The following table lists the valid waiter names, the operations they call,
and the default :delay and :max_attempts values.
| waiter_name | params | :delay | :max_attempts |
|---|---|---|---|
| deployment_complete | #get_deployment | 30 | 999 |
| environment_ready_for_deployment | #get_environment | 30 | 999 |
1112 |
# File 'sig/client.rbs', line 1112
def wait_until: (:deployment_complete waiter_name,
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
5484 5485 5486 |
# File 'lib/aws-sdk-appconfig/client.rb', line 5484 def waiter_names waiters.keys end |