Module: Aws::AppConfig::Types
- Defined in:
- lib/aws-sdk-appconfig/types.rb
Defined Under Namespace
Classes: AccountSettings, Action, ActionInvocation, Application, Applications, AppliedExtension, AttributeValue, BadRequestDetails, BadRequestException, Configuration, ConfigurationProfile, ConfigurationProfileSummary, ConfigurationProfiles, ConflictException, CreateApplicationRequest, CreateConfigurationProfileRequest, CreateDeploymentStrategyRequest, CreateEnvironmentRequest, CreateExperimentDefinitionRequest, CreateExtensionAssociationRequest, CreateExtensionRequest, CreateHostedConfigurationVersionRequest, DeleteApplicationRequest, DeleteConfigurationProfileRequest, DeleteDeploymentStrategyRequest, DeleteEnvironmentRequest, DeleteExperimentDefinitionRequest, DeleteExtensionAssociationRequest, DeleteExtensionRequest, DeleteHostedConfigurationVersionRequest, DeletionProtectionSettings, Deployment, DeploymentEvent, DeploymentParameters, DeploymentStrategies, DeploymentStrategy, DeploymentSummary, Deployments, Environment, Environments, ExperimentDefinition, ExperimentDefinitionSnapshot, ExperimentDefinitionSummary, ExperimentDefinitions, ExperimentRun, ExperimentRunEvent, ExperimentRunEvents, ExperimentRunResult, ExperimentRunSummary, ExperimentRuns, Extension, ExtensionAssociation, ExtensionAssociationSummary, ExtensionAssociations, ExtensionSummary, Extensions, FlagValue, GetApplicationRequest, GetConfigurationProfileRequest, GetConfigurationRequest, GetDeploymentRequest, GetDeploymentStrategyRequest, GetEnvironmentRequest, GetExperimentDefinitionRequest, GetExperimentRunRequest, GetExtensionAssociationRequest, GetExtensionRequest, GetHostedConfigurationVersionRequest, HostedConfigurationVersion, HostedConfigurationVersionSummary, HostedConfigurationVersions, InternalServerException, InvalidConfigurationDetail, ListApplicationsRequest, ListConfigurationProfilesRequest, ListDeploymentStrategiesRequest, ListDeploymentsRequest, ListEnvironmentsRequest, ListExperimentDefinitionsRequest, ListExperimentRunEventsRequest, ListExperimentRunsRequest, ListExtensionAssociationsRequest, ListExtensionsRequest, ListHostedConfigurationVersionsRequest, ListTagsForResourceRequest, Monitor, Parameter, PayloadTooLargeException, ResourceNotFoundException, ResourceTags, ServiceQuotaExceededException, StartDeploymentRequest, StartExperimentRunRequest, StopDeploymentRequest, StopExperimentRunRequest, TagResourceRequest, Treatment, TreatmentInput, TreatmentOverrides, UntagResourceRequest, UpdateAccountSettingsRequest, UpdateApplicationRequest, UpdateConfigurationProfileRequest, UpdateDeploymentStrategyRequest, UpdateEnvironmentRequest, UpdateExperimentDefinitionRequest, UpdateExperimentRunRequest, UpdateExtensionAssociationRequest, UpdateExtensionRequest, ValidateConfigurationRequest, Validator, VendedMetricsSettings
Instance Attribute Summary collapse
-
#boolean_value ⇒ Boolean
A Boolean value for the attribute.
-
#inline ⇒ Hash<String,String>
A map of entity IDs to treatment keys.
-
#invalid_configuration ⇒ Array<Types::InvalidConfigurationDetail>
Detailed information about the bad request exception error when creating a hosted configuration version.
-
#number_array ⇒ Array<Float>
An array of numeric values for the attribute.
-
#number_value ⇒ Float
A numeric value for the attribute.
-
#string_array ⇒ Array<String>
An array of string values for the attribute.
-
#string_value ⇒ String
A string value for the attribute.
Instance Attribute Details
#boolean_value ⇒ Boolean
A Boolean value for the attribute.
244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 |
# File 'lib/aws-sdk-appconfig/types.rb', line 244 class AttributeValue < Struct.new( :string_value, :number_value, :boolean_value, :string_array, :number_array, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class StringValue < AttributeValue; end class NumberValue < AttributeValue; end class BooleanValue < AttributeValue; end class StringArray < AttributeValue; end class NumberArray < AttributeValue; end class Unknown < AttributeValue; end end |
#inline ⇒ Hash<String,String>
A map of entity IDs to treatment keys. Each entry assigns the specified entity to the specified treatment, bypassing random assignment.
3467 3468 3469 3470 3471 3472 3473 3474 3475 3476 |
# File 'lib/aws-sdk-appconfig/types.rb', line 3467 class TreatmentOverrides < Struct.new( :inline, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Inline < TreatmentOverrides; end class Unknown < TreatmentOverrides; end end |
#invalid_configuration ⇒ Array<Types::InvalidConfigurationDetail>
Detailed information about the bad request exception error when creating a hosted configuration version.
273 274 275 276 277 278 279 280 281 282 |
# File 'lib/aws-sdk-appconfig/types.rb', line 273 class BadRequestDetails < Struct.new( :invalid_configuration, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class InvalidConfiguration < BadRequestDetails; end class Unknown < BadRequestDetails; end end |
#number_array ⇒ Array<Float>
An array of numeric values for the attribute.
244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 |
# File 'lib/aws-sdk-appconfig/types.rb', line 244 class AttributeValue < Struct.new( :string_value, :number_value, :boolean_value, :string_array, :number_array, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class StringValue < AttributeValue; end class NumberValue < AttributeValue; end class BooleanValue < AttributeValue; end class StringArray < AttributeValue; end class NumberArray < AttributeValue; end class Unknown < AttributeValue; end end |
#number_value ⇒ Float
A numeric value for the attribute.
244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 |
# File 'lib/aws-sdk-appconfig/types.rb', line 244 class AttributeValue < Struct.new( :string_value, :number_value, :boolean_value, :string_array, :number_array, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class StringValue < AttributeValue; end class NumberValue < AttributeValue; end class BooleanValue < AttributeValue; end class StringArray < AttributeValue; end class NumberArray < AttributeValue; end class Unknown < AttributeValue; end end |
#string_array ⇒ Array<String>
An array of string values for the attribute.
244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 |
# File 'lib/aws-sdk-appconfig/types.rb', line 244 class AttributeValue < Struct.new( :string_value, :number_value, :boolean_value, :string_array, :number_array, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class StringValue < AttributeValue; end class NumberValue < AttributeValue; end class BooleanValue < AttributeValue; end class StringArray < AttributeValue; end class NumberArray < AttributeValue; end class Unknown < AttributeValue; end end |
#string_value ⇒ String
A string value for the attribute.
244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 |
# File 'lib/aws-sdk-appconfig/types.rb', line 244 class AttributeValue < Struct.new( :string_value, :number_value, :boolean_value, :string_array, :number_array, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class StringValue < AttributeValue; end class NumberValue < AttributeValue; end class BooleanValue < AttributeValue; end class StringArray < AttributeValue; end class NumberArray < AttributeValue; end class Unknown < AttributeValue; end end |