Class: Aws::AppConfig::Types::AccountSettings

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-appconfig/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#deletion_protectionTypes::DeletionProtectionSettings

A parameter to configure deletion protection. Deletion protection prevents a user from deleting a configuration profile or an environment if AppConfig has called either GetLatestConfiguration or for the configuration profile or from the environment during the specified interval. The default interval for ProtectionPeriodInMinutes is 60.



32
33
34
35
36
37
# File 'lib/aws-sdk-appconfig/types.rb', line 32

class AccountSettings < Struct.new(
  :deletion_protection,
  :vended_metrics)
  SENSITIVE = []
  include Aws::Structure
end

#vended_metricsTypes::VendedMetricsSettings

Configuration for vended metrics in the account.



32
33
34
35
36
37
# File 'lib/aws-sdk-appconfig/types.rb', line 32

class AccountSettings < Struct.new(
  :deletion_protection,
  :vended_metrics)
  SENSITIVE = []
  include Aws::Structure
end