Class: Aws::AppConfig::Types::ActionInvocation

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-appconfig/types.rb

Overview

An extension that was invoked as part of a deployment event.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#action_nameString

The name of the action.



128
129
130
131
132
133
134
135
136
137
138
# File 'lib/aws-sdk-appconfig/types.rb', line 128

class ActionInvocation < Struct.new(
  :extension_identifier,
  :action_name,
  :uri,
  :role_arn,
  :error_message,
  :error_code,
  :invocation_id)
  SENSITIVE = []
  include Aws::Structure
end

#error_codeString

The error code when an extension invocation fails.



128
129
130
131
132
133
134
135
136
137
138
# File 'lib/aws-sdk-appconfig/types.rb', line 128

class ActionInvocation < Struct.new(
  :extension_identifier,
  :action_name,
  :uri,
  :role_arn,
  :error_message,
  :error_code,
  :invocation_id)
  SENSITIVE = []
  include Aws::Structure
end

#error_messageString

The error message when an extension invocation fails.



128
129
130
131
132
133
134
135
136
137
138
# File 'lib/aws-sdk-appconfig/types.rb', line 128

class ActionInvocation < Struct.new(
  :extension_identifier,
  :action_name,
  :uri,
  :role_arn,
  :error_message,
  :error_code,
  :invocation_id)
  SENSITIVE = []
  include Aws::Structure
end

#extension_identifierString

The name, the ID, or the Amazon Resource Name (ARN) of the extension.



128
129
130
131
132
133
134
135
136
137
138
# File 'lib/aws-sdk-appconfig/types.rb', line 128

class ActionInvocation < Struct.new(
  :extension_identifier,
  :action_name,
  :uri,
  :role_arn,
  :error_message,
  :error_code,
  :invocation_id)
  SENSITIVE = []
  include Aws::Structure
end

#invocation_idString

A system-generated ID for this invocation.



128
129
130
131
132
133
134
135
136
137
138
# File 'lib/aws-sdk-appconfig/types.rb', line 128

class ActionInvocation < Struct.new(
  :extension_identifier,
  :action_name,
  :uri,
  :role_arn,
  :error_message,
  :error_code,
  :invocation_id)
  SENSITIVE = []
  include Aws::Structure
end

#role_arnString

An Amazon Resource Name (ARN) for an Identity and Access Management assume role.



128
129
130
131
132
133
134
135
136
137
138
# File 'lib/aws-sdk-appconfig/types.rb', line 128

class ActionInvocation < Struct.new(
  :extension_identifier,
  :action_name,
  :uri,
  :role_arn,
  :error_message,
  :error_code,
  :invocation_id)
  SENSITIVE = []
  include Aws::Structure
end

#uriString

The extension URI associated to the action point in the extension definition. The URI can be an Amazon Resource Name (ARN) for one of the following: an Lambda function, an Amazon Simple Queue Service queue, an Amazon Simple Notification Service topic, or the Amazon EventBridge default event bus.



128
129
130
131
132
133
134
135
136
137
138
# File 'lib/aws-sdk-appconfig/types.rb', line 128

class ActionInvocation < Struct.new(
  :extension_identifier,
  :action_name,
  :uri,
  :role_arn,
  :error_message,
  :error_code,
  :invocation_id)
  SENSITIVE = []
  include Aws::Structure
end