Class: Aws::AppConfig::Types::AttributeValue

Inherits:
Struct
  • Object
show all
Includes:
Structure, Structure::Union
Defined in:
lib/aws-sdk-appconfig/types.rb

Overview

Note:

AttributeValue is a union - when making an API calls you must set exactly one of the members.

Note:

AttributeValue is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of AttributeValue corresponding to the set member.

A value for a feature flag attribute. Only one of the members can be set.

Defined Under Namespace

Classes: BooleanValue, NumberArray, NumberValue, StringArray, StringValue, Unknown

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#boolean_valueBoolean

A Boolean value for the attribute.

Returns:

  • (Boolean)


244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
# File 'lib/aws-sdk-appconfig/types.rb', line 244

class AttributeValue < Struct.new(
  :string_value,
  :number_value,
  :boolean_value,
  :string_array,
  :number_array,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class StringValue < AttributeValue; end
  class NumberValue < AttributeValue; end
  class BooleanValue < AttributeValue; end
  class StringArray < AttributeValue; end
  class NumberArray < AttributeValue; end
  class Unknown < AttributeValue; end
end

#number_arrayArray<Float>

An array of numeric values for the attribute.

Returns:

  • (Array<Float>)


244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
# File 'lib/aws-sdk-appconfig/types.rb', line 244

class AttributeValue < Struct.new(
  :string_value,
  :number_value,
  :boolean_value,
  :string_array,
  :number_array,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class StringValue < AttributeValue; end
  class NumberValue < AttributeValue; end
  class BooleanValue < AttributeValue; end
  class StringArray < AttributeValue; end
  class NumberArray < AttributeValue; end
  class Unknown < AttributeValue; end
end

#number_valueFloat

A numeric value for the attribute.

Returns:

  • (Float)


244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
# File 'lib/aws-sdk-appconfig/types.rb', line 244

class AttributeValue < Struct.new(
  :string_value,
  :number_value,
  :boolean_value,
  :string_array,
  :number_array,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class StringValue < AttributeValue; end
  class NumberValue < AttributeValue; end
  class BooleanValue < AttributeValue; end
  class StringArray < AttributeValue; end
  class NumberArray < AttributeValue; end
  class Unknown < AttributeValue; end
end

#string_arrayArray<String>

An array of string values for the attribute.

Returns:

  • (Array<String>)


244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
# File 'lib/aws-sdk-appconfig/types.rb', line 244

class AttributeValue < Struct.new(
  :string_value,
  :number_value,
  :boolean_value,
  :string_array,
  :number_array,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class StringValue < AttributeValue; end
  class NumberValue < AttributeValue; end
  class BooleanValue < AttributeValue; end
  class StringArray < AttributeValue; end
  class NumberArray < AttributeValue; end
  class Unknown < AttributeValue; end
end

#string_valueString

A string value for the attribute.

Returns:

  • (String)


244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
# File 'lib/aws-sdk-appconfig/types.rb', line 244

class AttributeValue < Struct.new(
  :string_value,
  :number_value,
  :boolean_value,
  :string_array,
  :number_array,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class StringValue < AttributeValue; end
  class NumberValue < AttributeValue; end
  class BooleanValue < AttributeValue; end
  class StringArray < AttributeValue; end
  class NumberArray < AttributeValue; end
  class Unknown < AttributeValue; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



244
245
246
# File 'lib/aws-sdk-appconfig/types.rb', line 244

def unknown
  @unknown
end