Class: Aws::AppConfig::Types::Configuration

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-appconfig/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:content]

Instance Attribute Summary collapse

Instance Attribute Details

#configuration_versionString

The configuration version.

Returns:

  • (String)


333
334
335
336
337
338
339
# File 'lib/aws-sdk-appconfig/types.rb', line 333

class Configuration < Struct.new(
  :content,
  :configuration_version,
  :content_type)
  SENSITIVE = [:content]
  include Aws::Structure
end

#contentString

The content of the configuration or the configuration data.

The Content attribute only contains data if the system finds new or updated configuration data. If there is no new or updated data and ClientConfigurationVersion matches the version of the current configuration, AppConfig returns a 204 No Content HTTP response code and the Content value will be empty.

Returns:

  • (String)


333
334
335
336
337
338
339
# File 'lib/aws-sdk-appconfig/types.rb', line 333

class Configuration < Struct.new(
  :content,
  :configuration_version,
  :content_type)
  SENSITIVE = [:content]
  include Aws::Structure
end

#content_typeString

A standard MIME type describing the format of the configuration content. For more information, see Content-Type.

Returns:

  • (String)


333
334
335
336
337
338
339
# File 'lib/aws-sdk-appconfig/types.rb', line 333

class Configuration < Struct.new(
  :content,
  :configuration_version,
  :content_type)
  SENSITIVE = [:content]
  include Aws::Structure
end