Class: Aws::AppConfig::Types::CreateExperimentDefinitionRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-appconfig/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#application_identifierString

The application ID or name.

Returns:

  • (String)


805
806
807
808
809
810
811
812
813
814
815
816
817
818
819
820
# File 'lib/aws-sdk-appconfig/types.rb', line 805

class CreateExperimentDefinitionRequest < Struct.new(
  :application_identifier,
  :name,
  :configuration_profile_identifier,
  :environment_identifier,
  :flag_key,
  :treatments,
  :control,
  :audience_rule,
  :hypothesis,
  :audience_description,
  :launch_criteria,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#audience_descriptionString

A description of the intended audience for the experiment.

Returns:

  • (String)


805
806
807
808
809
810
811
812
813
814
815
816
817
818
819
820
# File 'lib/aws-sdk-appconfig/types.rb', line 805

class CreateExperimentDefinitionRequest < Struct.new(
  :application_identifier,
  :name,
  :configuration_profile_identifier,
  :environment_identifier,
  :flag_key,
  :treatments,
  :control,
  :audience_rule,
  :hypothesis,
  :audience_description,
  :launch_criteria,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#audience_ruleString

A rule that defines which users are eligible to be assigned to treatments during the experiment.

Returns:

  • (String)


805
806
807
808
809
810
811
812
813
814
815
816
817
818
819
820
# File 'lib/aws-sdk-appconfig/types.rb', line 805

class CreateExperimentDefinitionRequest < Struct.new(
  :application_identifier,
  :name,
  :configuration_profile_identifier,
  :environment_identifier,
  :flag_key,
  :treatments,
  :control,
  :audience_rule,
  :hypothesis,
  :audience_description,
  :launch_criteria,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#configuration_profile_identifierString

The configuration profile ID or name that stores the feature flag.

Returns:

  • (String)


805
806
807
808
809
810
811
812
813
814
815
816
817
818
819
820
# File 'lib/aws-sdk-appconfig/types.rb', line 805

class CreateExperimentDefinitionRequest < Struct.new(
  :application_identifier,
  :name,
  :configuration_profile_identifier,
  :environment_identifier,
  :flag_key,
  :treatments,
  :control,
  :audience_rule,
  :hypothesis,
  :audience_description,
  :launch_criteria,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#controlTypes::TreatmentInput

The control treatment that represents the baseline experience for comparison.



805
806
807
808
809
810
811
812
813
814
815
816
817
818
819
820
# File 'lib/aws-sdk-appconfig/types.rb', line 805

class CreateExperimentDefinitionRequest < Struct.new(
  :application_identifier,
  :name,
  :configuration_profile_identifier,
  :environment_identifier,
  :flag_key,
  :treatments,
  :control,
  :audience_rule,
  :hypothesis,
  :audience_description,
  :launch_criteria,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#environment_identifierString

The environment ID or name where the experiment will run.

Returns:

  • (String)


805
806
807
808
809
810
811
812
813
814
815
816
817
818
819
820
# File 'lib/aws-sdk-appconfig/types.rb', line 805

class CreateExperimentDefinitionRequest < Struct.new(
  :application_identifier,
  :name,
  :configuration_profile_identifier,
  :environment_identifier,
  :flag_key,
  :treatments,
  :control,
  :audience_rule,
  :hypothesis,
  :audience_description,
  :launch_criteria,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#flag_keyString

The key of the existing feature flag to use with the experiment.

Returns:

  • (String)


805
806
807
808
809
810
811
812
813
814
815
816
817
818
819
820
# File 'lib/aws-sdk-appconfig/types.rb', line 805

class CreateExperimentDefinitionRequest < Struct.new(
  :application_identifier,
  :name,
  :configuration_profile_identifier,
  :environment_identifier,
  :flag_key,
  :treatments,
  :control,
  :audience_rule,
  :hypothesis,
  :audience_description,
  :launch_criteria,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#hypothesisString

A description of the goal or hypothesis the experiment is designed to validate.

Returns:

  • (String)


805
806
807
808
809
810
811
812
813
814
815
816
817
818
819
820
# File 'lib/aws-sdk-appconfig/types.rb', line 805

class CreateExperimentDefinitionRequest < Struct.new(
  :application_identifier,
  :name,
  :configuration_profile_identifier,
  :environment_identifier,
  :flag_key,
  :treatments,
  :control,
  :audience_rule,
  :hypothesis,
  :audience_description,
  :launch_criteria,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#launch_criteriaString

Information about the conditions under which you would launch the winning treatment.

Returns:

  • (String)


805
806
807
808
809
810
811
812
813
814
815
816
817
818
819
820
# File 'lib/aws-sdk-appconfig/types.rb', line 805

class CreateExperimentDefinitionRequest < Struct.new(
  :application_identifier,
  :name,
  :configuration_profile_identifier,
  :environment_identifier,
  :flag_key,
  :treatments,
  :control,
  :audience_rule,
  :hypothesis,
  :audience_description,
  :launch_criteria,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

A name for the experiment definition.

Returns:

  • (String)


805
806
807
808
809
810
811
812
813
814
815
816
817
818
819
820
# File 'lib/aws-sdk-appconfig/types.rb', line 805

class CreateExperimentDefinitionRequest < Struct.new(
  :application_identifier,
  :name,
  :configuration_profile_identifier,
  :environment_identifier,
  :flag_key,
  :treatments,
  :control,
  :audience_rule,
  :hypothesis,
  :audience_description,
  :launch_criteria,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tagsHash<String,String>

The tags to assign to the experiment definition. Tags help organize and categorize your AppConfig resources.

Returns:

  • (Hash<String,String>)


805
806
807
808
809
810
811
812
813
814
815
816
817
818
819
820
# File 'lib/aws-sdk-appconfig/types.rb', line 805

class CreateExperimentDefinitionRequest < Struct.new(
  :application_identifier,
  :name,
  :configuration_profile_identifier,
  :environment_identifier,
  :flag_key,
  :treatments,
  :control,
  :audience_rule,
  :hypothesis,
  :audience_description,
  :launch_criteria,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#treatmentsArray<Types::TreatmentInput>

A list of treatments to evaluate during the experiment. Each treatment defines a distinct variation compared to the control.

Returns:



805
806
807
808
809
810
811
812
813
814
815
816
817
818
819
820
# File 'lib/aws-sdk-appconfig/types.rb', line 805

class CreateExperimentDefinitionRequest < Struct.new(
  :application_identifier,
  :name,
  :configuration_profile_identifier,
  :environment_identifier,
  :flag_key,
  :treatments,
  :control,
  :audience_rule,
  :hypothesis,
  :audience_description,
  :launch_criteria,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end