Class: Aws::AppConfig::Types::CreateHostedConfigurationVersionRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::AppConfig::Types::CreateHostedConfigurationVersionRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-appconfig/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:content]
Instance Attribute Summary collapse
-
#application_id ⇒ String
The application ID.
-
#configuration_profile_id ⇒ String
The configuration profile ID.
-
#content ⇒ String
The configuration data, as bytes.
-
#content_type ⇒ String
A standard MIME type describing the format of the configuration content.
-
#description ⇒ String
A description of the configuration.
-
#latest_version_number ⇒ Integer
An optional locking token used to prevent race conditions from overwriting configuration updates when creating a new version.
-
#version_label ⇒ String
An optional, user-defined label for the AppConfig hosted configuration version.
Instance Attribute Details
#application_id ⇒ String
The application ID.
957 958 959 960 961 962 963 964 965 966 967 |
# File 'lib/aws-sdk-appconfig/types.rb', line 957 class CreateHostedConfigurationVersionRequest < Struct.new( :application_id, :configuration_profile_id, :description, :content, :content_type, :latest_version_number, :version_label) SENSITIVE = [:content] include Aws::Structure end |
#configuration_profile_id ⇒ String
The configuration profile ID.
957 958 959 960 961 962 963 964 965 966 967 |
# File 'lib/aws-sdk-appconfig/types.rb', line 957 class CreateHostedConfigurationVersionRequest < Struct.new( :application_id, :configuration_profile_id, :description, :content, :content_type, :latest_version_number, :version_label) SENSITIVE = [:content] include Aws::Structure end |
#content ⇒ String
The configuration data, as bytes.
957 958 959 960 961 962 963 964 965 966 967 |
# File 'lib/aws-sdk-appconfig/types.rb', line 957 class CreateHostedConfigurationVersionRequest < Struct.new( :application_id, :configuration_profile_id, :description, :content, :content_type, :latest_version_number, :version_label) SENSITIVE = [:content] include Aws::Structure end |
#content_type ⇒ String
A standard MIME type describing the format of the configuration content. For more information, see Content-Type.
957 958 959 960 961 962 963 964 965 966 967 |
# File 'lib/aws-sdk-appconfig/types.rb', line 957 class CreateHostedConfigurationVersionRequest < Struct.new( :application_id, :configuration_profile_id, :description, :content, :content_type, :latest_version_number, :version_label) SENSITIVE = [:content] include Aws::Structure end |
#description ⇒ String
A description of the configuration.
957 958 959 960 961 962 963 964 965 966 967 |
# File 'lib/aws-sdk-appconfig/types.rb', line 957 class CreateHostedConfigurationVersionRequest < Struct.new( :application_id, :configuration_profile_id, :description, :content, :content_type, :latest_version_number, :version_label) SENSITIVE = [:content] include Aws::Structure end |
#latest_version_number ⇒ Integer
An optional locking token used to prevent race conditions from overwriting configuration updates when creating a new version. To ensure your data is not overwritten when creating multiple hosted configuration versions in rapid succession, specify the version number of the latest hosted configuration version.
957 958 959 960 961 962 963 964 965 966 967 |
# File 'lib/aws-sdk-appconfig/types.rb', line 957 class CreateHostedConfigurationVersionRequest < Struct.new( :application_id, :configuration_profile_id, :description, :content, :content_type, :latest_version_number, :version_label) SENSITIVE = [:content] include Aws::Structure end |
#version_label ⇒ String
An optional, user-defined label for the AppConfig hosted configuration version. This value must contain at least one non-numeric character. For example, "v2.2.0".
957 958 959 960 961 962 963 964 965 966 967 |
# File 'lib/aws-sdk-appconfig/types.rb', line 957 class CreateHostedConfigurationVersionRequest < Struct.new( :application_id, :configuration_profile_id, :description, :content, :content_type, :latest_version_number, :version_label) SENSITIVE = [:content] include Aws::Structure end |