Class: Aws::AppConfig::Types::DeletionProtectionSettings

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-appconfig/types.rb

Overview

A parameter to configure deletion protection. Deletion protection prevents a user from deleting a configuration profile or an environment if AppConfig has called either GetLatestConfiguration or for the configuration profile or from the environment during the specified interval.

The default interval specified by ProtectionPeriodInMinutes is 60. DeletionProtectionCheck skips configuration profiles and environments that were created in the past hour.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#enabledBoolean

A parameter that indicates if deletion protection is enabled or not.

Returns:

  • (Boolean)


1194
1195
1196
1197
1198
1199
# File 'lib/aws-sdk-appconfig/types.rb', line 1194

class DeletionProtectionSettings < Struct.new(
  :enabled,
  :protection_period_in_minutes)
  SENSITIVE = []
  include Aws::Structure
end

#protection_period_in_minutesInteger

The time interval during which AppConfig monitors for calls to GetLatestConfiguration or for a configuration profile or from an environment. AppConfig returns an error if a user calls or for the designated configuration profile or environment. To bypass the error and delete a configuration profile or an environment, specify BYPASS for the DeletionProtectionCheck parameter for either or .

Returns:

  • (Integer)


1194
1195
1196
1197
1198
1199
# File 'lib/aws-sdk-appconfig/types.rb', line 1194

class DeletionProtectionSettings < Struct.new(
  :enabled,
  :protection_period_in_minutes)
  SENSITIVE = []
  include Aws::Structure
end