Class: Aws::AppConfig::Types::Deployment
- Inherits:
-
Struct
- Object
- Struct
- Aws::AppConfig::Types::Deployment
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-appconfig/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#application_id ⇒ String
The ID of the application that was deployed.
-
#applied_extensions ⇒ Array<Types::AppliedExtension>
A list of extensions that were processed as part of the deployment.
-
#completed_at ⇒ Time
The time the deployment completed.
-
#configuration_location_uri ⇒ String
Information about the source location of the configuration.
-
#configuration_name ⇒ String
The name of the configuration.
-
#configuration_profile_id ⇒ String
The ID of the configuration profile that was deployed.
-
#configuration_version ⇒ String
The configuration version that was deployed.
-
#deployment_duration_in_minutes ⇒ Integer
Total amount of time the deployment lasted.
-
#deployment_number ⇒ Integer
The sequence number of the deployment.
-
#deployment_strategy_id ⇒ String
The ID of the deployment strategy that was deployed.
-
#description ⇒ String
The description of the deployment.
-
#environment_id ⇒ String
The ID of the environment that was deployed.
-
#event_log ⇒ Array<Types::DeploymentEvent>
A list containing all events related to a deployment.
-
#final_bake_time_in_minutes ⇒ Integer
The amount of time that AppConfig monitored for alarms before considering the deployment to be complete and no longer eligible for automatic rollback.
-
#growth_factor ⇒ Float
The percentage of targets to receive a deployed configuration during each interval.
-
#growth_type ⇒ String
The algorithm used to define how percentage grew over time.
-
#kms_key_arn ⇒ String
The Amazon Resource Name of the Key Management Service key used to encrypt configuration data.
-
#kms_key_identifier ⇒ String
The Key Management Service key identifier (key ID, key alias, or key ARN) provided when the resource was created or updated.
-
#percentage_complete ⇒ Float
The percentage of targets for which the deployment is available.
-
#started_at ⇒ Time
The time the deployment started.
-
#state ⇒ String
The state of the deployment.
-
#version_label ⇒ String
A user-defined label for an AppConfig hosted configuration version.
Instance Attribute Details
#application_id ⇒ String
The ID of the application that was deployed.
1303 1304 1305 1306 1307 1308 1309 1310 1311 1312 1313 1314 1315 1316 1317 1318 1319 1320 1321 1322 1323 1324 1325 1326 1327 1328 |
# File 'lib/aws-sdk-appconfig/types.rb', line 1303 class Deployment < Struct.new( :application_id, :environment_id, :deployment_strategy_id, :configuration_profile_id, :deployment_number, :configuration_name, :configuration_location_uri, :configuration_version, :description, :deployment_duration_in_minutes, :growth_type, :growth_factor, :final_bake_time_in_minutes, :state, :event_log, :percentage_complete, :started_at, :completed_at, :applied_extensions, :kms_key_arn, :kms_key_identifier, :version_label) SENSITIVE = [] include Aws::Structure end |
#applied_extensions ⇒ Array<Types::AppliedExtension>
A list of extensions that were processed as part of the deployment.
The extensions that were previously associated to the configuration
profile, environment, or the application when StartDeployment was
called.
1303 1304 1305 1306 1307 1308 1309 1310 1311 1312 1313 1314 1315 1316 1317 1318 1319 1320 1321 1322 1323 1324 1325 1326 1327 1328 |
# File 'lib/aws-sdk-appconfig/types.rb', line 1303 class Deployment < Struct.new( :application_id, :environment_id, :deployment_strategy_id, :configuration_profile_id, :deployment_number, :configuration_name, :configuration_location_uri, :configuration_version, :description, :deployment_duration_in_minutes, :growth_type, :growth_factor, :final_bake_time_in_minutes, :state, :event_log, :percentage_complete, :started_at, :completed_at, :applied_extensions, :kms_key_arn, :kms_key_identifier, :version_label) SENSITIVE = [] include Aws::Structure end |
#completed_at ⇒ Time
The time the deployment completed.
1303 1304 1305 1306 1307 1308 1309 1310 1311 1312 1313 1314 1315 1316 1317 1318 1319 1320 1321 1322 1323 1324 1325 1326 1327 1328 |
# File 'lib/aws-sdk-appconfig/types.rb', line 1303 class Deployment < Struct.new( :application_id, :environment_id, :deployment_strategy_id, :configuration_profile_id, :deployment_number, :configuration_name, :configuration_location_uri, :configuration_version, :description, :deployment_duration_in_minutes, :growth_type, :growth_factor, :final_bake_time_in_minutes, :state, :event_log, :percentage_complete, :started_at, :completed_at, :applied_extensions, :kms_key_arn, :kms_key_identifier, :version_label) SENSITIVE = [] include Aws::Structure end |
#configuration_location_uri ⇒ String
Information about the source location of the configuration.
1303 1304 1305 1306 1307 1308 1309 1310 1311 1312 1313 1314 1315 1316 1317 1318 1319 1320 1321 1322 1323 1324 1325 1326 1327 1328 |
# File 'lib/aws-sdk-appconfig/types.rb', line 1303 class Deployment < Struct.new( :application_id, :environment_id, :deployment_strategy_id, :configuration_profile_id, :deployment_number, :configuration_name, :configuration_location_uri, :configuration_version, :description, :deployment_duration_in_minutes, :growth_type, :growth_factor, :final_bake_time_in_minutes, :state, :event_log, :percentage_complete, :started_at, :completed_at, :applied_extensions, :kms_key_arn, :kms_key_identifier, :version_label) SENSITIVE = [] include Aws::Structure end |
#configuration_name ⇒ String
The name of the configuration.
1303 1304 1305 1306 1307 1308 1309 1310 1311 1312 1313 1314 1315 1316 1317 1318 1319 1320 1321 1322 1323 1324 1325 1326 1327 1328 |
# File 'lib/aws-sdk-appconfig/types.rb', line 1303 class Deployment < Struct.new( :application_id, :environment_id, :deployment_strategy_id, :configuration_profile_id, :deployment_number, :configuration_name, :configuration_location_uri, :configuration_version, :description, :deployment_duration_in_minutes, :growth_type, :growth_factor, :final_bake_time_in_minutes, :state, :event_log, :percentage_complete, :started_at, :completed_at, :applied_extensions, :kms_key_arn, :kms_key_identifier, :version_label) SENSITIVE = [] include Aws::Structure end |
#configuration_profile_id ⇒ String
The ID of the configuration profile that was deployed.
1303 1304 1305 1306 1307 1308 1309 1310 1311 1312 1313 1314 1315 1316 1317 1318 1319 1320 1321 1322 1323 1324 1325 1326 1327 1328 |
# File 'lib/aws-sdk-appconfig/types.rb', line 1303 class Deployment < Struct.new( :application_id, :environment_id, :deployment_strategy_id, :configuration_profile_id, :deployment_number, :configuration_name, :configuration_location_uri, :configuration_version, :description, :deployment_duration_in_minutes, :growth_type, :growth_factor, :final_bake_time_in_minutes, :state, :event_log, :percentage_complete, :started_at, :completed_at, :applied_extensions, :kms_key_arn, :kms_key_identifier, :version_label) SENSITIVE = [] include Aws::Structure end |
#configuration_version ⇒ String
The configuration version that was deployed.
1303 1304 1305 1306 1307 1308 1309 1310 1311 1312 1313 1314 1315 1316 1317 1318 1319 1320 1321 1322 1323 1324 1325 1326 1327 1328 |
# File 'lib/aws-sdk-appconfig/types.rb', line 1303 class Deployment < Struct.new( :application_id, :environment_id, :deployment_strategy_id, :configuration_profile_id, :deployment_number, :configuration_name, :configuration_location_uri, :configuration_version, :description, :deployment_duration_in_minutes, :growth_type, :growth_factor, :final_bake_time_in_minutes, :state, :event_log, :percentage_complete, :started_at, :completed_at, :applied_extensions, :kms_key_arn, :kms_key_identifier, :version_label) SENSITIVE = [] include Aws::Structure end |
#deployment_duration_in_minutes ⇒ Integer
Total amount of time the deployment lasted.
1303 1304 1305 1306 1307 1308 1309 1310 1311 1312 1313 1314 1315 1316 1317 1318 1319 1320 1321 1322 1323 1324 1325 1326 1327 1328 |
# File 'lib/aws-sdk-appconfig/types.rb', line 1303 class Deployment < Struct.new( :application_id, :environment_id, :deployment_strategy_id, :configuration_profile_id, :deployment_number, :configuration_name, :configuration_location_uri, :configuration_version, :description, :deployment_duration_in_minutes, :growth_type, :growth_factor, :final_bake_time_in_minutes, :state, :event_log, :percentage_complete, :started_at, :completed_at, :applied_extensions, :kms_key_arn, :kms_key_identifier, :version_label) SENSITIVE = [] include Aws::Structure end |
#deployment_number ⇒ Integer
The sequence number of the deployment.
1303 1304 1305 1306 1307 1308 1309 1310 1311 1312 1313 1314 1315 1316 1317 1318 1319 1320 1321 1322 1323 1324 1325 1326 1327 1328 |
# File 'lib/aws-sdk-appconfig/types.rb', line 1303 class Deployment < Struct.new( :application_id, :environment_id, :deployment_strategy_id, :configuration_profile_id, :deployment_number, :configuration_name, :configuration_location_uri, :configuration_version, :description, :deployment_duration_in_minutes, :growth_type, :growth_factor, :final_bake_time_in_minutes, :state, :event_log, :percentage_complete, :started_at, :completed_at, :applied_extensions, :kms_key_arn, :kms_key_identifier, :version_label) SENSITIVE = [] include Aws::Structure end |
#deployment_strategy_id ⇒ String
The ID of the deployment strategy that was deployed.
1303 1304 1305 1306 1307 1308 1309 1310 1311 1312 1313 1314 1315 1316 1317 1318 1319 1320 1321 1322 1323 1324 1325 1326 1327 1328 |
# File 'lib/aws-sdk-appconfig/types.rb', line 1303 class Deployment < Struct.new( :application_id, :environment_id, :deployment_strategy_id, :configuration_profile_id, :deployment_number, :configuration_name, :configuration_location_uri, :configuration_version, :description, :deployment_duration_in_minutes, :growth_type, :growth_factor, :final_bake_time_in_minutes, :state, :event_log, :percentage_complete, :started_at, :completed_at, :applied_extensions, :kms_key_arn, :kms_key_identifier, :version_label) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description of the deployment.
1303 1304 1305 1306 1307 1308 1309 1310 1311 1312 1313 1314 1315 1316 1317 1318 1319 1320 1321 1322 1323 1324 1325 1326 1327 1328 |
# File 'lib/aws-sdk-appconfig/types.rb', line 1303 class Deployment < Struct.new( :application_id, :environment_id, :deployment_strategy_id, :configuration_profile_id, :deployment_number, :configuration_name, :configuration_location_uri, :configuration_version, :description, :deployment_duration_in_minutes, :growth_type, :growth_factor, :final_bake_time_in_minutes, :state, :event_log, :percentage_complete, :started_at, :completed_at, :applied_extensions, :kms_key_arn, :kms_key_identifier, :version_label) SENSITIVE = [] include Aws::Structure end |
#environment_id ⇒ String
The ID of the environment that was deployed.
1303 1304 1305 1306 1307 1308 1309 1310 1311 1312 1313 1314 1315 1316 1317 1318 1319 1320 1321 1322 1323 1324 1325 1326 1327 1328 |
# File 'lib/aws-sdk-appconfig/types.rb', line 1303 class Deployment < Struct.new( :application_id, :environment_id, :deployment_strategy_id, :configuration_profile_id, :deployment_number, :configuration_name, :configuration_location_uri, :configuration_version, :description, :deployment_duration_in_minutes, :growth_type, :growth_factor, :final_bake_time_in_minutes, :state, :event_log, :percentage_complete, :started_at, :completed_at, :applied_extensions, :kms_key_arn, :kms_key_identifier, :version_label) SENSITIVE = [] include Aws::Structure end |
#event_log ⇒ Array<Types::DeploymentEvent>
A list containing all events related to a deployment. The most recent events are displayed first.
1303 1304 1305 1306 1307 1308 1309 1310 1311 1312 1313 1314 1315 1316 1317 1318 1319 1320 1321 1322 1323 1324 1325 1326 1327 1328 |
# File 'lib/aws-sdk-appconfig/types.rb', line 1303 class Deployment < Struct.new( :application_id, :environment_id, :deployment_strategy_id, :configuration_profile_id, :deployment_number, :configuration_name, :configuration_location_uri, :configuration_version, :description, :deployment_duration_in_minutes, :growth_type, :growth_factor, :final_bake_time_in_minutes, :state, :event_log, :percentage_complete, :started_at, :completed_at, :applied_extensions, :kms_key_arn, :kms_key_identifier, :version_label) SENSITIVE = [] include Aws::Structure end |
#final_bake_time_in_minutes ⇒ Integer
The amount of time that AppConfig monitored for alarms before considering the deployment to be complete and no longer eligible for automatic rollback.
1303 1304 1305 1306 1307 1308 1309 1310 1311 1312 1313 1314 1315 1316 1317 1318 1319 1320 1321 1322 1323 1324 1325 1326 1327 1328 |
# File 'lib/aws-sdk-appconfig/types.rb', line 1303 class Deployment < Struct.new( :application_id, :environment_id, :deployment_strategy_id, :configuration_profile_id, :deployment_number, :configuration_name, :configuration_location_uri, :configuration_version, :description, :deployment_duration_in_minutes, :growth_type, :growth_factor, :final_bake_time_in_minutes, :state, :event_log, :percentage_complete, :started_at, :completed_at, :applied_extensions, :kms_key_arn, :kms_key_identifier, :version_label) SENSITIVE = [] include Aws::Structure end |
#growth_factor ⇒ Float
The percentage of targets to receive a deployed configuration during each interval.
1303 1304 1305 1306 1307 1308 1309 1310 1311 1312 1313 1314 1315 1316 1317 1318 1319 1320 1321 1322 1323 1324 1325 1326 1327 1328 |
# File 'lib/aws-sdk-appconfig/types.rb', line 1303 class Deployment < Struct.new( :application_id, :environment_id, :deployment_strategy_id, :configuration_profile_id, :deployment_number, :configuration_name, :configuration_location_uri, :configuration_version, :description, :deployment_duration_in_minutes, :growth_type, :growth_factor, :final_bake_time_in_minutes, :state, :event_log, :percentage_complete, :started_at, :completed_at, :applied_extensions, :kms_key_arn, :kms_key_identifier, :version_label) SENSITIVE = [] include Aws::Structure end |
#growth_type ⇒ String
The algorithm used to define how percentage grew over time.
1303 1304 1305 1306 1307 1308 1309 1310 1311 1312 1313 1314 1315 1316 1317 1318 1319 1320 1321 1322 1323 1324 1325 1326 1327 1328 |
# File 'lib/aws-sdk-appconfig/types.rb', line 1303 class Deployment < Struct.new( :application_id, :environment_id, :deployment_strategy_id, :configuration_profile_id, :deployment_number, :configuration_name, :configuration_location_uri, :configuration_version, :description, :deployment_duration_in_minutes, :growth_type, :growth_factor, :final_bake_time_in_minutes, :state, :event_log, :percentage_complete, :started_at, :completed_at, :applied_extensions, :kms_key_arn, :kms_key_identifier, :version_label) SENSITIVE = [] include Aws::Structure end |
#kms_key_arn ⇒ String
The Amazon Resource Name of the Key Management Service key used to encrypt configuration data. You can encrypt secrets stored in Secrets Manager, Amazon Simple Storage Service (Amazon S3) objects encrypted with SSE-KMS, or secure string parameters stored in Amazon Web Services Systems Manager Parameter Store.
1303 1304 1305 1306 1307 1308 1309 1310 1311 1312 1313 1314 1315 1316 1317 1318 1319 1320 1321 1322 1323 1324 1325 1326 1327 1328 |
# File 'lib/aws-sdk-appconfig/types.rb', line 1303 class Deployment < Struct.new( :application_id, :environment_id, :deployment_strategy_id, :configuration_profile_id, :deployment_number, :configuration_name, :configuration_location_uri, :configuration_version, :description, :deployment_duration_in_minutes, :growth_type, :growth_factor, :final_bake_time_in_minutes, :state, :event_log, :percentage_complete, :started_at, :completed_at, :applied_extensions, :kms_key_arn, :kms_key_identifier, :version_label) SENSITIVE = [] include Aws::Structure end |
#kms_key_identifier ⇒ String
The Key Management Service key identifier (key ID, key alias, or key ARN) provided when the resource was created or updated.
1303 1304 1305 1306 1307 1308 1309 1310 1311 1312 1313 1314 1315 1316 1317 1318 1319 1320 1321 1322 1323 1324 1325 1326 1327 1328 |
# File 'lib/aws-sdk-appconfig/types.rb', line 1303 class Deployment < Struct.new( :application_id, :environment_id, :deployment_strategy_id, :configuration_profile_id, :deployment_number, :configuration_name, :configuration_location_uri, :configuration_version, :description, :deployment_duration_in_minutes, :growth_type, :growth_factor, :final_bake_time_in_minutes, :state, :event_log, :percentage_complete, :started_at, :completed_at, :applied_extensions, :kms_key_arn, :kms_key_identifier, :version_label) SENSITIVE = [] include Aws::Structure end |
#percentage_complete ⇒ Float
The percentage of targets for which the deployment is available.
1303 1304 1305 1306 1307 1308 1309 1310 1311 1312 1313 1314 1315 1316 1317 1318 1319 1320 1321 1322 1323 1324 1325 1326 1327 1328 |
# File 'lib/aws-sdk-appconfig/types.rb', line 1303 class Deployment < Struct.new( :application_id, :environment_id, :deployment_strategy_id, :configuration_profile_id, :deployment_number, :configuration_name, :configuration_location_uri, :configuration_version, :description, :deployment_duration_in_minutes, :growth_type, :growth_factor, :final_bake_time_in_minutes, :state, :event_log, :percentage_complete, :started_at, :completed_at, :applied_extensions, :kms_key_arn, :kms_key_identifier, :version_label) SENSITIVE = [] include Aws::Structure end |
#started_at ⇒ Time
The time the deployment started.
1303 1304 1305 1306 1307 1308 1309 1310 1311 1312 1313 1314 1315 1316 1317 1318 1319 1320 1321 1322 1323 1324 1325 1326 1327 1328 |
# File 'lib/aws-sdk-appconfig/types.rb', line 1303 class Deployment < Struct.new( :application_id, :environment_id, :deployment_strategy_id, :configuration_profile_id, :deployment_number, :configuration_name, :configuration_location_uri, :configuration_version, :description, :deployment_duration_in_minutes, :growth_type, :growth_factor, :final_bake_time_in_minutes, :state, :event_log, :percentage_complete, :started_at, :completed_at, :applied_extensions, :kms_key_arn, :kms_key_identifier, :version_label) SENSITIVE = [] include Aws::Structure end |
#state ⇒ String
The state of the deployment.
1303 1304 1305 1306 1307 1308 1309 1310 1311 1312 1313 1314 1315 1316 1317 1318 1319 1320 1321 1322 1323 1324 1325 1326 1327 1328 |
# File 'lib/aws-sdk-appconfig/types.rb', line 1303 class Deployment < Struct.new( :application_id, :environment_id, :deployment_strategy_id, :configuration_profile_id, :deployment_number, :configuration_name, :configuration_location_uri, :configuration_version, :description, :deployment_duration_in_minutes, :growth_type, :growth_factor, :final_bake_time_in_minutes, :state, :event_log, :percentage_complete, :started_at, :completed_at, :applied_extensions, :kms_key_arn, :kms_key_identifier, :version_label) SENSITIVE = [] include Aws::Structure end |
#version_label ⇒ String
A user-defined label for an AppConfig hosted configuration version.
1303 1304 1305 1306 1307 1308 1309 1310 1311 1312 1313 1314 1315 1316 1317 1318 1319 1320 1321 1322 1323 1324 1325 1326 1327 1328 |
# File 'lib/aws-sdk-appconfig/types.rb', line 1303 class Deployment < Struct.new( :application_id, :environment_id, :deployment_strategy_id, :configuration_profile_id, :deployment_number, :configuration_name, :configuration_location_uri, :configuration_version, :description, :deployment_duration_in_minutes, :growth_type, :growth_factor, :final_bake_time_in_minutes, :state, :event_log, :percentage_complete, :started_at, :completed_at, :applied_extensions, :kms_key_arn, :kms_key_identifier, :version_label) SENSITIVE = [] include Aws::Structure end |