Class: Aws::AppConfig::Types::DeploymentSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::AppConfig::Types::DeploymentSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-appconfig/types.rb
Overview
Information about the deployment.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#completed_at ⇒ Time
Time the deployment completed.
-
#configuration_name ⇒ String
The name of the configuration.
-
#configuration_profile_id ⇒ String
The ID of the configuration profile that was deployed.
-
#configuration_version ⇒ String
The version of the configuration.
-
#deployment_duration_in_minutes ⇒ Integer
Total amount of time the deployment lasted.
-
#deployment_number ⇒ Integer
The sequence number of the deployment.
-
#final_bake_time_in_minutes ⇒ Integer
The amount of time that AppConfig monitors for alarms before considering the deployment to be complete and no longer eligible for automatic rollback.
-
#growth_factor ⇒ Float
The percentage of targets to receive a deployed configuration during each interval.
-
#growth_type ⇒ String
The algorithm used to define how percentage grows over time.
-
#percentage_complete ⇒ Float
The percentage of targets for which the deployment is available.
-
#started_at ⇒ Time
Time the deployment started.
-
#state ⇒ String
The state of the deployment.
-
#type ⇒ String
The type of deployment.
-
#version_label ⇒ String
A user-defined label for an AppConfig hosted configuration version.
Instance Attribute Details
#completed_at ⇒ Time
Time the deployment completed.
1529 1530 1531 1532 1533 1534 1535 1536 1537 1538 1539 1540 1541 1542 1543 1544 1545 1546 |
# File 'lib/aws-sdk-appconfig/types.rb', line 1529 class DeploymentSummary < Struct.new( :deployment_number, :configuration_profile_id, :configuration_name, :configuration_version, :deployment_duration_in_minutes, :growth_type, :growth_factor, :final_bake_time_in_minutes, :state, :percentage_complete, :started_at, :completed_at, :version_label, :type) SENSITIVE = [] include Aws::Structure end |
#configuration_name ⇒ String
The name of the configuration.
1529 1530 1531 1532 1533 1534 1535 1536 1537 1538 1539 1540 1541 1542 1543 1544 1545 1546 |
# File 'lib/aws-sdk-appconfig/types.rb', line 1529 class DeploymentSummary < Struct.new( :deployment_number, :configuration_profile_id, :configuration_name, :configuration_version, :deployment_duration_in_minutes, :growth_type, :growth_factor, :final_bake_time_in_minutes, :state, :percentage_complete, :started_at, :completed_at, :version_label, :type) SENSITIVE = [] include Aws::Structure end |
#configuration_profile_id ⇒ String
The ID of the configuration profile that was deployed.
1529 1530 1531 1532 1533 1534 1535 1536 1537 1538 1539 1540 1541 1542 1543 1544 1545 1546 |
# File 'lib/aws-sdk-appconfig/types.rb', line 1529 class DeploymentSummary < Struct.new( :deployment_number, :configuration_profile_id, :configuration_name, :configuration_version, :deployment_duration_in_minutes, :growth_type, :growth_factor, :final_bake_time_in_minutes, :state, :percentage_complete, :started_at, :completed_at, :version_label, :type) SENSITIVE = [] include Aws::Structure end |
#configuration_version ⇒ String
The version of the configuration.
1529 1530 1531 1532 1533 1534 1535 1536 1537 1538 1539 1540 1541 1542 1543 1544 1545 1546 |
# File 'lib/aws-sdk-appconfig/types.rb', line 1529 class DeploymentSummary < Struct.new( :deployment_number, :configuration_profile_id, :configuration_name, :configuration_version, :deployment_duration_in_minutes, :growth_type, :growth_factor, :final_bake_time_in_minutes, :state, :percentage_complete, :started_at, :completed_at, :version_label, :type) SENSITIVE = [] include Aws::Structure end |
#deployment_duration_in_minutes ⇒ Integer
Total amount of time the deployment lasted.
1529 1530 1531 1532 1533 1534 1535 1536 1537 1538 1539 1540 1541 1542 1543 1544 1545 1546 |
# File 'lib/aws-sdk-appconfig/types.rb', line 1529 class DeploymentSummary < Struct.new( :deployment_number, :configuration_profile_id, :configuration_name, :configuration_version, :deployment_duration_in_minutes, :growth_type, :growth_factor, :final_bake_time_in_minutes, :state, :percentage_complete, :started_at, :completed_at, :version_label, :type) SENSITIVE = [] include Aws::Structure end |
#deployment_number ⇒ Integer
The sequence number of the deployment.
1529 1530 1531 1532 1533 1534 1535 1536 1537 1538 1539 1540 1541 1542 1543 1544 1545 1546 |
# File 'lib/aws-sdk-appconfig/types.rb', line 1529 class DeploymentSummary < Struct.new( :deployment_number, :configuration_profile_id, :configuration_name, :configuration_version, :deployment_duration_in_minutes, :growth_type, :growth_factor, :final_bake_time_in_minutes, :state, :percentage_complete, :started_at, :completed_at, :version_label, :type) SENSITIVE = [] include Aws::Structure end |
#final_bake_time_in_minutes ⇒ Integer
The amount of time that AppConfig monitors for alarms before considering the deployment to be complete and no longer eligible for automatic rollback.
1529 1530 1531 1532 1533 1534 1535 1536 1537 1538 1539 1540 1541 1542 1543 1544 1545 1546 |
# File 'lib/aws-sdk-appconfig/types.rb', line 1529 class DeploymentSummary < Struct.new( :deployment_number, :configuration_profile_id, :configuration_name, :configuration_version, :deployment_duration_in_minutes, :growth_type, :growth_factor, :final_bake_time_in_minutes, :state, :percentage_complete, :started_at, :completed_at, :version_label, :type) SENSITIVE = [] include Aws::Structure end |
#growth_factor ⇒ Float
The percentage of targets to receive a deployed configuration during each interval.
1529 1530 1531 1532 1533 1534 1535 1536 1537 1538 1539 1540 1541 1542 1543 1544 1545 1546 |
# File 'lib/aws-sdk-appconfig/types.rb', line 1529 class DeploymentSummary < Struct.new( :deployment_number, :configuration_profile_id, :configuration_name, :configuration_version, :deployment_duration_in_minutes, :growth_type, :growth_factor, :final_bake_time_in_minutes, :state, :percentage_complete, :started_at, :completed_at, :version_label, :type) SENSITIVE = [] include Aws::Structure end |
#growth_type ⇒ String
The algorithm used to define how percentage grows over time.
1529 1530 1531 1532 1533 1534 1535 1536 1537 1538 1539 1540 1541 1542 1543 1544 1545 1546 |
# File 'lib/aws-sdk-appconfig/types.rb', line 1529 class DeploymentSummary < Struct.new( :deployment_number, :configuration_profile_id, :configuration_name, :configuration_version, :deployment_duration_in_minutes, :growth_type, :growth_factor, :final_bake_time_in_minutes, :state, :percentage_complete, :started_at, :completed_at, :version_label, :type) SENSITIVE = [] include Aws::Structure end |
#percentage_complete ⇒ Float
The percentage of targets for which the deployment is available.
1529 1530 1531 1532 1533 1534 1535 1536 1537 1538 1539 1540 1541 1542 1543 1544 1545 1546 |
# File 'lib/aws-sdk-appconfig/types.rb', line 1529 class DeploymentSummary < Struct.new( :deployment_number, :configuration_profile_id, :configuration_name, :configuration_version, :deployment_duration_in_minutes, :growth_type, :growth_factor, :final_bake_time_in_minutes, :state, :percentage_complete, :started_at, :completed_at, :version_label, :type) SENSITIVE = [] include Aws::Structure end |
#started_at ⇒ Time
Time the deployment started.
1529 1530 1531 1532 1533 1534 1535 1536 1537 1538 1539 1540 1541 1542 1543 1544 1545 1546 |
# File 'lib/aws-sdk-appconfig/types.rb', line 1529 class DeploymentSummary < Struct.new( :deployment_number, :configuration_profile_id, :configuration_name, :configuration_version, :deployment_duration_in_minutes, :growth_type, :growth_factor, :final_bake_time_in_minutes, :state, :percentage_complete, :started_at, :completed_at, :version_label, :type) SENSITIVE = [] include Aws::Structure end |
#state ⇒ String
The state of the deployment.
1529 1530 1531 1532 1533 1534 1535 1536 1537 1538 1539 1540 1541 1542 1543 1544 1545 1546 |
# File 'lib/aws-sdk-appconfig/types.rb', line 1529 class DeploymentSummary < Struct.new( :deployment_number, :configuration_profile_id, :configuration_name, :configuration_version, :deployment_duration_in_minutes, :growth_type, :growth_factor, :final_bake_time_in_minutes, :state, :percentage_complete, :started_at, :completed_at, :version_label, :type) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
The type of deployment.
1529 1530 1531 1532 1533 1534 1535 1536 1537 1538 1539 1540 1541 1542 1543 1544 1545 1546 |
# File 'lib/aws-sdk-appconfig/types.rb', line 1529 class DeploymentSummary < Struct.new( :deployment_number, :configuration_profile_id, :configuration_name, :configuration_version, :deployment_duration_in_minutes, :growth_type, :growth_factor, :final_bake_time_in_minutes, :state, :percentage_complete, :started_at, :completed_at, :version_label, :type) SENSITIVE = [] include Aws::Structure end |
#version_label ⇒ String
A user-defined label for an AppConfig hosted configuration version.
1529 1530 1531 1532 1533 1534 1535 1536 1537 1538 1539 1540 1541 1542 1543 1544 1545 1546 |
# File 'lib/aws-sdk-appconfig/types.rb', line 1529 class DeploymentSummary < Struct.new( :deployment_number, :configuration_profile_id, :configuration_name, :configuration_version, :deployment_duration_in_minutes, :growth_type, :growth_factor, :final_bake_time_in_minutes, :state, :percentage_complete, :started_at, :completed_at, :version_label, :type) SENSITIVE = [] include Aws::Structure end |