Class: Aws::AppConfig::Types::ExperimentDefinition

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-appconfig/types.rb

Overview

Describes an experiment definition, including the target audience, feature flag, treatments, and current status.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#application_idString

The application ID.

Returns:

  • (String)


1697
1698
1699
1700
1701
1702
1703
1704
1705
1706
1707
1708
1709
1710
1711
1712
1713
1714
1715
1716
# File 'lib/aws-sdk-appconfig/types.rb', line 1697

class ExperimentDefinition < Struct.new(
  :application_id,
  :id,
  :name,
  :hypothesis,
  :status,
  :configuration_profile_id,
  :environment_id,
  :flag_key,
  :audience_rule,
  :audience_description,
  :launch_criteria,
  :treatments,
  :control,
  :created_at,
  :updated_at,
  :kms_key_identifier)
  SENSITIVE = []
  include Aws::Structure
end

#audience_descriptionString

A description of the intended audience for the experiment.

Returns:

  • (String)


1697
1698
1699
1700
1701
1702
1703
1704
1705
1706
1707
1708
1709
1710
1711
1712
1713
1714
1715
1716
# File 'lib/aws-sdk-appconfig/types.rb', line 1697

class ExperimentDefinition < Struct.new(
  :application_id,
  :id,
  :name,
  :hypothesis,
  :status,
  :configuration_profile_id,
  :environment_id,
  :flag_key,
  :audience_rule,
  :audience_description,
  :launch_criteria,
  :treatments,
  :control,
  :created_at,
  :updated_at,
  :kms_key_identifier)
  SENSITIVE = []
  include Aws::Structure
end

#audience_ruleString

The rule that defines which users are eligible to be assigned to treatments.

Returns:

  • (String)


1697
1698
1699
1700
1701
1702
1703
1704
1705
1706
1707
1708
1709
1710
1711
1712
1713
1714
1715
1716
# File 'lib/aws-sdk-appconfig/types.rb', line 1697

class ExperimentDefinition < Struct.new(
  :application_id,
  :id,
  :name,
  :hypothesis,
  :status,
  :configuration_profile_id,
  :environment_id,
  :flag_key,
  :audience_rule,
  :audience_description,
  :launch_criteria,
  :treatments,
  :control,
  :created_at,
  :updated_at,
  :kms_key_identifier)
  SENSITIVE = []
  include Aws::Structure
end

#configuration_profile_idString

The configuration profile ID associated with the experiment.

Returns:

  • (String)


1697
1698
1699
1700
1701
1702
1703
1704
1705
1706
1707
1708
1709
1710
1711
1712
1713
1714
1715
1716
# File 'lib/aws-sdk-appconfig/types.rb', line 1697

class ExperimentDefinition < Struct.new(
  :application_id,
  :id,
  :name,
  :hypothesis,
  :status,
  :configuration_profile_id,
  :environment_id,
  :flag_key,
  :audience_rule,
  :audience_description,
  :launch_criteria,
  :treatments,
  :control,
  :created_at,
  :updated_at,
  :kms_key_identifier)
  SENSITIVE = []
  include Aws::Structure
end

#controlTypes::Treatment

The control treatment used as the baseline for comparison.

Returns:



1697
1698
1699
1700
1701
1702
1703
1704
1705
1706
1707
1708
1709
1710
1711
1712
1713
1714
1715
1716
# File 'lib/aws-sdk-appconfig/types.rb', line 1697

class ExperimentDefinition < Struct.new(
  :application_id,
  :id,
  :name,
  :hypothesis,
  :status,
  :configuration_profile_id,
  :environment_id,
  :flag_key,
  :audience_rule,
  :audience_description,
  :launch_criteria,
  :treatments,
  :control,
  :created_at,
  :updated_at,
  :kms_key_identifier)
  SENSITIVE = []
  include Aws::Structure
end

#created_atTime

The date and time the experiment definition was created, in ISO 8601 format.

Returns:

  • (Time)


1697
1698
1699
1700
1701
1702
1703
1704
1705
1706
1707
1708
1709
1710
1711
1712
1713
1714
1715
1716
# File 'lib/aws-sdk-appconfig/types.rb', line 1697

class ExperimentDefinition < Struct.new(
  :application_id,
  :id,
  :name,
  :hypothesis,
  :status,
  :configuration_profile_id,
  :environment_id,
  :flag_key,
  :audience_rule,
  :audience_description,
  :launch_criteria,
  :treatments,
  :control,
  :created_at,
  :updated_at,
  :kms_key_identifier)
  SENSITIVE = []
  include Aws::Structure
end

#environment_idString

The environment ID where the experiment runs.

Returns:

  • (String)


1697
1698
1699
1700
1701
1702
1703
1704
1705
1706
1707
1708
1709
1710
1711
1712
1713
1714
1715
1716
# File 'lib/aws-sdk-appconfig/types.rb', line 1697

class ExperimentDefinition < Struct.new(
  :application_id,
  :id,
  :name,
  :hypothesis,
  :status,
  :configuration_profile_id,
  :environment_id,
  :flag_key,
  :audience_rule,
  :audience_description,
  :launch_criteria,
  :treatments,
  :control,
  :created_at,
  :updated_at,
  :kms_key_identifier)
  SENSITIVE = []
  include Aws::Structure
end

#flag_keyString

The key of the feature flag used by the experiment.

Returns:

  • (String)


1697
1698
1699
1700
1701
1702
1703
1704
1705
1706
1707
1708
1709
1710
1711
1712
1713
1714
1715
1716
# File 'lib/aws-sdk-appconfig/types.rb', line 1697

class ExperimentDefinition < Struct.new(
  :application_id,
  :id,
  :name,
  :hypothesis,
  :status,
  :configuration_profile_id,
  :environment_id,
  :flag_key,
  :audience_rule,
  :audience_description,
  :launch_criteria,
  :treatments,
  :control,
  :created_at,
  :updated_at,
  :kms_key_identifier)
  SENSITIVE = []
  include Aws::Structure
end

#hypothesisString

The hypothesis that the experiment is designed to validate.

Returns:

  • (String)


1697
1698
1699
1700
1701
1702
1703
1704
1705
1706
1707
1708
1709
1710
1711
1712
1713
1714
1715
1716
# File 'lib/aws-sdk-appconfig/types.rb', line 1697

class ExperimentDefinition < Struct.new(
  :application_id,
  :id,
  :name,
  :hypothesis,
  :status,
  :configuration_profile_id,
  :environment_id,
  :flag_key,
  :audience_rule,
  :audience_description,
  :launch_criteria,
  :treatments,
  :control,
  :created_at,
  :updated_at,
  :kms_key_identifier)
  SENSITIVE = []
  include Aws::Structure
end

#idString

The experiment definition ID.

Returns:

  • (String)


1697
1698
1699
1700
1701
1702
1703
1704
1705
1706
1707
1708
1709
1710
1711
1712
1713
1714
1715
1716
# File 'lib/aws-sdk-appconfig/types.rb', line 1697

class ExperimentDefinition < Struct.new(
  :application_id,
  :id,
  :name,
  :hypothesis,
  :status,
  :configuration_profile_id,
  :environment_id,
  :flag_key,
  :audience_rule,
  :audience_description,
  :launch_criteria,
  :treatments,
  :control,
  :created_at,
  :updated_at,
  :kms_key_identifier)
  SENSITIVE = []
  include Aws::Structure
end

#kms_key_identifierString

The Amazon Resource Name (ARN) of the KMS key used to encrypt experiment data.

Returns:

  • (String)


1697
1698
1699
1700
1701
1702
1703
1704
1705
1706
1707
1708
1709
1710
1711
1712
1713
1714
1715
1716
# File 'lib/aws-sdk-appconfig/types.rb', line 1697

class ExperimentDefinition < Struct.new(
  :application_id,
  :id,
  :name,
  :hypothesis,
  :status,
  :configuration_profile_id,
  :environment_id,
  :flag_key,
  :audience_rule,
  :audience_description,
  :launch_criteria,
  :treatments,
  :control,
  :created_at,
  :updated_at,
  :kms_key_identifier)
  SENSITIVE = []
  include Aws::Structure
end

#launch_criteriaString

The conditions under which the winning treatment should be launched.

Returns:

  • (String)


1697
1698
1699
1700
1701
1702
1703
1704
1705
1706
1707
1708
1709
1710
1711
1712
1713
1714
1715
1716
# File 'lib/aws-sdk-appconfig/types.rb', line 1697

class ExperimentDefinition < Struct.new(
  :application_id,
  :id,
  :name,
  :hypothesis,
  :status,
  :configuration_profile_id,
  :environment_id,
  :flag_key,
  :audience_rule,
  :audience_description,
  :launch_criteria,
  :treatments,
  :control,
  :created_at,
  :updated_at,
  :kms_key_identifier)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the experiment definition.

Returns:

  • (String)


1697
1698
1699
1700
1701
1702
1703
1704
1705
1706
1707
1708
1709
1710
1711
1712
1713
1714
1715
1716
# File 'lib/aws-sdk-appconfig/types.rb', line 1697

class ExperimentDefinition < Struct.new(
  :application_id,
  :id,
  :name,
  :hypothesis,
  :status,
  :configuration_profile_id,
  :environment_id,
  :flag_key,
  :audience_rule,
  :audience_description,
  :launch_criteria,
  :treatments,
  :control,
  :created_at,
  :updated_at,
  :kms_key_identifier)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The current status of the experiment definition. Valid values: ACTIVE, IDLE, ARCHIVED.

Returns:

  • (String)


1697
1698
1699
1700
1701
1702
1703
1704
1705
1706
1707
1708
1709
1710
1711
1712
1713
1714
1715
1716
# File 'lib/aws-sdk-appconfig/types.rb', line 1697

class ExperimentDefinition < Struct.new(
  :application_id,
  :id,
  :name,
  :hypothesis,
  :status,
  :configuration_profile_id,
  :environment_id,
  :flag_key,
  :audience_rule,
  :audience_description,
  :launch_criteria,
  :treatments,
  :control,
  :created_at,
  :updated_at,
  :kms_key_identifier)
  SENSITIVE = []
  include Aws::Structure
end

#treatmentsArray<Types::Treatment>

The list of treatments defined for the experiment.

Returns:



1697
1698
1699
1700
1701
1702
1703
1704
1705
1706
1707
1708
1709
1710
1711
1712
1713
1714
1715
1716
# File 'lib/aws-sdk-appconfig/types.rb', line 1697

class ExperimentDefinition < Struct.new(
  :application_id,
  :id,
  :name,
  :hypothesis,
  :status,
  :configuration_profile_id,
  :environment_id,
  :flag_key,
  :audience_rule,
  :audience_description,
  :launch_criteria,
  :treatments,
  :control,
  :created_at,
  :updated_at,
  :kms_key_identifier)
  SENSITIVE = []
  include Aws::Structure
end

#updated_atTime

The date and time the experiment definition was last updated, in ISO 8601 format.

Returns:

  • (Time)


1697
1698
1699
1700
1701
1702
1703
1704
1705
1706
1707
1708
1709
1710
1711
1712
1713
1714
1715
1716
# File 'lib/aws-sdk-appconfig/types.rb', line 1697

class ExperimentDefinition < Struct.new(
  :application_id,
  :id,
  :name,
  :hypothesis,
  :status,
  :configuration_profile_id,
  :environment_id,
  :flag_key,
  :audience_rule,
  :audience_description,
  :launch_criteria,
  :treatments,
  :control,
  :created_at,
  :updated_at,
  :kms_key_identifier)
  SENSITIVE = []
  include Aws::Structure
end