Class: Aws::AppConfig::Types::ExperimentDefinitionSnapshot

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-appconfig/types.rb

Overview

A snapshot of the experiment definition captured at the time an experiment run was started. This preserves the configuration that was active during the run.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#application_idString

The application ID at the time the run was started.

Returns:

  • (String)


1773
1774
1775
1776
1777
1778
1779
1780
1781
1782
1783
1784
1785
1786
1787
1788
# File 'lib/aws-sdk-appconfig/types.rb', line 1773

class ExperimentDefinitionSnapshot < Struct.new(
  :application_id,
  :id,
  :name,
  :hypothesis,
  :configuration_profile_id,
  :environment_id,
  :flag_key,
  :audience_rule,
  :audience_description,
  :launch_criteria,
  :treatments,
  :control)
  SENSITIVE = []
  include Aws::Structure
end

#audience_descriptionString

The audience description at the time the run was started.

Returns:

  • (String)


1773
1774
1775
1776
1777
1778
1779
1780
1781
1782
1783
1784
1785
1786
1787
1788
# File 'lib/aws-sdk-appconfig/types.rb', line 1773

class ExperimentDefinitionSnapshot < Struct.new(
  :application_id,
  :id,
  :name,
  :hypothesis,
  :configuration_profile_id,
  :environment_id,
  :flag_key,
  :audience_rule,
  :audience_description,
  :launch_criteria,
  :treatments,
  :control)
  SENSITIVE = []
  include Aws::Structure
end

#audience_ruleString

The audience rule at the time the run was started.

Returns:

  • (String)


1773
1774
1775
1776
1777
1778
1779
1780
1781
1782
1783
1784
1785
1786
1787
1788
# File 'lib/aws-sdk-appconfig/types.rb', line 1773

class ExperimentDefinitionSnapshot < Struct.new(
  :application_id,
  :id,
  :name,
  :hypothesis,
  :configuration_profile_id,
  :environment_id,
  :flag_key,
  :audience_rule,
  :audience_description,
  :launch_criteria,
  :treatments,
  :control)
  SENSITIVE = []
  include Aws::Structure
end

#configuration_profile_idString

The configuration profile ID at the time the run was started.

Returns:

  • (String)


1773
1774
1775
1776
1777
1778
1779
1780
1781
1782
1783
1784
1785
1786
1787
1788
# File 'lib/aws-sdk-appconfig/types.rb', line 1773

class ExperimentDefinitionSnapshot < Struct.new(
  :application_id,
  :id,
  :name,
  :hypothesis,
  :configuration_profile_id,
  :environment_id,
  :flag_key,
  :audience_rule,
  :audience_description,
  :launch_criteria,
  :treatments,
  :control)
  SENSITIVE = []
  include Aws::Structure
end

#controlTypes::Treatment

The control treatment at the time the run was started.

Returns:



1773
1774
1775
1776
1777
1778
1779
1780
1781
1782
1783
1784
1785
1786
1787
1788
# File 'lib/aws-sdk-appconfig/types.rb', line 1773

class ExperimentDefinitionSnapshot < Struct.new(
  :application_id,
  :id,
  :name,
  :hypothesis,
  :configuration_profile_id,
  :environment_id,
  :flag_key,
  :audience_rule,
  :audience_description,
  :launch_criteria,
  :treatments,
  :control)
  SENSITIVE = []
  include Aws::Structure
end

#environment_idString

The environment ID at the time the run was started.

Returns:

  • (String)


1773
1774
1775
1776
1777
1778
1779
1780
1781
1782
1783
1784
1785
1786
1787
1788
# File 'lib/aws-sdk-appconfig/types.rb', line 1773

class ExperimentDefinitionSnapshot < Struct.new(
  :application_id,
  :id,
  :name,
  :hypothesis,
  :configuration_profile_id,
  :environment_id,
  :flag_key,
  :audience_rule,
  :audience_description,
  :launch_criteria,
  :treatments,
  :control)
  SENSITIVE = []
  include Aws::Structure
end

#flag_keyString

The feature flag key at the time the run was started.

Returns:

  • (String)


1773
1774
1775
1776
1777
1778
1779
1780
1781
1782
1783
1784
1785
1786
1787
1788
# File 'lib/aws-sdk-appconfig/types.rb', line 1773

class ExperimentDefinitionSnapshot < Struct.new(
  :application_id,
  :id,
  :name,
  :hypothesis,
  :configuration_profile_id,
  :environment_id,
  :flag_key,
  :audience_rule,
  :audience_description,
  :launch_criteria,
  :treatments,
  :control)
  SENSITIVE = []
  include Aws::Structure
end

#hypothesisString

The hypothesis at the time the run was started.

Returns:

  • (String)


1773
1774
1775
1776
1777
1778
1779
1780
1781
1782
1783
1784
1785
1786
1787
1788
# File 'lib/aws-sdk-appconfig/types.rb', line 1773

class ExperimentDefinitionSnapshot < Struct.new(
  :application_id,
  :id,
  :name,
  :hypothesis,
  :configuration_profile_id,
  :environment_id,
  :flag_key,
  :audience_rule,
  :audience_description,
  :launch_criteria,
  :treatments,
  :control)
  SENSITIVE = []
  include Aws::Structure
end

#idString

The experiment definition ID.

Returns:

  • (String)


1773
1774
1775
1776
1777
1778
1779
1780
1781
1782
1783
1784
1785
1786
1787
1788
# File 'lib/aws-sdk-appconfig/types.rb', line 1773

class ExperimentDefinitionSnapshot < Struct.new(
  :application_id,
  :id,
  :name,
  :hypothesis,
  :configuration_profile_id,
  :environment_id,
  :flag_key,
  :audience_rule,
  :audience_description,
  :launch_criteria,
  :treatments,
  :control)
  SENSITIVE = []
  include Aws::Structure
end

#launch_criteriaString

The launch criteria at the time the run was started.

Returns:

  • (String)


1773
1774
1775
1776
1777
1778
1779
1780
1781
1782
1783
1784
1785
1786
1787
1788
# File 'lib/aws-sdk-appconfig/types.rb', line 1773

class ExperimentDefinitionSnapshot < Struct.new(
  :application_id,
  :id,
  :name,
  :hypothesis,
  :configuration_profile_id,
  :environment_id,
  :flag_key,
  :audience_rule,
  :audience_description,
  :launch_criteria,
  :treatments,
  :control)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the experiment definition at the time the run was started.

Returns:

  • (String)


1773
1774
1775
1776
1777
1778
1779
1780
1781
1782
1783
1784
1785
1786
1787
1788
# File 'lib/aws-sdk-appconfig/types.rb', line 1773

class ExperimentDefinitionSnapshot < Struct.new(
  :application_id,
  :id,
  :name,
  :hypothesis,
  :configuration_profile_id,
  :environment_id,
  :flag_key,
  :audience_rule,
  :audience_description,
  :launch_criteria,
  :treatments,
  :control)
  SENSITIVE = []
  include Aws::Structure
end

#treatmentsArray<Types::Treatment>

The treatments at the time the run was started.

Returns:



1773
1774
1775
1776
1777
1778
1779
1780
1781
1782
1783
1784
1785
1786
1787
1788
# File 'lib/aws-sdk-appconfig/types.rb', line 1773

class ExperimentDefinitionSnapshot < Struct.new(
  :application_id,
  :id,
  :name,
  :hypothesis,
  :configuration_profile_id,
  :environment_id,
  :flag_key,
  :audience_rule,
  :audience_description,
  :launch_criteria,
  :treatments,
  :control)
  SENSITIVE = []
  include Aws::Structure
end