Class: Aws::AppConfig::Types::ExperimentDefinitionSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::AppConfig::Types::ExperimentDefinitionSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-appconfig/types.rb
Overview
Summary information about an experiment definition.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#application_id ⇒ String
The application ID.
-
#configuration_profile_id ⇒ String
The configuration profile ID associated with the experiment.
-
#created_at ⇒ Time
The date and time the experiment definition was created, in ISO 8601 format.
-
#environment_id ⇒ String
The environment ID where the experiment runs.
-
#flag_key ⇒ String
The key of the feature flag used by the experiment.
-
#hypothesis ⇒ String
The hypothesis that the experiment is designed to validate.
-
#id ⇒ String
The experiment definition ID.
-
#name ⇒ String
The name of the experiment definition.
-
#status ⇒ String
The current status of the experiment definition.
-
#updated_at ⇒ Time
The date and time the experiment definition was last updated, in ISO 8601 format.
Instance Attribute Details
#application_id ⇒ String
The application ID.
1836 1837 1838 1839 1840 1841 1842 1843 1844 1845 1846 1847 1848 1849 |
# File 'lib/aws-sdk-appconfig/types.rb', line 1836 class ExperimentDefinitionSummary < Struct.new( :application_id, :id, :name, :hypothesis, :status, :configuration_profile_id, :environment_id, :flag_key, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#configuration_profile_id ⇒ String
The configuration profile ID associated with the experiment.
1836 1837 1838 1839 1840 1841 1842 1843 1844 1845 1846 1847 1848 1849 |
# File 'lib/aws-sdk-appconfig/types.rb', line 1836 class ExperimentDefinitionSummary < Struct.new( :application_id, :id, :name, :hypothesis, :status, :configuration_profile_id, :environment_id, :flag_key, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Time
The date and time the experiment definition was created, in ISO 8601 format.
1836 1837 1838 1839 1840 1841 1842 1843 1844 1845 1846 1847 1848 1849 |
# File 'lib/aws-sdk-appconfig/types.rb', line 1836 class ExperimentDefinitionSummary < Struct.new( :application_id, :id, :name, :hypothesis, :status, :configuration_profile_id, :environment_id, :flag_key, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#environment_id ⇒ String
The environment ID where the experiment runs.
1836 1837 1838 1839 1840 1841 1842 1843 1844 1845 1846 1847 1848 1849 |
# File 'lib/aws-sdk-appconfig/types.rb', line 1836 class ExperimentDefinitionSummary < Struct.new( :application_id, :id, :name, :hypothesis, :status, :configuration_profile_id, :environment_id, :flag_key, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#flag_key ⇒ String
The key of the feature flag used by the experiment.
1836 1837 1838 1839 1840 1841 1842 1843 1844 1845 1846 1847 1848 1849 |
# File 'lib/aws-sdk-appconfig/types.rb', line 1836 class ExperimentDefinitionSummary < Struct.new( :application_id, :id, :name, :hypothesis, :status, :configuration_profile_id, :environment_id, :flag_key, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#hypothesis ⇒ String
The hypothesis that the experiment is designed to validate.
1836 1837 1838 1839 1840 1841 1842 1843 1844 1845 1846 1847 1848 1849 |
# File 'lib/aws-sdk-appconfig/types.rb', line 1836 class ExperimentDefinitionSummary < Struct.new( :application_id, :id, :name, :hypothesis, :status, :configuration_profile_id, :environment_id, :flag_key, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The experiment definition ID.
1836 1837 1838 1839 1840 1841 1842 1843 1844 1845 1846 1847 1848 1849 |
# File 'lib/aws-sdk-appconfig/types.rb', line 1836 class ExperimentDefinitionSummary < Struct.new( :application_id, :id, :name, :hypothesis, :status, :configuration_profile_id, :environment_id, :flag_key, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the experiment definition.
1836 1837 1838 1839 1840 1841 1842 1843 1844 1845 1846 1847 1848 1849 |
# File 'lib/aws-sdk-appconfig/types.rb', line 1836 class ExperimentDefinitionSummary < Struct.new( :application_id, :id, :name, :hypothesis, :status, :configuration_profile_id, :environment_id, :flag_key, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The current status of the experiment definition.
1836 1837 1838 1839 1840 1841 1842 1843 1844 1845 1846 1847 1848 1849 |
# File 'lib/aws-sdk-appconfig/types.rb', line 1836 class ExperimentDefinitionSummary < Struct.new( :application_id, :id, :name, :hypothesis, :status, :configuration_profile_id, :environment_id, :flag_key, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#updated_at ⇒ Time
The date and time the experiment definition was last updated, in ISO 8601 format.
1836 1837 1838 1839 1840 1841 1842 1843 1844 1845 1846 1847 1848 1849 |
# File 'lib/aws-sdk-appconfig/types.rb', line 1836 class ExperimentDefinitionSummary < Struct.new( :application_id, :id, :name, :hypothesis, :status, :configuration_profile_id, :environment_id, :flag_key, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |