Class: Aws::AppConfig::Types::ExperimentDefinitions
- Inherits:
-
Struct
- Object
- Struct
- Aws::AppConfig::Types::ExperimentDefinitions
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-appconfig/types.rb
Overview
The response for a list experiment definitions request.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#items ⇒ Array<Types::ExperimentDefinitionSummary>
The list of experiment definitions.
-
#next_token ⇒ String
A token to use for the next set of results.
Instance Attribute Details
#items ⇒ Array<Types::ExperimentDefinitionSummary>
The list of experiment definitions.
1863 1864 1865 1866 1867 1868 |
# File 'lib/aws-sdk-appconfig/types.rb', line 1863 class ExperimentDefinitions < Struct.new( :items, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
A token to use for the next set of results.
1863 1864 1865 1866 1867 1868 |
# File 'lib/aws-sdk-appconfig/types.rb', line 1863 class ExperimentDefinitions < Struct.new( :items, :next_token) SENSITIVE = [] include Aws::Structure end |