Class: Aws::AppConfig::Types::ExperimentRun

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-appconfig/types.rb

Overview

Describes an experiment run, including its status, exposure settings, and treatment overrides.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#application_idString

The application ID.

Returns:

  • (String)


1928
1929
1930
1931
1932
1933
1934
1935
1936
1937
1938
1939
1940
1941
1942
1943
# File 'lib/aws-sdk-appconfig/types.rb', line 1928

class ExperimentRun < Struct.new(
  :application_id,
  :experiment_definition_id,
  :run,
  :description,
  :status,
  :exposure_percentage,
  :treatment_overrides,
  :result,
  :started_at,
  :updated_at,
  :ended_at,
  :experiment_definition_snapshot)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

A description of the experiment run.

Returns:

  • (String)


1928
1929
1930
1931
1932
1933
1934
1935
1936
1937
1938
1939
1940
1941
1942
1943
# File 'lib/aws-sdk-appconfig/types.rb', line 1928

class ExperimentRun < Struct.new(
  :application_id,
  :experiment_definition_id,
  :run,
  :description,
  :status,
  :exposure_percentage,
  :treatment_overrides,
  :result,
  :started_at,
  :updated_at,
  :ended_at,
  :experiment_definition_snapshot)
  SENSITIVE = []
  include Aws::Structure
end

#ended_atTime

The date and time the experiment run ended, in ISO 8601 format.

Returns:

  • (Time)


1928
1929
1930
1931
1932
1933
1934
1935
1936
1937
1938
1939
1940
1941
1942
1943
# File 'lib/aws-sdk-appconfig/types.rb', line 1928

class ExperimentRun < Struct.new(
  :application_id,
  :experiment_definition_id,
  :run,
  :description,
  :status,
  :exposure_percentage,
  :treatment_overrides,
  :result,
  :started_at,
  :updated_at,
  :ended_at,
  :experiment_definition_snapshot)
  SENSITIVE = []
  include Aws::Structure
end

#experiment_definition_idString

The experiment definition ID.

Returns:

  • (String)


1928
1929
1930
1931
1932
1933
1934
1935
1936
1937
1938
1939
1940
1941
1942
1943
# File 'lib/aws-sdk-appconfig/types.rb', line 1928

class ExperimentRun < Struct.new(
  :application_id,
  :experiment_definition_id,
  :run,
  :description,
  :status,
  :exposure_percentage,
  :treatment_overrides,
  :result,
  :started_at,
  :updated_at,
  :ended_at,
  :experiment_definition_snapshot)
  SENSITIVE = []
  include Aws::Structure
end

#experiment_definition_snapshotTypes::ExperimentDefinitionSnapshot

A snapshot of the experiment definition at the time the run was started.



1928
1929
1930
1931
1932
1933
1934
1935
1936
1937
1938
1939
1940
1941
1942
1943
# File 'lib/aws-sdk-appconfig/types.rb', line 1928

class ExperimentRun < Struct.new(
  :application_id,
  :experiment_definition_id,
  :run,
  :description,
  :status,
  :exposure_percentage,
  :treatment_overrides,
  :result,
  :started_at,
  :updated_at,
  :ended_at,
  :experiment_definition_snapshot)
  SENSITIVE = []
  include Aws::Structure
end

#exposure_percentageFloat

The percentage of the target audience exposed to treatments.

Returns:

  • (Float)


1928
1929
1930
1931
1932
1933
1934
1935
1936
1937
1938
1939
1940
1941
1942
1943
# File 'lib/aws-sdk-appconfig/types.rb', line 1928

class ExperimentRun < Struct.new(
  :application_id,
  :experiment_definition_id,
  :run,
  :description,
  :status,
  :exposure_percentage,
  :treatment_overrides,
  :result,
  :started_at,
  :updated_at,
  :ended_at,
  :experiment_definition_snapshot)
  SENSITIVE = []
  include Aws::Structure
end

#resultTypes::ExperimentRunResult

The result of the experiment run, including the executive summary and launch decision rationale.



1928
1929
1930
1931
1932
1933
1934
1935
1936
1937
1938
1939
1940
1941
1942
1943
# File 'lib/aws-sdk-appconfig/types.rb', line 1928

class ExperimentRun < Struct.new(
  :application_id,
  :experiment_definition_id,
  :run,
  :description,
  :status,
  :exposure_percentage,
  :treatment_overrides,
  :result,
  :started_at,
  :updated_at,
  :ended_at,
  :experiment_definition_snapshot)
  SENSITIVE = []
  include Aws::Structure
end

#runInteger

The experiment run number.

Returns:

  • (Integer)


1928
1929
1930
1931
1932
1933
1934
1935
1936
1937
1938
1939
1940
1941
1942
1943
# File 'lib/aws-sdk-appconfig/types.rb', line 1928

class ExperimentRun < Struct.new(
  :application_id,
  :experiment_definition_id,
  :run,
  :description,
  :status,
  :exposure_percentage,
  :treatment_overrides,
  :result,
  :started_at,
  :updated_at,
  :ended_at,
  :experiment_definition_snapshot)
  SENSITIVE = []
  include Aws::Structure
end

#started_atTime

The date and time the experiment run started, in ISO 8601 format.

Returns:

  • (Time)


1928
1929
1930
1931
1932
1933
1934
1935
1936
1937
1938
1939
1940
1941
1942
1943
# File 'lib/aws-sdk-appconfig/types.rb', line 1928

class ExperimentRun < Struct.new(
  :application_id,
  :experiment_definition_id,
  :run,
  :description,
  :status,
  :exposure_percentage,
  :treatment_overrides,
  :result,
  :started_at,
  :updated_at,
  :ended_at,
  :experiment_definition_snapshot)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The current status of the experiment run. Valid values: RUNNING, DONE.

Returns:

  • (String)


1928
1929
1930
1931
1932
1933
1934
1935
1936
1937
1938
1939
1940
1941
1942
1943
# File 'lib/aws-sdk-appconfig/types.rb', line 1928

class ExperimentRun < Struct.new(
  :application_id,
  :experiment_definition_id,
  :run,
  :description,
  :status,
  :exposure_percentage,
  :treatment_overrides,
  :result,
  :started_at,
  :updated_at,
  :ended_at,
  :experiment_definition_snapshot)
  SENSITIVE = []
  include Aws::Structure
end

#treatment_overridesTypes::TreatmentOverrides

Treatment assignment overrides that assign specific entity IDs to treatments.



1928
1929
1930
1931
1932
1933
1934
1935
1936
1937
1938
1939
1940
1941
1942
1943
# File 'lib/aws-sdk-appconfig/types.rb', line 1928

class ExperimentRun < Struct.new(
  :application_id,
  :experiment_definition_id,
  :run,
  :description,
  :status,
  :exposure_percentage,
  :treatment_overrides,
  :result,
  :started_at,
  :updated_at,
  :ended_at,
  :experiment_definition_snapshot)
  SENSITIVE = []
  include Aws::Structure
end

#updated_atTime

The date and time the experiment run was last updated, in ISO 8601 format.

Returns:

  • (Time)


1928
1929
1930
1931
1932
1933
1934
1935
1936
1937
1938
1939
1940
1941
1942
1943
# File 'lib/aws-sdk-appconfig/types.rb', line 1928

class ExperimentRun < Struct.new(
  :application_id,
  :experiment_definition_id,
  :run,
  :description,
  :status,
  :exposure_percentage,
  :treatment_overrides,
  :result,
  :started_at,
  :updated_at,
  :ended_at,
  :experiment_definition_snapshot)
  SENSITIVE = []
  include Aws::Structure
end