Class: Aws::AppConfig::Types::ExperimentRunEvent

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-appconfig/types.rb

Overview

Describes an event that occurred during an experiment run.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#associated_deploymentString

The Amazon Resource Name (ARN) of the deployment associated with this event.

Returns:

  • (String)


1979
1980
1981
1982
1983
1984
1985
1986
1987
1988
1989
# File 'lib/aws-sdk-appconfig/types.rb', line 1979

class ExperimentRunEvent < Struct.new(
  :description,
  :associated_deployment,
  :event_type,
  :occurred_at,
  :triggered_by,
  :exposure_percentage,
  :treatment_overrides)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

A description of the event.

Returns:

  • (String)


1979
1980
1981
1982
1983
1984
1985
1986
1987
1988
1989
# File 'lib/aws-sdk-appconfig/types.rb', line 1979

class ExperimentRunEvent < Struct.new(
  :description,
  :associated_deployment,
  :event_type,
  :occurred_at,
  :triggered_by,
  :exposure_percentage,
  :treatment_overrides)
  SENSITIVE = []
  include Aws::Structure
end

#event_typeString

The type of event. Valid values: RUN_STARTED, EXPOSURE_UPDATED, OVERRIDES_UPDATED, RUN_STOPPED.

Returns:

  • (String)


1979
1980
1981
1982
1983
1984
1985
1986
1987
1988
1989
# File 'lib/aws-sdk-appconfig/types.rb', line 1979

class ExperimentRunEvent < Struct.new(
  :description,
  :associated_deployment,
  :event_type,
  :occurred_at,
  :triggered_by,
  :exposure_percentage,
  :treatment_overrides)
  SENSITIVE = []
  include Aws::Structure
end

#exposure_percentageFloat

The exposure percentage at the time of the event.

Returns:

  • (Float)


1979
1980
1981
1982
1983
1984
1985
1986
1987
1988
1989
# File 'lib/aws-sdk-appconfig/types.rb', line 1979

class ExperimentRunEvent < Struct.new(
  :description,
  :associated_deployment,
  :event_type,
  :occurred_at,
  :triggered_by,
  :exposure_percentage,
  :treatment_overrides)
  SENSITIVE = []
  include Aws::Structure
end

#occurred_atTime

The date and time the event occurred, in ISO 8601 format.

Returns:

  • (Time)


1979
1980
1981
1982
1983
1984
1985
1986
1987
1988
1989
# File 'lib/aws-sdk-appconfig/types.rb', line 1979

class ExperimentRunEvent < Struct.new(
  :description,
  :associated_deployment,
  :event_type,
  :occurred_at,
  :triggered_by,
  :exposure_percentage,
  :treatment_overrides)
  SENSITIVE = []
  include Aws::Structure
end

#treatment_overridesTypes::TreatmentOverrides

The treatment overrides at the time of the event.



1979
1980
1981
1982
1983
1984
1985
1986
1987
1988
1989
# File 'lib/aws-sdk-appconfig/types.rb', line 1979

class ExperimentRunEvent < Struct.new(
  :description,
  :associated_deployment,
  :event_type,
  :occurred_at,
  :triggered_by,
  :exposure_percentage,
  :treatment_overrides)
  SENSITIVE = []
  include Aws::Structure
end

#triggered_byString

The principal that triggered the event.

Returns:

  • (String)


1979
1980
1981
1982
1983
1984
1985
1986
1987
1988
1989
# File 'lib/aws-sdk-appconfig/types.rb', line 1979

class ExperimentRunEvent < Struct.new(
  :description,
  :associated_deployment,
  :event_type,
  :occurred_at,
  :triggered_by,
  :exposure_percentage,
  :treatment_overrides)
  SENSITIVE = []
  include Aws::Structure
end