Class: Aws::AppConfig::Types::ExperimentRunResult

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-appconfig/types.rb

Overview

The result of an experiment run, including the executive summary and launch decision rationale.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#executive_summaryString

A summary of the experiment outcome and key findings.

Returns:

  • (String)


2027
2028
2029
2030
2031
2032
2033
# File 'lib/aws-sdk-appconfig/types.rb', line 2027

class ExperimentRunResult < Struct.new(
  :executive_summary,
  :reasons_to_launch,
  :reasons_not_to_launch)
  SENSITIVE = []
  include Aws::Structure
end

#reasons_not_to_launchString

Evidence against launching the treatment.

Returns:

  • (String)


2027
2028
2029
2030
2031
2032
2033
# File 'lib/aws-sdk-appconfig/types.rb', line 2027

class ExperimentRunResult < Struct.new(
  :executive_summary,
  :reasons_to_launch,
  :reasons_not_to_launch)
  SENSITIVE = []
  include Aws::Structure
end

#reasons_to_launchString

Evidence in favor of launching the winning treatment.

Returns:

  • (String)


2027
2028
2029
2030
2031
2032
2033
# File 'lib/aws-sdk-appconfig/types.rb', line 2027

class ExperimentRunResult < Struct.new(
  :executive_summary,
  :reasons_to_launch,
  :reasons_not_to_launch)
  SENSITIVE = []
  include Aws::Structure
end