Class: Aws::AppConfig::Types::ExperimentRunSummary

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-appconfig/types.rb

Overview

Summary information about an experiment run.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#descriptionString

A description of the experiment run.

Returns:

  • (String)


2068
2069
2070
2071
2072
2073
2074
2075
2076
2077
2078
# File 'lib/aws-sdk-appconfig/types.rb', line 2068

class ExperimentRunSummary < Struct.new(
  :experiment_definition_id,
  :run,
  :description,
  :status,
  :started_at,
  :updated_at,
  :ended_at)
  SENSITIVE = []
  include Aws::Structure
end

#ended_atTime

The date and time the experiment run ended, in ISO 8601 format.

Returns:

  • (Time)


2068
2069
2070
2071
2072
2073
2074
2075
2076
2077
2078
# File 'lib/aws-sdk-appconfig/types.rb', line 2068

class ExperimentRunSummary < Struct.new(
  :experiment_definition_id,
  :run,
  :description,
  :status,
  :started_at,
  :updated_at,
  :ended_at)
  SENSITIVE = []
  include Aws::Structure
end

#experiment_definition_idString

The experiment definition ID.

Returns:

  • (String)


2068
2069
2070
2071
2072
2073
2074
2075
2076
2077
2078
# File 'lib/aws-sdk-appconfig/types.rb', line 2068

class ExperimentRunSummary < Struct.new(
  :experiment_definition_id,
  :run,
  :description,
  :status,
  :started_at,
  :updated_at,
  :ended_at)
  SENSITIVE = []
  include Aws::Structure
end

#runInteger

The experiment run number.

Returns:

  • (Integer)


2068
2069
2070
2071
2072
2073
2074
2075
2076
2077
2078
# File 'lib/aws-sdk-appconfig/types.rb', line 2068

class ExperimentRunSummary < Struct.new(
  :experiment_definition_id,
  :run,
  :description,
  :status,
  :started_at,
  :updated_at,
  :ended_at)
  SENSITIVE = []
  include Aws::Structure
end

#started_atTime

The date and time the experiment run started, in ISO 8601 format.

Returns:

  • (Time)


2068
2069
2070
2071
2072
2073
2074
2075
2076
2077
2078
# File 'lib/aws-sdk-appconfig/types.rb', line 2068

class ExperimentRunSummary < Struct.new(
  :experiment_definition_id,
  :run,
  :description,
  :status,
  :started_at,
  :updated_at,
  :ended_at)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The current status of the experiment run.

Returns:

  • (String)


2068
2069
2070
2071
2072
2073
2074
2075
2076
2077
2078
# File 'lib/aws-sdk-appconfig/types.rb', line 2068

class ExperimentRunSummary < Struct.new(
  :experiment_definition_id,
  :run,
  :description,
  :status,
  :started_at,
  :updated_at,
  :ended_at)
  SENSITIVE = []
  include Aws::Structure
end

#updated_atTime

The date and time the experiment run was last updated, in ISO 8601 format.

Returns:

  • (Time)


2068
2069
2070
2071
2072
2073
2074
2075
2076
2077
2078
# File 'lib/aws-sdk-appconfig/types.rb', line 2068

class ExperimentRunSummary < Struct.new(
  :experiment_definition_id,
  :run,
  :description,
  :status,
  :started_at,
  :updated_at,
  :ended_at)
  SENSITIVE = []
  include Aws::Structure
end