Class: Aws::AppConfig::Types::ExperimentRuns
- Inherits:
-
Struct
- Object
- Struct
- Aws::AppConfig::Types::ExperimentRuns
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-appconfig/types.rb
Overview
The response for a list experiment runs request.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#items ⇒ Array<Types::ExperimentRunSummary>
The list of experiment runs.
-
#next_token ⇒ String
A token to use for the next set of results.
Instance Attribute Details
#items ⇒ Array<Types::ExperimentRunSummary>
The list of experiment runs.
2092 2093 2094 2095 2096 2097 |
# File 'lib/aws-sdk-appconfig/types.rb', line 2092 class ExperimentRuns < Struct.new( :items, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
A token to use for the next set of results.
2092 2093 2094 2095 2096 2097 |
# File 'lib/aws-sdk-appconfig/types.rb', line 2092 class ExperimentRuns < Struct.new( :items, :next_token) SENSITIVE = [] include Aws::Structure end |