Class: Aws::AppConfig::Types::Extension

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-appconfig/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#actionsHash<String,Array<Types::Action>>

The actions defined in the extension.

Returns:



2133
2134
2135
2136
2137
2138
2139
2140
2141
2142
2143
# File 'lib/aws-sdk-appconfig/types.rb', line 2133

class Extension < Struct.new(
  :id,
  :name,
  :version_number,
  :arn,
  :description,
  :actions,
  :parameters)
  SENSITIVE = []
  include Aws::Structure
end

#arnString

The system-generated Amazon Resource Name (ARN) for the extension.

Returns:

  • (String)


2133
2134
2135
2136
2137
2138
2139
2140
2141
2142
2143
# File 'lib/aws-sdk-appconfig/types.rb', line 2133

class Extension < Struct.new(
  :id,
  :name,
  :version_number,
  :arn,
  :description,
  :actions,
  :parameters)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

Information about the extension.

Returns:

  • (String)


2133
2134
2135
2136
2137
2138
2139
2140
2141
2142
2143
# File 'lib/aws-sdk-appconfig/types.rb', line 2133

class Extension < Struct.new(
  :id,
  :name,
  :version_number,
  :arn,
  :description,
  :actions,
  :parameters)
  SENSITIVE = []
  include Aws::Structure
end

#idString

The system-generated ID of the extension.

Returns:

  • (String)


2133
2134
2135
2136
2137
2138
2139
2140
2141
2142
2143
# File 'lib/aws-sdk-appconfig/types.rb', line 2133

class Extension < Struct.new(
  :id,
  :name,
  :version_number,
  :arn,
  :description,
  :actions,
  :parameters)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The extension name.

Returns:

  • (String)


2133
2134
2135
2136
2137
2138
2139
2140
2141
2142
2143
# File 'lib/aws-sdk-appconfig/types.rb', line 2133

class Extension < Struct.new(
  :id,
  :name,
  :version_number,
  :arn,
  :description,
  :actions,
  :parameters)
  SENSITIVE = []
  include Aws::Structure
end

#parametersHash<String,Types::Parameter>

The parameters accepted by the extension. You specify parameter values when you associate the extension to an AppConfig resource by using the CreateExtensionAssociation API action. For Lambda extension actions, these parameters are included in the Lambda request object.

Returns:



2133
2134
2135
2136
2137
2138
2139
2140
2141
2142
2143
# File 'lib/aws-sdk-appconfig/types.rb', line 2133

class Extension < Struct.new(
  :id,
  :name,
  :version_number,
  :arn,
  :description,
  :actions,
  :parameters)
  SENSITIVE = []
  include Aws::Structure
end

#version_numberInteger

The extension version number.

Returns:

  • (Integer)


2133
2134
2135
2136
2137
2138
2139
2140
2141
2142
2143
# File 'lib/aws-sdk-appconfig/types.rb', line 2133

class Extension < Struct.new(
  :id,
  :name,
  :version_number,
  :arn,
  :description,
  :actions,
  :parameters)
  SENSITIVE = []
  include Aws::Structure
end