Class: Aws::AppConfig::Types::ExtensionAssociationSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::AppConfig::Types::ExtensionAssociationSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-appconfig/types.rb
Overview
Information about an association between an extension and an AppConfig
resource such as an application, environment, or configuration
profile. Call GetExtensionAssociation to get more information about
an association.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#extension_arn ⇒ String
The system-generated Amazon Resource Name (ARN) for the extension.
-
#id ⇒ String
The extension association ID.
-
#resource_arn ⇒ String
The ARNs of applications, configuration profiles, or environments defined in the association.
Instance Attribute Details
#extension_arn ⇒ String
The system-generated Amazon Resource Name (ARN) for the extension.
2205 2206 2207 2208 2209 2210 2211 |
# File 'lib/aws-sdk-appconfig/types.rb', line 2205 class ExtensionAssociationSummary < Struct.new( :id, :extension_arn, :resource_arn) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The extension association ID. This ID is used to call other
ExtensionAssociation API actions such as GetExtensionAssociation
or DeleteExtensionAssociation.
2205 2206 2207 2208 2209 2210 2211 |
# File 'lib/aws-sdk-appconfig/types.rb', line 2205 class ExtensionAssociationSummary < Struct.new( :id, :extension_arn, :resource_arn) SENSITIVE = [] include Aws::Structure end |
#resource_arn ⇒ String
The ARNs of applications, configuration profiles, or environments defined in the association.
2205 2206 2207 2208 2209 2210 2211 |
# File 'lib/aws-sdk-appconfig/types.rb', line 2205 class ExtensionAssociationSummary < Struct.new( :id, :extension_arn, :resource_arn) SENSITIVE = [] include Aws::Structure end |