Class: Aws::AppConfig::Types::FlagValue

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-appconfig/types.rb

Overview

The feature flag value configuration for a treatment, including the enabled state and attribute values.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#attribute_valuesHash<String,Types::AttributeValue>

The attribute values associated with this flag value.

Returns:



2300
2301
2302
2303
2304
2305
# File 'lib/aws-sdk-appconfig/types.rb', line 2300

class FlagValue < Struct.new(
  :enabled,
  :attribute_values)
  SENSITIVE = []
  include Aws::Structure
end

#enabledBoolean

Whether the feature flag is enabled for this treatment.

Returns:

  • (Boolean)


2300
2301
2302
2303
2304
2305
# File 'lib/aws-sdk-appconfig/types.rb', line 2300

class FlagValue < Struct.new(
  :enabled,
  :attribute_values)
  SENSITIVE = []
  include Aws::Structure
end