Class: Aws::AppConfig::Types::HostedConfigurationVersion
- Inherits:
-
Struct
- Object
- Struct
- Aws::AppConfig::Types::HostedConfigurationVersion
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-appconfig/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:content]
Instance Attribute Summary collapse
-
#application_id ⇒ String
The application ID.
-
#configuration_profile_id ⇒ String
The configuration profile ID.
-
#content ⇒ String
The content of the configuration or the configuration data.
-
#content_type ⇒ String
A standard MIME type describing the format of the configuration content.
-
#description ⇒ String
A description of the configuration.
-
#kms_key_arn ⇒ String
The Amazon Resource Name of the Key Management Service key that was used to encrypt this specific version of the configuration data in the AppConfig hosted configuration store.
-
#version_label ⇒ String
A user-defined label for an AppConfig hosted configuration version.
-
#version_number ⇒ Integer
The configuration version.
Instance Attribute Details
#application_id ⇒ String
The application ID.
2589 2590 2591 2592 2593 2594 2595 2596 2597 2598 2599 2600 |
# File 'lib/aws-sdk-appconfig/types.rb', line 2589 class HostedConfigurationVersion < Struct.new( :application_id, :configuration_profile_id, :version_number, :description, :content, :content_type, :version_label, :kms_key_arn) SENSITIVE = [:content] include Aws::Structure end |
#configuration_profile_id ⇒ String
The configuration profile ID.
2589 2590 2591 2592 2593 2594 2595 2596 2597 2598 2599 2600 |
# File 'lib/aws-sdk-appconfig/types.rb', line 2589 class HostedConfigurationVersion < Struct.new( :application_id, :configuration_profile_id, :version_number, :description, :content, :content_type, :version_label, :kms_key_arn) SENSITIVE = [:content] include Aws::Structure end |
#content ⇒ String
The content of the configuration or the configuration data.
2589 2590 2591 2592 2593 2594 2595 2596 2597 2598 2599 2600 |
# File 'lib/aws-sdk-appconfig/types.rb', line 2589 class HostedConfigurationVersion < Struct.new( :application_id, :configuration_profile_id, :version_number, :description, :content, :content_type, :version_label, :kms_key_arn) SENSITIVE = [:content] include Aws::Structure end |
#content_type ⇒ String
A standard MIME type describing the format of the configuration content. For more information, see Content-Type.
2589 2590 2591 2592 2593 2594 2595 2596 2597 2598 2599 2600 |
# File 'lib/aws-sdk-appconfig/types.rb', line 2589 class HostedConfigurationVersion < Struct.new( :application_id, :configuration_profile_id, :version_number, :description, :content, :content_type, :version_label, :kms_key_arn) SENSITIVE = [:content] include Aws::Structure end |
#description ⇒ String
A description of the configuration.
2589 2590 2591 2592 2593 2594 2595 2596 2597 2598 2599 2600 |
# File 'lib/aws-sdk-appconfig/types.rb', line 2589 class HostedConfigurationVersion < Struct.new( :application_id, :configuration_profile_id, :version_number, :description, :content, :content_type, :version_label, :kms_key_arn) SENSITIVE = [:content] include Aws::Structure end |
#kms_key_arn ⇒ String
The Amazon Resource Name of the Key Management Service key that was used to encrypt this specific version of the configuration data in the AppConfig hosted configuration store.
2589 2590 2591 2592 2593 2594 2595 2596 2597 2598 2599 2600 |
# File 'lib/aws-sdk-appconfig/types.rb', line 2589 class HostedConfigurationVersion < Struct.new( :application_id, :configuration_profile_id, :version_number, :description, :content, :content_type, :version_label, :kms_key_arn) SENSITIVE = [:content] include Aws::Structure end |
#version_label ⇒ String
A user-defined label for an AppConfig hosted configuration version.
2589 2590 2591 2592 2593 2594 2595 2596 2597 2598 2599 2600 |
# File 'lib/aws-sdk-appconfig/types.rb', line 2589 class HostedConfigurationVersion < Struct.new( :application_id, :configuration_profile_id, :version_number, :description, :content, :content_type, :version_label, :kms_key_arn) SENSITIVE = [:content] include Aws::Structure end |
#version_number ⇒ Integer
The configuration version.
2589 2590 2591 2592 2593 2594 2595 2596 2597 2598 2599 2600 |
# File 'lib/aws-sdk-appconfig/types.rb', line 2589 class HostedConfigurationVersion < Struct.new( :application_id, :configuration_profile_id, :version_number, :description, :content, :content_type, :version_label, :kms_key_arn) SENSITIVE = [:content] include Aws::Structure end |