Class: Aws::AppConfig::Types::HostedConfigurationVersionSummary

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-appconfig/types.rb

Overview

Information about the configuration.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#application_idString

The application ID.



1911
1912
1913
1914
1915
1916
1917
1918
1919
1920
1921
# File 'lib/aws-sdk-appconfig/types.rb', line 1911

class HostedConfigurationVersionSummary < Struct.new(
  :application_id,
  :configuration_profile_id,
  :version_number,
  :description,
  :content_type,
  :version_label,
  :kms_key_arn)
  SENSITIVE = []
  include Aws::Structure
end

#configuration_profile_idString

The configuration profile ID.



1911
1912
1913
1914
1915
1916
1917
1918
1919
1920
1921
# File 'lib/aws-sdk-appconfig/types.rb', line 1911

class HostedConfigurationVersionSummary < Struct.new(
  :application_id,
  :configuration_profile_id,
  :version_number,
  :description,
  :content_type,
  :version_label,
  :kms_key_arn)
  SENSITIVE = []
  include Aws::Structure
end

#content_typeString

A standard MIME type describing the format of the configuration content. For more information, see [Content-Type][1].

[1]: www.w3.org/Protocols/rfc2616/rfc2616-sec14.html#sec14.17



1911
1912
1913
1914
1915
1916
1917
1918
1919
1920
1921
# File 'lib/aws-sdk-appconfig/types.rb', line 1911

class HostedConfigurationVersionSummary < Struct.new(
  :application_id,
  :configuration_profile_id,
  :version_number,
  :description,
  :content_type,
  :version_label,
  :kms_key_arn)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

A description of the configuration.



1911
1912
1913
1914
1915
1916
1917
1918
1919
1920
1921
# File 'lib/aws-sdk-appconfig/types.rb', line 1911

class HostedConfigurationVersionSummary < Struct.new(
  :application_id,
  :configuration_profile_id,
  :version_number,
  :description,
  :content_type,
  :version_label,
  :kms_key_arn)
  SENSITIVE = []
  include Aws::Structure
end

#kms_key_arnString

The Amazon Resource Name of the Key Management Service key that was used to encrypt this specific version of the configuration data in the AppConfig hosted configuration store.



1911
1912
1913
1914
1915
1916
1917
1918
1919
1920
1921
# File 'lib/aws-sdk-appconfig/types.rb', line 1911

class HostedConfigurationVersionSummary < Struct.new(
  :application_id,
  :configuration_profile_id,
  :version_number,
  :description,
  :content_type,
  :version_label,
  :kms_key_arn)
  SENSITIVE = []
  include Aws::Structure
end

#version_labelString

A user-defined label for an AppConfig hosted configuration version.



1911
1912
1913
1914
1915
1916
1917
1918
1919
1920
1921
# File 'lib/aws-sdk-appconfig/types.rb', line 1911

class HostedConfigurationVersionSummary < Struct.new(
  :application_id,
  :configuration_profile_id,
  :version_number,
  :description,
  :content_type,
  :version_label,
  :kms_key_arn)
  SENSITIVE = []
  include Aws::Structure
end

#version_numberInteger

The configuration version.



1911
1912
1913
1914
1915
1916
1917
1918
1919
1920
1921
# File 'lib/aws-sdk-appconfig/types.rb', line 1911

class HostedConfigurationVersionSummary < Struct.new(
  :application_id,
  :configuration_profile_id,
  :version_number,
  :description,
  :content_type,
  :version_label,
  :kms_key_arn)
  SENSITIVE = []
  include Aws::Structure
end