Class: Aws::AppConfig::Types::ListDeploymentStrategiesRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-appconfig/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#max_results ⇒ Integer

The maximum number of items to return for this call. The call also returns a token that you can specify in a subsequent call to get the next set of results.

Returns:

  • (Integer)


2791
2792
2793
2794
2795
2796
# File 'lib/aws-sdk-appconfig/types.rb', line 2791

class ListDeploymentStrategiesRequest < Struct.new(
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_token ⇒ String

A token to start the list. Use this token to get the next set of results.

Returns:

  • (String)


2791
2792
2793
2794
2795
2796
# File 'lib/aws-sdk-appconfig/types.rb', line 2791

class ListDeploymentStrategiesRequest < Struct.new(
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end