Class: Aws::AppConfig::Types::ListDeploymentsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-appconfig/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#application_id ⇒ String

The application ID.

Returns:

  • (String)


2821
2822
2823
2824
2825
2826
2827
2828
# File 'lib/aws-sdk-appconfig/types.rb', line 2821

class ListDeploymentsRequest < Struct.new(
  :application_id,
  :environment_id,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#environment_id ⇒ String

The environment ID.

Returns:

  • (String)


2821
2822
2823
2824
2825
2826
2827
2828
# File 'lib/aws-sdk-appconfig/types.rb', line 2821

class ListDeploymentsRequest < Struct.new(
  :application_id,
  :environment_id,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#max_results ⇒ Integer

The maximum number of items that may be returned for this call. If there are items that have not yet been returned, the response will include a non-null NextToken that you can provide in a subsequent call to get the next set of results.

Returns:

  • (Integer)


2821
2822
2823
2824
2825
2826
2827
2828
# File 'lib/aws-sdk-appconfig/types.rb', line 2821

class ListDeploymentsRequest < Struct.new(
  :application_id,
  :environment_id,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_token ⇒ String

The token returned by a prior call to this operation indicating the next set of results to be returned. If not specified, the operation will return the first set of results.

Returns:

  • (String)


2821
2822
2823
2824
2825
2826
2827
2828
# File 'lib/aws-sdk-appconfig/types.rb', line 2821

class ListDeploymentsRequest < Struct.new(
  :application_id,
  :environment_id,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end