Class: Aws::AppConfig::Types::ListHostedConfigurationVersionsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-appconfig/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#application_id ⇒ String

The application ID.

Returns:

  • (String)


3047
3048
3049
3050
3051
3052
3053
3054
3055
# File 'lib/aws-sdk-appconfig/types.rb', line 3047

class ListHostedConfigurationVersionsRequest < Struct.new(
  :application_id,
  :configuration_profile_id,
  :max_results,
  :next_token,
  :version_label)
  SENSITIVE = []
  include Aws::Structure
end

#configuration_profile_id ⇒ String

The configuration profile ID.

Returns:

  • (String)


3047
3048
3049
3050
3051
3052
3053
3054
3055
# File 'lib/aws-sdk-appconfig/types.rb', line 3047

class ListHostedConfigurationVersionsRequest < Struct.new(
  :application_id,
  :configuration_profile_id,
  :max_results,
  :next_token,
  :version_label)
  SENSITIVE = []
  include Aws::Structure
end

#max_results ⇒ Integer

The maximum number of items to return for this call. If MaxResults is not provided in the call, AppConfig returns the maximum of 50. The call also returns a token that you can specify in a subsequent call to get the next set of results.

Returns:

  • (Integer)


3047
3048
3049
3050
3051
3052
3053
3054
3055
# File 'lib/aws-sdk-appconfig/types.rb', line 3047

class ListHostedConfigurationVersionsRequest < Struct.new(
  :application_id,
  :configuration_profile_id,
  :max_results,
  :next_token,
  :version_label)
  SENSITIVE = []
  include Aws::Structure
end

#next_token ⇒ String

A token to start the list. Use this token to get the next set of results.

Returns:

  • (String)


3047
3048
3049
3050
3051
3052
3053
3054
3055
# File 'lib/aws-sdk-appconfig/types.rb', line 3047

class ListHostedConfigurationVersionsRequest < Struct.new(
  :application_id,
  :configuration_profile_id,
  :max_results,
  :next_token,
  :version_label)
  SENSITIVE = []
  include Aws::Structure
end

#version_label ⇒ String

An optional filter that can be used to specify the version label of an AppConfig hosted configuration version. This parameter supports filtering by prefix using a wildcard, for example "v2*". If you don't specify an asterisk at the end of the value, only an exact match is returned.

Returns:

  • (String)


3047
3048
3049
3050
3051
3052
3053
3054
3055
# File 'lib/aws-sdk-appconfig/types.rb', line 3047

class ListHostedConfigurationVersionsRequest < Struct.new(
  :application_id,
  :configuration_profile_id,
  :max_results,
  :next_token,
  :version_label)
  SENSITIVE = []
  include Aws::Structure
end