Class: Aws::AppConfig::Types::Parameter

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-appconfig/types.rb

Overview

A value such as an Amazon Resource Name (ARN) or an Amazon Simple Notification Service topic entered in an extension when invoked. Parameter values are specified in an extension association. For more information about extensions, see Extending workflows in the AppConfig User Guide.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#descriptionString

Information about the parameter.

Returns:

  • (String)


3115
3116
3117
3118
3119
3120
3121
# File 'lib/aws-sdk-appconfig/types.rb', line 3115

class Parameter < Struct.new(
  :description,
  :required,
  :dynamic)
  SENSITIVE = []
  include Aws::Structure
end

#dynamicBoolean

Indicates whether this parameter's value can be supplied at the extension's action point instead of during extension association. Dynamic parameters can't be marked Required.

Returns:

  • (Boolean)


3115
3116
3117
3118
3119
3120
3121
# File 'lib/aws-sdk-appconfig/types.rb', line 3115

class Parameter < Struct.new(
  :description,
  :required,
  :dynamic)
  SENSITIVE = []
  include Aws::Structure
end

#requiredBoolean

A parameter value must be specified in the extension association.

Returns:

  • (Boolean)


3115
3116
3117
3118
3119
3120
3121
# File 'lib/aws-sdk-appconfig/types.rb', line 3115

class Parameter < Struct.new(
  :description,
  :required,
  :dynamic)
  SENSITIVE = []
  include Aws::Structure
end