Class: Aws::AppConfig::Types::ServiceQuotaExceededException

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-appconfig/types.rb

Overview

The number of one more AppConfig resources exceeds the maximum allowed. Verify that your environment doesn't exceed the following service quotas:

Applications: 100 max

To resolve this issue, you can delete one or more resources and try again. Or, you can request a quota increase. For more information about quotas and to request an increase, see Service quotas for AppConfig in the Amazon Web Services General Reference.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#messageString

Returns:

  • (String)


3199
3200
3201
3202
3203
# File 'lib/aws-sdk-appconfig/types.rb', line 3199

class ServiceQuotaExceededException < Struct.new(
  :message)
  SENSITIVE = []
  include Aws::Structure
end