Class: Aws::AppConfig::Types::StartExperimentRunRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-appconfig/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#application_identifier ⇒ String

The application ID or name.



3305
3306
3307
3308
3309
3310
3311
3312
3313
3314
3315
# File 'lib/aws-sdk-appconfig/types.rb', line 3305

class StartExperimentRunRequest < Struct.new(
  :application_identifier,
  :experiment_definition_identifier,
  :description,
  :exposure_percentage,
  :treatment_overrides,
  :tags,
  :deployment_parameters)
  SENSITIVE = []
  include Aws::Structure
end

#deployment_parameters ⇒ Types::DeploymentParameters

The deployment parameters for the experiment run, including a KMS key identifier for encryption.



3305
3306
3307
3308
3309
3310
3311
3312
3313
3314
3315
# File 'lib/aws-sdk-appconfig/types.rb', line 3305

class StartExperimentRunRequest < Struct.new(
  :application_identifier,
  :experiment_definition_identifier,
  :description,
  :exposure_percentage,
  :treatment_overrides,
  :tags,
  :deployment_parameters)
  SENSITIVE = []
  include Aws::Structure
end

#description ⇒ String

A description of this experiment run.



3305
3306
3307
3308
3309
3310
3311
3312
3313
3314
3315
# File 'lib/aws-sdk-appconfig/types.rb', line 3305

class StartExperimentRunRequest < Struct.new(
  :application_identifier,
  :experiment_definition_identifier,
  :description,
  :exposure_percentage,
  :treatment_overrides,
  :tags,
  :deployment_parameters)
  SENSITIVE = []
  include Aws::Structure
end

#experiment_definition_identifier ⇒ String

The experiment definition ID or name.



3305
3306
3307
3308
3309
3310
3311
3312
3313
3314
3315
# File 'lib/aws-sdk-appconfig/types.rb', line 3305

class StartExperimentRunRequest < Struct.new(
  :application_identifier,
  :experiment_definition_identifier,
  :description,
  :exposure_percentage,
  :treatment_overrides,
  :tags,
  :deployment_parameters)
  SENSITIVE = []
  include Aws::Structure
end

#exposure_percentage ⇒ Float

The percentage of the target audience to expose to treatments. Set to 0 to validate the experiment before exposing production users.



3305
3306
3307
3308
3309
3310
3311
3312
3313
3314
3315
# File 'lib/aws-sdk-appconfig/types.rb', line 3305

class StartExperimentRunRequest < Struct.new(
  :application_identifier,
  :experiment_definition_identifier,
  :description,
  :exposure_percentage,
  :treatment_overrides,
  :tags,
  :deployment_parameters)
  SENSITIVE = []
  include Aws::Structure
end

#tags ⇒ Hash<String,String>

The tags to assign to the experiment run.



3305
3306
3307
3308
3309
3310
3311
3312
3313
3314
3315
# File 'lib/aws-sdk-appconfig/types.rb', line 3305

class StartExperimentRunRequest < Struct.new(
  :application_identifier,
  :experiment_definition_identifier,
  :description,
  :exposure_percentage,
  :treatment_overrides,
  :tags,
  :deployment_parameters)
  SENSITIVE = []
  include Aws::Structure
end

#treatment_overrides ⇒ Types::TreatmentOverrides

Treatment assignment overrides that assign specific entity IDs to treatments directly, bypassing random assignment.



3305
3306
3307
3308
3309
3310
3311
3312
3313
3314
3315
# File 'lib/aws-sdk-appconfig/types.rb', line 3305

class StartExperimentRunRequest < Struct.new(
  :application_identifier,
  :experiment_definition_identifier,
  :description,
  :exposure_percentage,
  :treatment_overrides,
  :tags,
  :deployment_parameters)
  SENSITIVE = []
  include Aws::Structure
end