Class: Aws::AppConfig::Types::StopExperimentRunRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::AppConfig::Types::StopExperimentRunRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-appconfig/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#application_identifier ⇒ String
The application ID or name.
-
#deployment_parameters ⇒ Types::DeploymentParameters
Optional deployment parameters for the stop operation.
-
#experiment_definition_identifier ⇒ String
The experiment definition ID or name.
-
#result ⇒ Types::ExperimentRunResult
The result of the experiment run, including an executive summary and reasons for or against launching.
-
#run ⇒ Integer
The run number to stop.
Instance Attribute Details
#application_identifier ⇒ String
The application ID or name.
3368 3369 3370 3371 3372 3373 3374 3375 3376 |
# File 'lib/aws-sdk-appconfig/types.rb', line 3368 class StopExperimentRunRequest < Struct.new( :application_identifier, :experiment_definition_identifier, :run, :result, :deployment_parameters) SENSITIVE = [] include Aws::Structure end |
#deployment_parameters ⇒ Types::DeploymentParameters
Optional deployment parameters for the stop operation.
3368 3369 3370 3371 3372 3373 3374 3375 3376 |
# File 'lib/aws-sdk-appconfig/types.rb', line 3368 class StopExperimentRunRequest < Struct.new( :application_identifier, :experiment_definition_identifier, :run, :result, :deployment_parameters) SENSITIVE = [] include Aws::Structure end |
#experiment_definition_identifier ⇒ String
The experiment definition ID or name.
3368 3369 3370 3371 3372 3373 3374 3375 3376 |
# File 'lib/aws-sdk-appconfig/types.rb', line 3368 class StopExperimentRunRequest < Struct.new( :application_identifier, :experiment_definition_identifier, :run, :result, :deployment_parameters) SENSITIVE = [] include Aws::Structure end |
#result ⇒ Types::ExperimentRunResult
The result of the experiment run, including an executive summary and reasons for or against launching.
3368 3369 3370 3371 3372 3373 3374 3375 3376 |
# File 'lib/aws-sdk-appconfig/types.rb', line 3368 class StopExperimentRunRequest < Struct.new( :application_identifier, :experiment_definition_identifier, :run, :result, :deployment_parameters) SENSITIVE = [] include Aws::Structure end |
#run ⇒ Integer
The run number to stop.
3368 3369 3370 3371 3372 3373 3374 3375 3376 |
# File 'lib/aws-sdk-appconfig/types.rb', line 3368 class StopExperimentRunRequest < Struct.new( :application_identifier, :experiment_definition_identifier, :run, :result, :deployment_parameters) SENSITIVE = [] include Aws::Structure end |