Class: Aws::AppConfig::Types::Treatment

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-appconfig/types.rb

Overview

Describes a treatment in an experiment, including its traffic allocation weight and feature flag value.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#descriptionString

A description of the treatment.

Returns:

  • (String)


3418
3419
3420
3421
3422
3423
3424
3425
# File 'lib/aws-sdk-appconfig/types.rb', line 3418

class Treatment < Struct.new(
  :key,
  :weight,
  :description,
  :flag_value)
  SENSITIVE = []
  include Aws::Structure
end

#flag_valueTypes::FlagValue

The feature flag value served to users assigned to this treatment.

Returns:



3418
3419
3420
3421
3422
3423
3424
3425
# File 'lib/aws-sdk-appconfig/types.rb', line 3418

class Treatment < Struct.new(
  :key,
  :weight,
  :description,
  :flag_value)
  SENSITIVE = []
  include Aws::Structure
end

#keyString

The unique key that identifies this treatment.

Returns:

  • (String)


3418
3419
3420
3421
3422
3423
3424
3425
# File 'lib/aws-sdk-appconfig/types.rb', line 3418

class Treatment < Struct.new(
  :key,
  :weight,
  :description,
  :flag_value)
  SENSITIVE = []
  include Aws::Structure
end

#weightFloat

The traffic allocation weight for this treatment.

Returns:

  • (Float)


3418
3419
3420
3421
3422
3423
3424
3425
# File 'lib/aws-sdk-appconfig/types.rb', line 3418

class Treatment < Struct.new(
  :key,
  :weight,
  :description,
  :flag_value)
  SENSITIVE = []
  include Aws::Structure
end