Class: Aws::AppConfig::Types::TreatmentInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-appconfig/types.rb

Overview

Input structure for defining a treatment when creating or updating an experiment definition.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#descriptionString

A description of the treatment.

Returns:

  • (String)


3444
3445
3446
3447
3448
3449
3450
# File 'lib/aws-sdk-appconfig/types.rb', line 3444

class TreatmentInput < Struct.new(
  :weight,
  :description,
  :flag_value)
  SENSITIVE = []
  include Aws::Structure
end

#flag_valueTypes::FlagValue

The feature flag value to serve to users assigned to this treatment.

Returns:



3444
3445
3446
3447
3448
3449
3450
# File 'lib/aws-sdk-appconfig/types.rb', line 3444

class TreatmentInput < Struct.new(
  :weight,
  :description,
  :flag_value)
  SENSITIVE = []
  include Aws::Structure
end

#weightFloat

The traffic allocation weight for this treatment.

Returns:

  • (Float)


3444
3445
3446
3447
3448
3449
3450
# File 'lib/aws-sdk-appconfig/types.rb', line 3444

class TreatmentInput < Struct.new(
  :weight,
  :description,
  :flag_value)
  SENSITIVE = []
  include Aws::Structure
end