Class: Aws::AppConfig::Types::UpdateAccountSettingsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-appconfig/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#deletion_protectionTypes::DeletionProtectionSettings

A parameter to configure deletion protection. Deletion protection prevents a user from deleting a configuration profile or an environment if AppConfig has called either GetLatestConfiguration or for the configuration profile or from the environment during the specified interval. The default interval for ProtectionPeriodInMinutes is 60.



3514
3515
3516
3517
3518
3519
# File 'lib/aws-sdk-appconfig/types.rb', line 3514

class UpdateAccountSettingsRequest < Struct.new(
  :deletion_protection,
  :vended_metrics)
  SENSITIVE = []
  include Aws::Structure
end

#vended_metricsTypes::VendedMetricsSettings

Configuration for vended metrics in the account.



3514
3515
3516
3517
3518
3519
# File 'lib/aws-sdk-appconfig/types.rb', line 3514

class UpdateAccountSettingsRequest < Struct.new(
  :deletion_protection,
  :vended_metrics)
  SENSITIVE = []
  include Aws::Structure
end