Class: Aws::AppConfig::Types::UpdateConfigurationProfileRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::AppConfig::Types::UpdateConfigurationProfileRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-appconfig/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#application_id ⇒ String
The application ID.
-
#configuration_profile_id ⇒ String
The ID of the configuration profile.
-
#description ⇒ String
A description of the configuration profile.
-
#kms_key_identifier ⇒ String
The identifier for a Key Management Service key to encrypt new configuration data versions in the AppConfig hosted configuration store.
-
#name ⇒ String
The name of the configuration profile.
-
#retrieval_role_arn ⇒ String
The ARN of an IAM role with permission to access the configuration at the specified
LocationUri. -
#validators ⇒ Array<Types::Validator>
A list of methods for validating the configuration.
Instance Attribute Details
#application_id ⇒ String
The application ID.
3584 3585 3586 3587 3588 3589 3590 3591 3592 3593 3594 |
# File 'lib/aws-sdk-appconfig/types.rb', line 3584 class UpdateConfigurationProfileRequest < Struct.new( :application_id, :configuration_profile_id, :name, :description, :retrieval_role_arn, :validators, :kms_key_identifier) SENSITIVE = [] include Aws::Structure end |
#configuration_profile_id ⇒ String
The ID of the configuration profile.
3584 3585 3586 3587 3588 3589 3590 3591 3592 3593 3594 |
# File 'lib/aws-sdk-appconfig/types.rb', line 3584 class UpdateConfigurationProfileRequest < Struct.new( :application_id, :configuration_profile_id, :name, :description, :retrieval_role_arn, :validators, :kms_key_identifier) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A description of the configuration profile.
3584 3585 3586 3587 3588 3589 3590 3591 3592 3593 3594 |
# File 'lib/aws-sdk-appconfig/types.rb', line 3584 class UpdateConfigurationProfileRequest < Struct.new( :application_id, :configuration_profile_id, :name, :description, :retrieval_role_arn, :validators, :kms_key_identifier) SENSITIVE = [] include Aws::Structure end |
#kms_key_identifier ⇒ String
The identifier for a Key Management Service key to encrypt new
configuration data versions in the AppConfig hosted configuration
store. This attribute is only used for hosted configuration types.
The identifier can be an KMS key ID, alias, or the Amazon Resource
Name (ARN) of the key ID or alias. To encrypt data managed in other
configuration stores, see the documentation for how to specify an
KMS key for that particular service.
3584 3585 3586 3587 3588 3589 3590 3591 3592 3593 3594 |
# File 'lib/aws-sdk-appconfig/types.rb', line 3584 class UpdateConfigurationProfileRequest < Struct.new( :application_id, :configuration_profile_id, :name, :description, :retrieval_role_arn, :validators, :kms_key_identifier) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the configuration profile.
3584 3585 3586 3587 3588 3589 3590 3591 3592 3593 3594 |
# File 'lib/aws-sdk-appconfig/types.rb', line 3584 class UpdateConfigurationProfileRequest < Struct.new( :application_id, :configuration_profile_id, :name, :description, :retrieval_role_arn, :validators, :kms_key_identifier) SENSITIVE = [] include Aws::Structure end |
#retrieval_role_arn ⇒ String
The ARN of an IAM role with permission to access the configuration
at the specified LocationUri.
A retrieval role ARN is not required for configurations stored in CodePipeline or the AppConfig hosted configuration store. It is required for all other sources that store your configuration.
3584 3585 3586 3587 3588 3589 3590 3591 3592 3593 3594 |
# File 'lib/aws-sdk-appconfig/types.rb', line 3584 class UpdateConfigurationProfileRequest < Struct.new( :application_id, :configuration_profile_id, :name, :description, :retrieval_role_arn, :validators, :kms_key_identifier) SENSITIVE = [] include Aws::Structure end |
#validators ⇒ Array<Types::Validator>
A list of methods for validating the configuration.
3584 3585 3586 3587 3588 3589 3590 3591 3592 3593 3594 |
# File 'lib/aws-sdk-appconfig/types.rb', line 3584 class UpdateConfigurationProfileRequest < Struct.new( :application_id, :configuration_profile_id, :name, :description, :retrieval_role_arn, :validators, :kms_key_identifier) SENSITIVE = [] include Aws::Structure end |