Class: Aws::AppConfig::Types::UpdateDeploymentStrategyRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-appconfig/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#deployment_duration_in_minutesInteger

Total amount of time for a deployment to last.



2646
2647
2648
2649
2650
2651
2652
2653
2654
2655
# File 'lib/aws-sdk-appconfig/types.rb', line 2646

class UpdateDeploymentStrategyRequest < Struct.new(
  :deployment_strategy_id,
  :description,
  :deployment_duration_in_minutes,
  :final_bake_time_in_minutes,
  :growth_factor,
  :growth_type)
  SENSITIVE = []
  include Aws::Structure
end

#deployment_strategy_idString

The deployment strategy ID.



2646
2647
2648
2649
2650
2651
2652
2653
2654
2655
# File 'lib/aws-sdk-appconfig/types.rb', line 2646

class UpdateDeploymentStrategyRequest < Struct.new(
  :deployment_strategy_id,
  :description,
  :deployment_duration_in_minutes,
  :final_bake_time_in_minutes,
  :growth_factor,
  :growth_type)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

A description of the deployment strategy.



2646
2647
2648
2649
2650
2651
2652
2653
2654
2655
# File 'lib/aws-sdk-appconfig/types.rb', line 2646

class UpdateDeploymentStrategyRequest < Struct.new(
  :deployment_strategy_id,
  :description,
  :deployment_duration_in_minutes,
  :final_bake_time_in_minutes,
  :growth_factor,
  :growth_type)
  SENSITIVE = []
  include Aws::Structure
end

#final_bake_time_in_minutesInteger

The amount of time that AppConfig monitors for alarms before considering the deployment to be complete and no longer eligible for automatic rollback.



2646
2647
2648
2649
2650
2651
2652
2653
2654
2655
# File 'lib/aws-sdk-appconfig/types.rb', line 2646

class UpdateDeploymentStrategyRequest < Struct.new(
  :deployment_strategy_id,
  :description,
  :deployment_duration_in_minutes,
  :final_bake_time_in_minutes,
  :growth_factor,
  :growth_type)
  SENSITIVE = []
  include Aws::Structure
end

#growth_factorFloat

The percentage of targets to receive a deployed configuration during each interval.



2646
2647
2648
2649
2650
2651
2652
2653
2654
2655
# File 'lib/aws-sdk-appconfig/types.rb', line 2646

class UpdateDeploymentStrategyRequest < Struct.new(
  :deployment_strategy_id,
  :description,
  :deployment_duration_in_minutes,
  :final_bake_time_in_minutes,
  :growth_factor,
  :growth_type)
  SENSITIVE = []
  include Aws::Structure
end

#growth_typeString

The algorithm used to define how percentage grows over time. AppConfig supports the following growth types:

Linear: For this type, AppConfig processes the deployment by increments of the growth factor evenly distributed over the deployment time. For example, a linear deployment that uses a growth factor of 20 initially makes the configuration available to 20 percent of the targets. After 1/5th of the deployment time has passed, the system updates the percentage to 40 percent. This continues until 100% of the targets are set to receive the deployed configuration.

Exponential: For this type, AppConfig processes the deployment exponentially using the following formula: ‘G*(2^N)`. In this formula, G is the growth factor specified by the user and N is the number of steps until the configuration is deployed to all targets. For example, if you specify a growth factor of 2, then the system rolls out the configuration as follows:

‘2*(2^0)`

‘2*(2^1)`

‘2*(2^2)`

Expressed numerically, the deployment rolls out as follows: 2% of the targets, 4% of the targets, 8% of the targets, and continues until the configuration has been deployed to all targets.



2646
2647
2648
2649
2650
2651
2652
2653
2654
2655
# File 'lib/aws-sdk-appconfig/types.rb', line 2646

class UpdateDeploymentStrategyRequest < Struct.new(
  :deployment_strategy_id,
  :description,
  :deployment_duration_in_minutes,
  :final_bake_time_in_minutes,
  :growth_factor,
  :growth_type)
  SENSITIVE = []
  include Aws::Structure
end