Class: Aws::AppConfig::Types::VendedMetricsSettings
- Inherits:
-
Struct
- Object
- Struct
- Aws::AppConfig::Types::VendedMetricsSettings
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-appconfig/types.rb
Overview
The configuration settings for vended metrics in your AppConfig account.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#enabled ⇒ Boolean
Specifies whether vended metrics are enabled for the account.
Instance Attribute Details
#enabled ⇒ Boolean
Specifies whether vended metrics are enabled for the account.
3899 3900 3901 3902 3903 |
# File 'lib/aws-sdk-appconfig/types.rb', line 3899 class VendedMetricsSettings < Struct.new( :enabled) SENSITIVE = [] include Aws::Structure end |