Class: Aws::AppConfig::Waiters::DeploymentComplete

Inherits:
Object
  • Object
show all
Defined in:
sig/waiters.rbs,
lib/aws-sdk-appconfig/waiters.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(options) ⇒ DeploymentComplete

Returns a new instance of DeploymentComplete.

Parameters:

  • options (Hash)

Options Hash (options):

  • :client (required, Client)
  • :max_attempts (Integer) — default: 999
  • :delay (Integer) — default: 30
  • :before_attempt (Proc)
  • :before_wait (Proc)


85
86
# File 'lib/aws-sdk-appconfig/waiters.rb', line 85

def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void

Instance Attribute Details

#waiterObject (readonly)

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.



123
124
125
# File 'lib/aws-sdk-appconfig/waiters.rb', line 123

def waiter
  @waiter
end

Instance Method Details

#wait(params = {}) ⇒ Types::Deployment

Returns a response object which responds to the following methods:

Options Hash (params):

  • :application_id (required, String)

    The ID of the application that includes the deployment you want to get.

  • :environment_id (required, String)

    The ID of the environment that includes the deployment you want to get.

  • :deployment_number (required, Integer)

    The sequence number of the deployment.

Returns:



118
# File 'lib/aws-sdk-appconfig/waiters.rb', line 118

def wait: (