Class: Aws::AppConfig::Waiters::EnvironmentReadyForDeployment

Inherits:
Object
  • Object
show all
Defined in:
sig/waiters.rbs,
lib/aws-sdk-appconfig/waiters.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(options) ⇒ EnvironmentReadyForDeployment

Returns a new instance of EnvironmentReadyForDeployment.

Parameters:

  • options (Hash)

Options Hash (options):

  • :client (required, Client)
  • :max_attempts (Integer) — default: 999
  • :delay (Integer) — default: 30
  • :before_attempt (Proc)
  • :before_wait (Proc)


135
136
# File 'lib/aws-sdk-appconfig/waiters.rb', line 135

def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void

Instance Attribute Details

#waiterObject (readonly)

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.



173
174
175
# File 'lib/aws-sdk-appconfig/waiters.rb', line 173

def waiter
  @waiter
end

Instance Method Details

#wait(params = {}) ⇒ Types::Environment

Returns a response object which responds to the following methods:

Options Hash (params):

  • :application_id (required, String)

    The ID of the application that includes the environment you want to get.

  • :environment_id (required, String)

    The ID of the environment that you want to get.

Returns:



168
# File 'lib/aws-sdk-appconfig/waiters.rb', line 168

def wait: (