Class: Aws::AppConfig::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::AppConfig::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-appconfig/client.rb
Overview
An API client for AppConfig. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::AppConfig::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#create_application(params = {}) ⇒ Types::Application
Creates an application.
-
#create_configuration_profile(params = {}) ⇒ Types::ConfigurationProfile
Creates a configuration profile, which is information that enables AppConfig to access the configuration source.
-
#create_deployment_strategy(params = {}) ⇒ Types::DeploymentStrategy
Creates a deployment strategy that defines important criteria for rolling out your configuration to the designated targets.
-
#create_environment(params = {}) ⇒ Types::Environment
Creates an environment.
-
#create_extension(params = {}) ⇒ Types::Extension
Creates an AppConfig extension.
-
#create_extension_association(params = {}) ⇒ Types::ExtensionAssociation
When you create an extension or configure an Amazon Web Services authored extension, you associate the extension with an AppConfig application, environment, or configuration profile.
-
#create_hosted_configuration_version(params = {}) ⇒ Types::HostedConfigurationVersion
Creates a new configuration in the AppConfig hosted configuration store.
-
#delete_application(params = {}) ⇒ Struct
Deletes an application.
-
#delete_configuration_profile(params = {}) ⇒ Struct
Deletes a configuration profile.
-
#delete_deployment_strategy(params = {}) ⇒ Struct
Deletes a deployment strategy.
-
#delete_environment(params = {}) ⇒ Struct
Deletes an environment.
-
#delete_extension(params = {}) ⇒ Struct
Deletes an AppConfig extension.
-
#delete_extension_association(params = {}) ⇒ Struct
Deletes an extension association.
-
#delete_hosted_configuration_version(params = {}) ⇒ Struct
Deletes a version of a configuration from the AppConfig hosted configuration store.
-
#get_account_settings(params = {}) ⇒ Types::AccountSettings
Returns information about the status of the ‘DeletionProtection` parameter.
-
#get_application(params = {}) ⇒ Types::Application
Retrieves information about an application.
-
#get_configuration(params = {}) ⇒ Types::Configuration
(Deprecated) Retrieves the latest deployed configuration.
-
#get_configuration_profile(params = {}) ⇒ Types::ConfigurationProfile
Retrieves information about a configuration profile.
-
#get_deployment(params = {}) ⇒ Types::Deployment
Retrieves information about a configuration deployment.
-
#get_deployment_strategy(params = {}) ⇒ Types::DeploymentStrategy
Retrieves information about a deployment strategy.
-
#get_environment(params = {}) ⇒ Types::Environment
Retrieves information about an environment.
-
#get_extension(params = {}) ⇒ Types::Extension
Returns information about an AppConfig extension.
-
#get_extension_association(params = {}) ⇒ Types::ExtensionAssociation
Returns information about an AppConfig extension association.
-
#get_hosted_configuration_version(params = {}) ⇒ Types::HostedConfigurationVersion
Retrieves information about a specific configuration version.
-
#list_applications(params = {}) ⇒ Types::Applications
Lists all applications in your Amazon Web Services account.
-
#list_configuration_profiles(params = {}) ⇒ Types::ConfigurationProfiles
Lists the configuration profiles for an application.
-
#list_deployment_strategies(params = {}) ⇒ Types::DeploymentStrategies
Lists deployment strategies.
-
#list_deployments(params = {}) ⇒ Types::Deployments
Lists the deployments for an environment in descending deployment number order.
-
#list_environments(params = {}) ⇒ Types::Environments
Lists the environments for an application.
-
#list_extension_associations(params = {}) ⇒ Types::ExtensionAssociations
Lists all AppConfig extension associations in the account.
-
#list_extensions(params = {}) ⇒ Types::Extensions
Lists all custom and Amazon Web Services authored AppConfig extensions in the account.
-
#list_hosted_configuration_versions(params = {}) ⇒ Types::HostedConfigurationVersions
Lists configurations stored in the AppConfig hosted configuration store by version.
-
#list_tags_for_resource(params = {}) ⇒ Types::ResourceTags
Retrieves the list of key-value tags assigned to the resource.
-
#start_deployment(params = {}) ⇒ Types::Deployment
Starts a deployment.
-
#stop_deployment(params = {}) ⇒ Types::Deployment
Stops a deployment.
-
#tag_resource(params = {}) ⇒ Struct
Assigns metadata to an AppConfig resource.
-
#untag_resource(params = {}) ⇒ Struct
Deletes a tag key and value from an AppConfig resource.
-
#update_account_settings(params = {}) ⇒ Types::AccountSettings
Updates the value of the ‘DeletionProtection` parameter.
-
#update_application(params = {}) ⇒ Types::Application
Updates an application.
-
#update_configuration_profile(params = {}) ⇒ Types::ConfigurationProfile
Updates a configuration profile.
-
#update_deployment_strategy(params = {}) ⇒ Types::DeploymentStrategy
Updates a deployment strategy.
-
#update_environment(params = {}) ⇒ Types::Environment
Updates an environment.
-
#update_extension(params = {}) ⇒ Types::Extension
Updates an AppConfig extension.
-
#update_extension_association(params = {}) ⇒ Types::ExtensionAssociation
Updates an association.
-
#validate_configuration(params = {}) ⇒ Struct
Uses the validators in a configuration profile to validate a configuration.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
-
#wait_until(waiter_name, params = {}, options = {}) {|w.waiter| ... } ⇒ Boolean
Polls an API operation until a resource enters a desired state.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-appconfig/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
4050 4051 4052 |
# File 'lib/aws-sdk-appconfig/client.rb', line 4050 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
4053 4054 4055 |
# File 'lib/aws-sdk-appconfig/client.rb', line 4053 def errors_module Errors end |
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3908 3909 3910 3911 3912 3913 3914 3915 3916 3917 3918 3919 3920 3921 3922 3923 3924 |
# File 'lib/aws-sdk-appconfig/client.rb', line 3908 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::AppConfig') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-appconfig' context[:gem_version] = '1.81.0' Seahorse::Client::Request.new(handlers, context) end |
#create_application(params = {}) ⇒ Types::Application
Creates an application. In AppConfig, an application is simply an organizational construct like a folder. This organizational construct has a relationship with some unit of executable code. For example, you could create an application called MyMobileApp to organize and manage configuration data for a mobile application installed by your users.
537 538 539 540 |
# File 'lib/aws-sdk-appconfig/client.rb', line 537 def create_application(params = {}, = {}) req = build_request(:create_application, params) req.send_request() end |
#create_configuration_profile(params = {}) ⇒ Types::ConfigurationProfile
Creates a configuration profile, which is information that enables AppConfig to access the configuration source. Valid configuration sources include the following:
-
Configuration data in YAML, JSON, and other formats stored in the AppConfig hosted configuration store
-
Configuration data stored as objects in an Amazon Simple Storage Service (Amazon S3) bucket
-
Pipelines stored in CodePipeline
-
Secrets stored in Secrets Manager
-
Standard and secure string parameters stored in Amazon Web Services Systems Manager Parameter Store
-
Configuration data in SSM documents stored in the Systems Manager document store
A configuration profile includes the following information:
-
The URI location of the configuration data.
-
The Identity and Access Management (IAM) role that provides access to the configuration data.
-
A validator for the configuration data. Available validators include either a JSON Schema or an Amazon Web Services Lambda function.
For more information, see [Create a Configuration and a Configuration Profile] in the *AppConfig User Guide*.
[1]: docs.aws.amazon.com/appconfig/latest/userguide/appconfig-creating-configuration-and-profile.html
723 724 725 726 |
# File 'lib/aws-sdk-appconfig/client.rb', line 723 def create_configuration_profile(params = {}, = {}) req = build_request(:create_configuration_profile, params) req.send_request() end |
#create_deployment_strategy(params = {}) ⇒ Types::DeploymentStrategy
Creates a deployment strategy that defines important criteria for rolling out your configuration to the designated targets. A deployment strategy includes the overall duration required, a percentage of targets to receive the deployment during each interval, an algorithm that defines how percentage grows, and bake time.
864 865 866 867 |
# File 'lib/aws-sdk-appconfig/client.rb', line 864 def create_deployment_strategy(params = {}, = {}) req = build_request(:create_deployment_strategy, params) req.send_request() end |
#create_environment(params = {}) ⇒ Types::Environment
Creates an environment. For each application, you define one or more environments. An environment is a deployment group of AppConfig targets, such as applications in a ‘Beta` or `Production` environment. You can also define environments for application subcomponents such as the `Web`, `Mobile` and `Back-end` components for your application. You can configure Amazon CloudWatch alarms for each environment. The system monitors alarms during a configuration deployment. If an alarm is triggered, the system rolls back the configuration.
955 956 957 958 |
# File 'lib/aws-sdk-appconfig/client.rb', line 955 def create_environment(params = {}, = {}) req = build_request(:create_environment, params) req.send_request() end |
#create_extension(params = {}) ⇒ Types::Extension
Creates an AppConfig extension. An extension augments your ability to inject logic or behavior at different points during the AppConfig workflow of creating or deploying a configuration.
You can create your own extensions or use the Amazon Web Services authored extensions provided by AppConfig. For an AppConfig extension that uses Lambda, you must create a Lambda function to perform any computation and processing defined in the extension. If you plan to create custom versions of the Amazon Web Services authored notification extensions, you only need to specify an Amazon Resource Name (ARN) in the ‘Uri` field for the new extension version.
-
For a custom EventBridge notification extension, enter the ARN of the EventBridge default events in the ‘Uri` field.
-
For a custom Amazon SNS notification extension, enter the ARN of an Amazon SNS topic in the ‘Uri` field.
-
For a custom Amazon SQS notification extension, enter the ARN of an Amazon SQS message queue in the ‘Uri` field.
For more information about extensions, see [Extending workflows] in the *AppConfig User Guide*.
[1]: docs.aws.amazon.com/appconfig/latest/userguide/working-with-appconfig-extensions.html
1075 1076 1077 1078 |
# File 'lib/aws-sdk-appconfig/client.rb', line 1075 def create_extension(params = {}, = {}) req = build_request(:create_extension, params) req.send_request() end |
#create_extension_association(params = {}) ⇒ Types::ExtensionAssociation
When you create an extension or configure an Amazon Web Services authored extension, you associate the extension with an AppConfig application, environment, or configuration profile. For example, you can choose to run the ‘AppConfig deployment events to Amazon SNS` Amazon Web Services authored extension and receive notifications on an Amazon SNS topic anytime a configuration deployment is started for a specific application. Defining which extension to associate with an AppConfig resource is called an *extension association*. An extension association is a specified relationship between an extension and an AppConfig resource, such as an application or a configuration profile. For more information about extensions and associations, see [Extending workflows] in the *AppConfig User Guide*.
[1]: docs.aws.amazon.com/appconfig/latest/userguide/working-with-appconfig-extensions.html
1154 1155 1156 1157 |
# File 'lib/aws-sdk-appconfig/client.rb', line 1154 def create_extension_association(params = {}, = {}) req = build_request(:create_extension_association, params) req.send_request() end |
#create_hosted_configuration_version(params = {}) ⇒ Types::HostedConfigurationVersion
Creates a new configuration in the AppConfig hosted configuration store. If you’re creating a feature flag, we recommend you familiarize yourself with the JSON schema for feature flag data. For more information, see [Type reference for AWS.AppConfig.FeatureFlags] in the *AppConfig User Guide*.
1266 1267 1268 1269 |
# File 'lib/aws-sdk-appconfig/client.rb', line 1266 def create_hosted_configuration_version(params = {}, = {}) req = build_request(:create_hosted_configuration_version, params) req.send_request() end |
#delete_application(params = {}) ⇒ Struct
Deletes an application.
1297 1298 1299 1300 |
# File 'lib/aws-sdk-appconfig/client.rb', line 1297 def delete_application(params = {}, = {}) req = build_request(:delete_application, params) req.send_request() end |
#delete_configuration_profile(params = {}) ⇒ Struct
Deletes a configuration profile.
To prevent users from unintentionally deleting actively-used configuration profiles, enable [deletion protection].
[1]: docs.aws.amazon.com/appconfig/latest/userguide/deletion-protection.html
1368 1369 1370 1371 |
# File 'lib/aws-sdk-appconfig/client.rb', line 1368 def delete_configuration_profile(params = {}, = {}) req = build_request(:delete_configuration_profile, params) req.send_request() end |
#delete_deployment_strategy(params = {}) ⇒ Struct
Deletes a deployment strategy.
1399 1400 1401 1402 |
# File 'lib/aws-sdk-appconfig/client.rb', line 1399 def delete_deployment_strategy(params = {}, = {}) req = build_request(:delete_deployment_strategy, params) req.send_request() end |
#delete_environment(params = {}) ⇒ Struct
Deletes an environment.
To prevent users from unintentionally deleting actively-used environments, enable [deletion protection].
[1]: docs.aws.amazon.com/appconfig/latest/userguide/deletion-protection.html
1470 1471 1472 1473 |
# File 'lib/aws-sdk-appconfig/client.rb', line 1470 def delete_environment(params = {}, = {}) req = build_request(:delete_environment, params) req.send_request() end |
#delete_extension(params = {}) ⇒ Struct
Deletes an AppConfig extension. You must delete all associations to an extension before you delete the extension.
1499 1500 1501 1502 |
# File 'lib/aws-sdk-appconfig/client.rb', line 1499 def delete_extension(params = {}, = {}) req = build_request(:delete_extension, params) req.send_request() end |
#delete_extension_association(params = {}) ⇒ Struct
Deletes an extension association. This action doesn’t delete extensions defined in the association.
1522 1523 1524 1525 |
# File 'lib/aws-sdk-appconfig/client.rb', line 1522 def delete_extension_association(params = {}, = {}) req = build_request(:delete_extension_association, params) req.send_request() end |
#delete_hosted_configuration_version(params = {}) ⇒ Struct
Deletes a version of a configuration from the AppConfig hosted configuration store.
1565 1566 1567 1568 |
# File 'lib/aws-sdk-appconfig/client.rb', line 1565 def delete_hosted_configuration_version(params = {}, = {}) req = build_request(:delete_hosted_configuration_version, params) req.send_request() end |
#get_account_settings(params = {}) ⇒ Types::AccountSettings
Returns information about the status of the ‘DeletionProtection` parameter.
1586 1587 1588 1589 |
# File 'lib/aws-sdk-appconfig/client.rb', line 1586 def get_account_settings(params = {}, = {}) req = build_request(:get_account_settings, params) req.send_request() end |
#get_application(params = {}) ⇒ Types::Application
Retrieves information about an application.
1633 1634 1635 1636 |
# File 'lib/aws-sdk-appconfig/client.rb', line 1633 def get_application(params = {}, = {}) req = build_request(:get_application, params) req.send_request() end |
#get_configuration(params = {}) ⇒ Types::Configuration
(Deprecated) Retrieves the latest deployed configuration.
Note the following important information.
* This API action is deprecated. Calls to receive configuration data
should use the [StartConfigurationSession][1] and
[GetLatestConfiguration][2] APIs instead.
-
GetConfiguration is a priced call. For more information, see [Pricing].
[1]: docs.aws.amazon.com/appconfig/2019-10-09/APIReference/API_appconfigdata_StartConfigurationSession.html [2]: docs.aws.amazon.com/appconfig/2019-10-09/APIReference/API_appconfigdata_GetLatestConfiguration.html [3]: aws.amazon.com/systems-manager/pricing/
1750 1751 1752 1753 |
# File 'lib/aws-sdk-appconfig/client.rb', line 1750 def get_configuration(params = {}, = {}) req = build_request(:get_configuration, params) req.send_request() end |
#get_configuration_profile(params = {}) ⇒ Types::ConfigurationProfile
Retrieves information about a configuration profile.
1822 1823 1824 1825 |
# File 'lib/aws-sdk-appconfig/client.rb', line 1822 def get_configuration_profile(params = {}, = {}) req = build_request(:get_configuration_profile, params) req.send_request() end |
#get_deployment(params = {}) ⇒ Types::Deployment
Retrieves information about a configuration deployment.
The following waiters are defined for this operation (see #wait_until for detailed usage):
* deployment_complete
2000 2001 2002 2003 |
# File 'lib/aws-sdk-appconfig/client.rb', line 2000 def get_deployment(params = {}, = {}) req = build_request(:get_deployment, params) req.send_request() end |
#get_deployment_strategy(params = {}) ⇒ Types::DeploymentStrategy
Retrieves information about a deployment strategy. A deployment strategy defines important criteria for rolling out your configuration to the designated targets. A deployment strategy includes the overall duration required, a percentage of targets to receive the deployment during each interval, an algorithm that defines how percentage grows, and bake time.
2067 2068 2069 2070 |
# File 'lib/aws-sdk-appconfig/client.rb', line 2067 def get_deployment_strategy(params = {}, = {}) req = build_request(:get_deployment_strategy, params) req.send_request() end |
#get_environment(params = {}) ⇒ Types::Environment
Retrieves information about an environment. An environment is a deployment group of AppConfig applications, such as applications in a ‘Production` environment or in an `EU_Region` environment. Each configuration deployment targets an environment. You can enable one or more Amazon CloudWatch alarms for an environment. If an alarm is triggered during a deployment, AppConfig roles back the configuration.
The following waiters are defined for this operation (see #wait_until for detailed usage):
* environment_ready_for_deployment
2140 2141 2142 2143 |
# File 'lib/aws-sdk-appconfig/client.rb', line 2140 def get_environment(params = {}, = {}) req = build_request(:get_environment, params) req.send_request() end |
#get_extension(params = {}) ⇒ Types::Extension
Returns information about an AppConfig extension.
2193 2194 2195 2196 |
# File 'lib/aws-sdk-appconfig/client.rb', line 2193 def get_extension(params = {}, = {}) req = build_request(:get_extension, params) req.send_request() end |
#get_extension_association(params = {}) ⇒ Types::ExtensionAssociation
Returns information about an AppConfig extension association. For more information about extensions and associations, see [Extending workflows] in the *AppConfig User Guide*.
[1]: docs.aws.amazon.com/appconfig/latest/userguide/working-with-appconfig-extensions.html
2238 2239 2240 2241 |
# File 'lib/aws-sdk-appconfig/client.rb', line 2238 def get_extension_association(params = {}, = {}) req = build_request(:get_extension_association, params) req.send_request() end |
#get_hosted_configuration_version(params = {}) ⇒ Types::HostedConfigurationVersion
Retrieves information about a specific configuration version.
2308 2309 2310 2311 |
# File 'lib/aws-sdk-appconfig/client.rb', line 2308 def get_hosted_configuration_version(params = {}, = {}) req = build_request(:get_hosted_configuration_version, params) req.send_request() end |
#list_applications(params = {}) ⇒ Types::Applications
Lists all applications in your Amazon Web Services account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2377 2378 2379 2380 |
# File 'lib/aws-sdk-appconfig/client.rb', line 2377 def list_applications(params = {}, = {}) req = build_request(:list_applications, params) req.send_request() end |
#list_configuration_profiles(params = {}) ⇒ Types::ConfigurationProfiles
Lists the configuration profiles for an application.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2455 2456 2457 2458 |
# File 'lib/aws-sdk-appconfig/client.rb', line 2455 def list_configuration_profiles(params = {}, = {}) req = build_request(:list_configuration_profiles, params) req.send_request() end |
#list_deployment_strategies(params = {}) ⇒ Types::DeploymentStrategies
Lists deployment strategies.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2525 2526 2527 2528 |
# File 'lib/aws-sdk-appconfig/client.rb', line 2525 def list_deployment_strategies(params = {}, = {}) req = build_request(:list_deployment_strategies, params) req.send_request() end |
#list_deployments(params = {}) ⇒ Types::Deployments
Lists the deployments for an environment in descending deployment number order.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2617 2618 2619 2620 |
# File 'lib/aws-sdk-appconfig/client.rb', line 2617 def list_deployments(params = {}, = {}) req = build_request(:list_deployments, params) req.send_request() end |
#list_environments(params = {}) ⇒ Types::Environments
Lists the environments for an application.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2690 2691 2692 2693 |
# File 'lib/aws-sdk-appconfig/client.rb', line 2690 def list_environments(params = {}, = {}) req = build_request(:list_environments, params) req.send_request() end |
#list_extension_associations(params = {}) ⇒ Types::ExtensionAssociations
Lists all AppConfig extension associations in the account. For more information about extensions and associations, see [Extending workflows] in the *AppConfig User Guide*.
[1]: docs.aws.amazon.com/appconfig/latest/userguide/working-with-appconfig-extensions.html
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2750 2751 2752 2753 |
# File 'lib/aws-sdk-appconfig/client.rb', line 2750 def list_extension_associations(params = {}, = {}) req = build_request(:list_extension_associations, params) req.send_request() end |
#list_extensions(params = {}) ⇒ Types::Extensions
Lists all custom and Amazon Web Services authored AppConfig extensions in the account. For more information about extensions, see [Extending workflows] in the *AppConfig User Guide*.
[1]: docs.aws.amazon.com/appconfig/latest/userguide/working-with-appconfig-extensions.html
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2804 2805 2806 2807 |
# File 'lib/aws-sdk-appconfig/client.rb', line 2804 def list_extensions(params = {}, = {}) req = build_request(:list_extensions, params) req.send_request() end |
#list_hosted_configuration_versions(params = {}) ⇒ Types::HostedConfigurationVersions
Lists configurations stored in the AppConfig hosted configuration store by version.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2891 2892 2893 2894 |
# File 'lib/aws-sdk-appconfig/client.rb', line 2891 def list_hosted_configuration_versions(params = {}, = {}) req = build_request(:list_hosted_configuration_versions, params) req.send_request() end |
#list_tags_for_resource(params = {}) ⇒ Types::ResourceTags
Retrieves the list of key-value tags assigned to the resource.
2936 2937 2938 2939 |
# File 'lib/aws-sdk-appconfig/client.rb', line 2936 def (params = {}, = {}) req = build_request(:list_tags_for_resource, params) req.send_request() end |
#start_deployment(params = {}) ⇒ Types::Deployment
Starts a deployment.
3111 3112 3113 3114 |
# File 'lib/aws-sdk-appconfig/client.rb', line 3111 def start_deployment(params = {}, = {}) req = build_request(:start_deployment, params) req.send_request() end |
#stop_deployment(params = {}) ⇒ Types::Deployment
Stops a deployment. This API action works only on deployments that have a status of ‘DEPLOYING`, unless an `AllowRevert` parameter is supplied. If the `AllowRevert` parameter is supplied, the status of an in-progress deployment will be `ROLLED_BACK`. The status of a completed deployment will be `REVERTED`. AppConfig only allows a revert within 72 hours of deployment completion.
3237 3238 3239 3240 |
# File 'lib/aws-sdk-appconfig/client.rb', line 3237 def stop_deployment(params = {}, = {}) req = build_request(:stop_deployment, params) req.send_request() end |
#tag_resource(params = {}) ⇒ Struct
Assigns metadata to an AppConfig resource. Tags help organize and categorize your AppConfig resources. Each tag consists of a key and an optional value, both of which you define. You can specify a maximum of 50 tags for a resource.
3282 3283 3284 3285 |
# File 'lib/aws-sdk-appconfig/client.rb', line 3282 def tag_resource(params = {}, = {}) req = build_request(:tag_resource, params) req.send_request() end |
#untag_resource(params = {}) ⇒ Struct
Deletes a tag key and value from an AppConfig resource.
3320 3321 3322 3323 |
# File 'lib/aws-sdk-appconfig/client.rb', line 3320 def untag_resource(params = {}, = {}) req = build_request(:untag_resource, params) req.send_request() end |
#update_account_settings(params = {}) ⇒ Types::AccountSettings
Updates the value of the ‘DeletionProtection` parameter.
3361 3362 3363 3364 |
# File 'lib/aws-sdk-appconfig/client.rb', line 3361 def update_account_settings(params = {}, = {}) req = build_request(:update_account_settings, params) req.send_request() end |
#update_application(params = {}) ⇒ Types::Application
Updates an application.
3419 3420 3421 3422 |
# File 'lib/aws-sdk-appconfig/client.rb', line 3419 def update_application(params = {}, = {}) req = build_request(:update_application, params) req.send_request() end |
#update_configuration_profile(params = {}) ⇒ Types::ConfigurationProfile
Updates a configuration profile.
3528 3529 3530 3531 |
# File 'lib/aws-sdk-appconfig/client.rb', line 3528 def update_configuration_profile(params = {}, = {}) req = build_request(:update_configuration_profile, params) req.send_request() end |
#update_deployment_strategy(params = {}) ⇒ Types::DeploymentStrategy
Updates a deployment strategy.
3641 3642 3643 3644 |
# File 'lib/aws-sdk-appconfig/client.rb', line 3641 def update_deployment_strategy(params = {}, = {}) req = build_request(:update_deployment_strategy, params) req.send_request() end |
#update_environment(params = {}) ⇒ Types::Environment
Updates an environment.
3722 3723 3724 3725 |
# File 'lib/aws-sdk-appconfig/client.rb', line 3722 def update_environment(params = {}, = {}) req = build_request(:update_environment, params) req.send_request() end |
#update_extension(params = {}) ⇒ Types::Extension
Updates an AppConfig extension. For more information about extensions, see [Extending workflows] in the *AppConfig User Guide*.
[1]: docs.aws.amazon.com/appconfig/latest/userguide/working-with-appconfig-extensions.html
3806 3807 3808 3809 |
# File 'lib/aws-sdk-appconfig/client.rb', line 3806 def update_extension(params = {}, = {}) req = build_request(:update_extension, params) req.send_request() end |
#update_extension_association(params = {}) ⇒ Types::ExtensionAssociation
Updates an association. For more information about extensions and associations, see [Extending workflows] in the *AppConfig User Guide*.
[1]: docs.aws.amazon.com/appconfig/latest/userguide/working-with-appconfig-extensions.html
3857 3858 3859 3860 |
# File 'lib/aws-sdk-appconfig/client.rb', line 3857 def update_extension_association(params = {}, = {}) req = build_request(:update_extension_association, params) req.send_request() end |
#validate_configuration(params = {}) ⇒ Struct
Uses the validators in a configuration profile to validate a configuration.
3899 3900 3901 3902 |
# File 'lib/aws-sdk-appconfig/client.rb', line 3899 def validate_configuration(params = {}, = {}) req = build_request(:validate_configuration, params) req.send_request() end |
#wait_until(waiter_name, params = {}, options = {}) {|w.waiter| ... } ⇒ Boolean
Polls an API operation until a resource enters a desired state.
## Basic Usage
A waiter will call an API operation until:
-
It is successful
-
It enters a terminal state
-
It makes the maximum number of attempts
In between attempts, the waiter will sleep.
# polls in a loop, sleeping between attempts
client.wait_until(waiter_name, params)
## Configuration
You can configure the maximum number of polling attempts, and the delay (in seconds) between each polling attempt. You can pass configuration as the final arguments hash.
# poll for ~25 seconds
client.wait_until(waiter_name, params, {
max_attempts: 5,
delay: 5,
})
## Callbacks
You can be notified before each polling attempt and before each delay. If you throw ‘:success` or `:failure` from these callbacks, it will terminate the waiter.
started_at = Time.now
client.wait_until(waiter_name, params, {
# disable max attempts
max_attempts: nil,
# poll for 1 hour, instead of a number of attempts
before_wait: -> (attempts, response) do
throw :failure if Time.now - started_at > 3600
end
})
## Handling Errors
When a waiter is unsuccessful, it will raise an error. All of the failure errors extend from Waiters::Errors::WaiterFailed.
begin
client.wait_until(...)
rescue Aws::Waiters::Errors::WaiterFailed
# resource did not enter the desired state in time
end
## Valid Waiters
The following table lists the valid waiter names, the operations they call, and the default ‘:delay` and `:max_attempts` values.
| waiter_name | params | :delay | :max_attempts | | ——————————– | ———————— | ——– | ————- | | deployment_complete | #get_deployment | 30 | 999 | | environment_ready_for_deployment | #get_environment | 30 | 999 |
4015 4016 4017 4018 4019 |
# File 'lib/aws-sdk-appconfig/client.rb', line 4015 def wait_until(waiter_name, params = {}, = {}) w = waiter(waiter_name, ) yield(w.waiter) if block_given? # deprecated w.wait(params) end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
4023 4024 4025 |
# File 'lib/aws-sdk-appconfig/client.rb', line 4023 def waiter_names waiters.keys end |