Method: Aws::AppConfig::Client#get_environment
- Defined in:
- lib/aws-sdk-appconfig/client.rb
#get_environment(params = {}) ⇒ Types::Environment
Retrieves information about an environment. An environment is a deployment group of AppConfig applications, such as applications in a Production environment or in an EU_Region environment. Each configuration deployment targets an environment. You can enable one or more Amazon CloudWatch alarms for an environment. If an alarm is triggered during a deployment, AppConfig roles back the configuration.
The following waiters are defined for this operation (see #wait_until for detailed usage):
* environment_ready_for_deployment
2142 2143 2144 2145 |
# File 'lib/aws-sdk-appconfig/client.rb', line 2142 def get_environment(params = {}, = {}) req = build_request(:get_environment, params) req.send_request() end |