Class: Aws::AppConfig::Types::ActionInvocation

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-appconfig/types.rb

Overview

An extension that was invoked as part of a deployment event.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#action_nameString

The name of the action.



106
107
108
109
110
111
112
113
114
115
116
# File 'lib/aws-sdk-appconfig/types.rb', line 106

class ActionInvocation < Struct.new(
  :extension_identifier,
  :action_name,
  :uri,
  :role_arn,
  :error_message,
  :error_code,
  :invocation_id)
  SENSITIVE = []
  include Aws::Structure
end

#error_codeString

The error code when an extension invocation fails.



106
107
108
109
110
111
112
113
114
115
116
# File 'lib/aws-sdk-appconfig/types.rb', line 106

class ActionInvocation < Struct.new(
  :extension_identifier,
  :action_name,
  :uri,
  :role_arn,
  :error_message,
  :error_code,
  :invocation_id)
  SENSITIVE = []
  include Aws::Structure
end

#error_messageString

The error message when an extension invocation fails.



106
107
108
109
110
111
112
113
114
115
116
# File 'lib/aws-sdk-appconfig/types.rb', line 106

class ActionInvocation < Struct.new(
  :extension_identifier,
  :action_name,
  :uri,
  :role_arn,
  :error_message,
  :error_code,
  :invocation_id)
  SENSITIVE = []
  include Aws::Structure
end

#extension_identifierString

The name, the ID, or the Amazon Resource Name (ARN) of the extension.



106
107
108
109
110
111
112
113
114
115
116
# File 'lib/aws-sdk-appconfig/types.rb', line 106

class ActionInvocation < Struct.new(
  :extension_identifier,
  :action_name,
  :uri,
  :role_arn,
  :error_message,
  :error_code,
  :invocation_id)
  SENSITIVE = []
  include Aws::Structure
end

#invocation_idString

A system-generated ID for this invocation.



106
107
108
109
110
111
112
113
114
115
116
# File 'lib/aws-sdk-appconfig/types.rb', line 106

class ActionInvocation < Struct.new(
  :extension_identifier,
  :action_name,
  :uri,
  :role_arn,
  :error_message,
  :error_code,
  :invocation_id)
  SENSITIVE = []
  include Aws::Structure
end

#role_arnString

An Amazon Resource Name (ARN) for an Identity and Access Management assume role.



106
107
108
109
110
111
112
113
114
115
116
# File 'lib/aws-sdk-appconfig/types.rb', line 106

class ActionInvocation < Struct.new(
  :extension_identifier,
  :action_name,
  :uri,
  :role_arn,
  :error_message,
  :error_code,
  :invocation_id)
  SENSITIVE = []
  include Aws::Structure
end

#uriString

The extension URI associated to the action point in the extension definition. The URI can be an Amazon Resource Name (ARN) for one of the following: an Lambda function, an Amazon Simple Queue Service queue, an Amazon Simple Notification Service topic, or the Amazon EventBridge default event bus.



106
107
108
109
110
111
112
113
114
115
116
# File 'lib/aws-sdk-appconfig/types.rb', line 106

class ActionInvocation < Struct.new(
  :extension_identifier,
  :action_name,
  :uri,
  :role_arn,
  :error_message,
  :error_code,
  :invocation_id)
  SENSITIVE = []
  include Aws::Structure
end