Class: Aws::AppConfig::Types::CreateExperimentDefinitionRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::AppConfig::Types::CreateExperimentDefinitionRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-appconfig/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#application_identifier ⇒ String
The application ID or name.
-
#audience_description ⇒ String
A description of the intended audience for the experiment.
-
#audience_rule ⇒ String
A rule that defines which users are eligible to be assigned to treatments during the experiment.
-
#configuration_profile_identifier ⇒ String
The configuration profile ID or name that stores the feature flag.
-
#control ⇒ Types::TreatmentInput
The control treatment that represents the baseline experience for comparison.
-
#environment_identifier ⇒ String
The environment ID or name where the experiment will run.
-
#flag_key ⇒ String
The key of the existing feature flag to use with the experiment.
-
#hypothesis ⇒ String
A description of the goal or hypothesis the experiment is designed to validate.
-
#launch_criteria ⇒ String
Information about the conditions under which you would launch the winning treatment.
-
#name ⇒ String
A name for the experiment definition.
-
#tags ⇒ Hash<String,String>
The tags to assign to the experiment definition.
-
#treatments ⇒ Array<Types::TreatmentInput>
A list of treatments to evaluate during the experiment.
Instance Attribute Details
#application_identifier ⇒ String
The application ID or name.
805 806 807 808 809 810 811 812 813 814 815 816 817 818 819 820 |
# File 'lib/aws-sdk-appconfig/types.rb', line 805 class CreateExperimentDefinitionRequest < Struct.new( :application_identifier, :name, :configuration_profile_identifier, :environment_identifier, :flag_key, :treatments, :control, :audience_rule, :hypothesis, :audience_description, :launch_criteria, :tags) SENSITIVE = [] include Aws::Structure end |
#audience_description ⇒ String
A description of the intended audience for the experiment.
805 806 807 808 809 810 811 812 813 814 815 816 817 818 819 820 |
# File 'lib/aws-sdk-appconfig/types.rb', line 805 class CreateExperimentDefinitionRequest < Struct.new( :application_identifier, :name, :configuration_profile_identifier, :environment_identifier, :flag_key, :treatments, :control, :audience_rule, :hypothesis, :audience_description, :launch_criteria, :tags) SENSITIVE = [] include Aws::Structure end |
#audience_rule ⇒ String
A rule that defines which users are eligible to be assigned to treatments during the experiment.
805 806 807 808 809 810 811 812 813 814 815 816 817 818 819 820 |
# File 'lib/aws-sdk-appconfig/types.rb', line 805 class CreateExperimentDefinitionRequest < Struct.new( :application_identifier, :name, :configuration_profile_identifier, :environment_identifier, :flag_key, :treatments, :control, :audience_rule, :hypothesis, :audience_description, :launch_criteria, :tags) SENSITIVE = [] include Aws::Structure end |
#configuration_profile_identifier ⇒ String
The configuration profile ID or name that stores the feature flag.
805 806 807 808 809 810 811 812 813 814 815 816 817 818 819 820 |
# File 'lib/aws-sdk-appconfig/types.rb', line 805 class CreateExperimentDefinitionRequest < Struct.new( :application_identifier, :name, :configuration_profile_identifier, :environment_identifier, :flag_key, :treatments, :control, :audience_rule, :hypothesis, :audience_description, :launch_criteria, :tags) SENSITIVE = [] include Aws::Structure end |
#control ⇒ Types::TreatmentInput
The control treatment that represents the baseline experience for comparison.
805 806 807 808 809 810 811 812 813 814 815 816 817 818 819 820 |
# File 'lib/aws-sdk-appconfig/types.rb', line 805 class CreateExperimentDefinitionRequest < Struct.new( :application_identifier, :name, :configuration_profile_identifier, :environment_identifier, :flag_key, :treatments, :control, :audience_rule, :hypothesis, :audience_description, :launch_criteria, :tags) SENSITIVE = [] include Aws::Structure end |
#environment_identifier ⇒ String
The environment ID or name where the experiment will run.
805 806 807 808 809 810 811 812 813 814 815 816 817 818 819 820 |
# File 'lib/aws-sdk-appconfig/types.rb', line 805 class CreateExperimentDefinitionRequest < Struct.new( :application_identifier, :name, :configuration_profile_identifier, :environment_identifier, :flag_key, :treatments, :control, :audience_rule, :hypothesis, :audience_description, :launch_criteria, :tags) SENSITIVE = [] include Aws::Structure end |
#flag_key ⇒ String
The key of the existing feature flag to use with the experiment.
805 806 807 808 809 810 811 812 813 814 815 816 817 818 819 820 |
# File 'lib/aws-sdk-appconfig/types.rb', line 805 class CreateExperimentDefinitionRequest < Struct.new( :application_identifier, :name, :configuration_profile_identifier, :environment_identifier, :flag_key, :treatments, :control, :audience_rule, :hypothesis, :audience_description, :launch_criteria, :tags) SENSITIVE = [] include Aws::Structure end |
#hypothesis ⇒ String
A description of the goal or hypothesis the experiment is designed to validate.
805 806 807 808 809 810 811 812 813 814 815 816 817 818 819 820 |
# File 'lib/aws-sdk-appconfig/types.rb', line 805 class CreateExperimentDefinitionRequest < Struct.new( :application_identifier, :name, :configuration_profile_identifier, :environment_identifier, :flag_key, :treatments, :control, :audience_rule, :hypothesis, :audience_description, :launch_criteria, :tags) SENSITIVE = [] include Aws::Structure end |
#launch_criteria ⇒ String
Information about the conditions under which you would launch the winning treatment.
805 806 807 808 809 810 811 812 813 814 815 816 817 818 819 820 |
# File 'lib/aws-sdk-appconfig/types.rb', line 805 class CreateExperimentDefinitionRequest < Struct.new( :application_identifier, :name, :configuration_profile_identifier, :environment_identifier, :flag_key, :treatments, :control, :audience_rule, :hypothesis, :audience_description, :launch_criteria, :tags) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
A name for the experiment definition.
805 806 807 808 809 810 811 812 813 814 815 816 817 818 819 820 |
# File 'lib/aws-sdk-appconfig/types.rb', line 805 class CreateExperimentDefinitionRequest < Struct.new( :application_identifier, :name, :configuration_profile_identifier, :environment_identifier, :flag_key, :treatments, :control, :audience_rule, :hypothesis, :audience_description, :launch_criteria, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags to assign to the experiment definition. Tags help organize and categorize your AppConfig resources.
805 806 807 808 809 810 811 812 813 814 815 816 817 818 819 820 |
# File 'lib/aws-sdk-appconfig/types.rb', line 805 class CreateExperimentDefinitionRequest < Struct.new( :application_identifier, :name, :configuration_profile_identifier, :environment_identifier, :flag_key, :treatments, :control, :audience_rule, :hypothesis, :audience_description, :launch_criteria, :tags) SENSITIVE = [] include Aws::Structure end |
#treatments ⇒ Array<Types::TreatmentInput>
A list of treatments to evaluate during the experiment. Each treatment defines a distinct variation compared to the control.
805 806 807 808 809 810 811 812 813 814 815 816 817 818 819 820 |
# File 'lib/aws-sdk-appconfig/types.rb', line 805 class CreateExperimentDefinitionRequest < Struct.new( :application_identifier, :name, :configuration_profile_identifier, :environment_identifier, :flag_key, :treatments, :control, :audience_rule, :hypothesis, :audience_description, :launch_criteria, :tags) SENSITIVE = [] include Aws::Structure end |