Class: Aws::AppConfig::Types::CreateHostedConfigurationVersionRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-appconfig/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:content]

Instance Attribute Summary collapse

Instance Attribute Details

#application_idString

The application ID.



784
785
786
787
788
789
790
791
792
793
794
# File 'lib/aws-sdk-appconfig/types.rb', line 784

class CreateHostedConfigurationVersionRequest < Struct.new(
  :application_id,
  :configuration_profile_id,
  :description,
  :content,
  :content_type,
  :latest_version_number,
  :version_label)
  SENSITIVE = [:content]
  include Aws::Structure
end

#configuration_profile_idString

The configuration profile ID.



784
785
786
787
788
789
790
791
792
793
794
# File 'lib/aws-sdk-appconfig/types.rb', line 784

class CreateHostedConfigurationVersionRequest < Struct.new(
  :application_id,
  :configuration_profile_id,
  :description,
  :content,
  :content_type,
  :latest_version_number,
  :version_label)
  SENSITIVE = [:content]
  include Aws::Structure
end

#contentString

The content of the configuration or the configuration data.



784
785
786
787
788
789
790
791
792
793
794
# File 'lib/aws-sdk-appconfig/types.rb', line 784

class CreateHostedConfigurationVersionRequest < Struct.new(
  :application_id,
  :configuration_profile_id,
  :description,
  :content,
  :content_type,
  :latest_version_number,
  :version_label)
  SENSITIVE = [:content]
  include Aws::Structure
end

#content_typeString

A standard MIME type describing the format of the configuration content. For more information, see [Content-Type].

[1]: www.w3.org/Protocols/rfc2616/rfc2616-sec14.html#sec14.17



784
785
786
787
788
789
790
791
792
793
794
# File 'lib/aws-sdk-appconfig/types.rb', line 784

class CreateHostedConfigurationVersionRequest < Struct.new(
  :application_id,
  :configuration_profile_id,
  :description,
  :content,
  :content_type,
  :latest_version_number,
  :version_label)
  SENSITIVE = [:content]
  include Aws::Structure
end

#descriptionString

A description of the configuration.



784
785
786
787
788
789
790
791
792
793
794
# File 'lib/aws-sdk-appconfig/types.rb', line 784

class CreateHostedConfigurationVersionRequest < Struct.new(
  :application_id,
  :configuration_profile_id,
  :description,
  :content,
  :content_type,
  :latest_version_number,
  :version_label)
  SENSITIVE = [:content]
  include Aws::Structure
end

#latest_version_numberInteger

An optional locking token used to prevent race conditions from overwriting configuration updates when creating a new version. To ensure your data is not overwritten when creating multiple hosted configuration versions in rapid succession, specify the version number of the latest hosted configuration version.



784
785
786
787
788
789
790
791
792
793
794
# File 'lib/aws-sdk-appconfig/types.rb', line 784

class CreateHostedConfigurationVersionRequest < Struct.new(
  :application_id,
  :configuration_profile_id,
  :description,
  :content,
  :content_type,
  :latest_version_number,
  :version_label)
  SENSITIVE = [:content]
  include Aws::Structure
end

#version_labelString

An optional, user-defined label for the AppConfig hosted configuration version. This value must contain at least one non-numeric character. For example, “v2.2.0”.



784
785
786
787
788
789
790
791
792
793
794
# File 'lib/aws-sdk-appconfig/types.rb', line 784

class CreateHostedConfigurationVersionRequest < Struct.new(
  :application_id,
  :configuration_profile_id,
  :description,
  :content,
  :content_type,
  :latest_version_number,
  :version_label)
  SENSITIVE = [:content]
  include Aws::Structure
end