Class: Aws::AppConfig::Types::ExperimentDefinitionSnapshot
- Inherits:
-
Struct
- Object
- Struct
- Aws::AppConfig::Types::ExperimentDefinitionSnapshot
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-appconfig/types.rb
Overview
A snapshot of the experiment definition captured at the time an experiment run was started. This preserves the configuration that was active during the run.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#application_id ⇒ String
The application ID at the time the run was started.
-
#audience_description ⇒ String
The audience description at the time the run was started.
-
#audience_rule ⇒ String
The audience rule at the time the run was started.
-
#configuration_profile_id ⇒ String
The configuration profile ID at the time the run was started.
-
#control ⇒ Types::Treatment
The control treatment at the time the run was started.
-
#environment_id ⇒ String
The environment ID at the time the run was started.
-
#flag_key ⇒ String
The feature flag key at the time the run was started.
-
#hypothesis ⇒ String
The hypothesis at the time the run was started.
-
#id ⇒ String
The experiment definition ID.
-
#launch_criteria ⇒ String
The launch criteria at the time the run was started.
-
#name ⇒ String
The name of the experiment definition at the time the run was started.
-
#treatments ⇒ Array<Types::Treatment>
The treatments at the time the run was started.
Instance Attribute Details
#application_id ⇒ String
The application ID at the time the run was started.
1773 1774 1775 1776 1777 1778 1779 1780 1781 1782 1783 1784 1785 1786 1787 1788 |
# File 'lib/aws-sdk-appconfig/types.rb', line 1773 class ExperimentDefinitionSnapshot < Struct.new( :application_id, :id, :name, :hypothesis, :configuration_profile_id, :environment_id, :flag_key, :audience_rule, :audience_description, :launch_criteria, :treatments, :control) SENSITIVE = [] include Aws::Structure end |
#audience_description ⇒ String
The audience description at the time the run was started.
1773 1774 1775 1776 1777 1778 1779 1780 1781 1782 1783 1784 1785 1786 1787 1788 |
# File 'lib/aws-sdk-appconfig/types.rb', line 1773 class ExperimentDefinitionSnapshot < Struct.new( :application_id, :id, :name, :hypothesis, :configuration_profile_id, :environment_id, :flag_key, :audience_rule, :audience_description, :launch_criteria, :treatments, :control) SENSITIVE = [] include Aws::Structure end |
#audience_rule ⇒ String
The audience rule at the time the run was started.
1773 1774 1775 1776 1777 1778 1779 1780 1781 1782 1783 1784 1785 1786 1787 1788 |
# File 'lib/aws-sdk-appconfig/types.rb', line 1773 class ExperimentDefinitionSnapshot < Struct.new( :application_id, :id, :name, :hypothesis, :configuration_profile_id, :environment_id, :flag_key, :audience_rule, :audience_description, :launch_criteria, :treatments, :control) SENSITIVE = [] include Aws::Structure end |
#configuration_profile_id ⇒ String
The configuration profile ID at the time the run was started.
1773 1774 1775 1776 1777 1778 1779 1780 1781 1782 1783 1784 1785 1786 1787 1788 |
# File 'lib/aws-sdk-appconfig/types.rb', line 1773 class ExperimentDefinitionSnapshot < Struct.new( :application_id, :id, :name, :hypothesis, :configuration_profile_id, :environment_id, :flag_key, :audience_rule, :audience_description, :launch_criteria, :treatments, :control) SENSITIVE = [] include Aws::Structure end |
#control ⇒ Types::Treatment
The control treatment at the time the run was started.
1773 1774 1775 1776 1777 1778 1779 1780 1781 1782 1783 1784 1785 1786 1787 1788 |
# File 'lib/aws-sdk-appconfig/types.rb', line 1773 class ExperimentDefinitionSnapshot < Struct.new( :application_id, :id, :name, :hypothesis, :configuration_profile_id, :environment_id, :flag_key, :audience_rule, :audience_description, :launch_criteria, :treatments, :control) SENSITIVE = [] include Aws::Structure end |
#environment_id ⇒ String
The environment ID at the time the run was started.
1773 1774 1775 1776 1777 1778 1779 1780 1781 1782 1783 1784 1785 1786 1787 1788 |
# File 'lib/aws-sdk-appconfig/types.rb', line 1773 class ExperimentDefinitionSnapshot < Struct.new( :application_id, :id, :name, :hypothesis, :configuration_profile_id, :environment_id, :flag_key, :audience_rule, :audience_description, :launch_criteria, :treatments, :control) SENSITIVE = [] include Aws::Structure end |
#flag_key ⇒ String
The feature flag key at the time the run was started.
1773 1774 1775 1776 1777 1778 1779 1780 1781 1782 1783 1784 1785 1786 1787 1788 |
# File 'lib/aws-sdk-appconfig/types.rb', line 1773 class ExperimentDefinitionSnapshot < Struct.new( :application_id, :id, :name, :hypothesis, :configuration_profile_id, :environment_id, :flag_key, :audience_rule, :audience_description, :launch_criteria, :treatments, :control) SENSITIVE = [] include Aws::Structure end |
#hypothesis ⇒ String
The hypothesis at the time the run was started.
1773 1774 1775 1776 1777 1778 1779 1780 1781 1782 1783 1784 1785 1786 1787 1788 |
# File 'lib/aws-sdk-appconfig/types.rb', line 1773 class ExperimentDefinitionSnapshot < Struct.new( :application_id, :id, :name, :hypothesis, :configuration_profile_id, :environment_id, :flag_key, :audience_rule, :audience_description, :launch_criteria, :treatments, :control) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The experiment definition ID.
1773 1774 1775 1776 1777 1778 1779 1780 1781 1782 1783 1784 1785 1786 1787 1788 |
# File 'lib/aws-sdk-appconfig/types.rb', line 1773 class ExperimentDefinitionSnapshot < Struct.new( :application_id, :id, :name, :hypothesis, :configuration_profile_id, :environment_id, :flag_key, :audience_rule, :audience_description, :launch_criteria, :treatments, :control) SENSITIVE = [] include Aws::Structure end |
#launch_criteria ⇒ String
The launch criteria at the time the run was started.
1773 1774 1775 1776 1777 1778 1779 1780 1781 1782 1783 1784 1785 1786 1787 1788 |
# File 'lib/aws-sdk-appconfig/types.rb', line 1773 class ExperimentDefinitionSnapshot < Struct.new( :application_id, :id, :name, :hypothesis, :configuration_profile_id, :environment_id, :flag_key, :audience_rule, :audience_description, :launch_criteria, :treatments, :control) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the experiment definition at the time the run was started.
1773 1774 1775 1776 1777 1778 1779 1780 1781 1782 1783 1784 1785 1786 1787 1788 |
# File 'lib/aws-sdk-appconfig/types.rb', line 1773 class ExperimentDefinitionSnapshot < Struct.new( :application_id, :id, :name, :hypothesis, :configuration_profile_id, :environment_id, :flag_key, :audience_rule, :audience_description, :launch_criteria, :treatments, :control) SENSITIVE = [] include Aws::Structure end |
#treatments ⇒ Array<Types::Treatment>
The treatments at the time the run was started.
1773 1774 1775 1776 1777 1778 1779 1780 1781 1782 1783 1784 1785 1786 1787 1788 |
# File 'lib/aws-sdk-appconfig/types.rb', line 1773 class ExperimentDefinitionSnapshot < Struct.new( :application_id, :id, :name, :hypothesis, :configuration_profile_id, :environment_id, :flag_key, :audience_rule, :audience_description, :launch_criteria, :treatments, :control) SENSITIVE = [] include Aws::Structure end |