Class: Aws::AppConfig::Types::ExperimentRunEvent
- Inherits:
-
Struct
- Object
- Struct
- Aws::AppConfig::Types::ExperimentRunEvent
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-appconfig/types.rb
Overview
Describes an event that occurred during an experiment run.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#associated_deployment ⇒ String
The Amazon Resource Name (ARN) of the deployment associated with this event.
-
#description ⇒ String
A description of the event.
-
#event_type ⇒ String
The type of event.
-
#exposure_percentage ⇒ Float
The exposure percentage at the time of the event.
-
#occurred_at ⇒ Time
The date and time the event occurred, in ISO 8601 format.
-
#treatment_overrides ⇒ Types::TreatmentOverrides
The treatment overrides at the time of the event.
-
#triggered_by ⇒ String
The principal that triggered the event.
Instance Attribute Details
#associated_deployment ⇒ String
The Amazon Resource Name (ARN) of the deployment associated with this event.
1979 1980 1981 1982 1983 1984 1985 1986 1987 1988 1989 |
# File 'lib/aws-sdk-appconfig/types.rb', line 1979 class ExperimentRunEvent < Struct.new( :description, :associated_deployment, :event_type, :occurred_at, :triggered_by, :exposure_percentage, :treatment_overrides) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A description of the event.
1979 1980 1981 1982 1983 1984 1985 1986 1987 1988 1989 |
# File 'lib/aws-sdk-appconfig/types.rb', line 1979 class ExperimentRunEvent < Struct.new( :description, :associated_deployment, :event_type, :occurred_at, :triggered_by, :exposure_percentage, :treatment_overrides) SENSITIVE = [] include Aws::Structure end |
#event_type ⇒ String
The type of event. Valid values: RUN_STARTED, EXPOSURE_UPDATED,
OVERRIDES_UPDATED, RUN_STOPPED.
1979 1980 1981 1982 1983 1984 1985 1986 1987 1988 1989 |
# File 'lib/aws-sdk-appconfig/types.rb', line 1979 class ExperimentRunEvent < Struct.new( :description, :associated_deployment, :event_type, :occurred_at, :triggered_by, :exposure_percentage, :treatment_overrides) SENSITIVE = [] include Aws::Structure end |
#exposure_percentage ⇒ Float
The exposure percentage at the time of the event.
1979 1980 1981 1982 1983 1984 1985 1986 1987 1988 1989 |
# File 'lib/aws-sdk-appconfig/types.rb', line 1979 class ExperimentRunEvent < Struct.new( :description, :associated_deployment, :event_type, :occurred_at, :triggered_by, :exposure_percentage, :treatment_overrides) SENSITIVE = [] include Aws::Structure end |
#occurred_at ⇒ Time
The date and time the event occurred, in ISO 8601 format.
1979 1980 1981 1982 1983 1984 1985 1986 1987 1988 1989 |
# File 'lib/aws-sdk-appconfig/types.rb', line 1979 class ExperimentRunEvent < Struct.new( :description, :associated_deployment, :event_type, :occurred_at, :triggered_by, :exposure_percentage, :treatment_overrides) SENSITIVE = [] include Aws::Structure end |
#treatment_overrides ⇒ Types::TreatmentOverrides
The treatment overrides at the time of the event.
1979 1980 1981 1982 1983 1984 1985 1986 1987 1988 1989 |
# File 'lib/aws-sdk-appconfig/types.rb', line 1979 class ExperimentRunEvent < Struct.new( :description, :associated_deployment, :event_type, :occurred_at, :triggered_by, :exposure_percentage, :treatment_overrides) SENSITIVE = [] include Aws::Structure end |
#triggered_by ⇒ String
The principal that triggered the event.
1979 1980 1981 1982 1983 1984 1985 1986 1987 1988 1989 |
# File 'lib/aws-sdk-appconfig/types.rb', line 1979 class ExperimentRunEvent < Struct.new( :description, :associated_deployment, :event_type, :occurred_at, :triggered_by, :exposure_percentage, :treatment_overrides) SENSITIVE = [] include Aws::Structure end |