Class: Aws::AppConfig::Types::ExperimentRunEvents
- Inherits:
-
Struct
- Object
- Struct
- Aws::AppConfig::Types::ExperimentRunEvents
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-appconfig/types.rb
Overview
The response for a list experiment run events request.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#items ⇒ Array<Types::ExperimentRunEvent>
The list of experiment run events.
-
#next_token ⇒ String
A token to use for the next set of results.
Instance Attribute Details
#items ⇒ Array<Types::ExperimentRunEvent>
The list of experiment run events.
2003 2004 2005 2006 2007 2008 |
# File 'lib/aws-sdk-appconfig/types.rb', line 2003 class ExperimentRunEvents < Struct.new( :items, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
A token to use for the next set of results.
2003 2004 2005 2006 2007 2008 |
# File 'lib/aws-sdk-appconfig/types.rb', line 2003 class ExperimentRunEvents < Struct.new( :items, :next_token) SENSITIVE = [] include Aws::Structure end |