Class: Aws::AppConfig::Types::ExperimentRunResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::AppConfig::Types::ExperimentRunResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-appconfig/types.rb
Overview
The result of an experiment run, including the executive summary and launch decision rationale.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#executive_summary ⇒ String
A summary of the experiment outcome and key findings.
-
#reasons_not_to_launch ⇒ String
Evidence against launching the treatment.
-
#reasons_to_launch ⇒ String
Evidence in favor of launching the winning treatment.
Instance Attribute Details
#executive_summary ⇒ String
A summary of the experiment outcome and key findings.
2027 2028 2029 2030 2031 2032 2033 |
# File 'lib/aws-sdk-appconfig/types.rb', line 2027 class ExperimentRunResult < Struct.new( :executive_summary, :reasons_to_launch, :reasons_not_to_launch) SENSITIVE = [] include Aws::Structure end |
#reasons_not_to_launch ⇒ String
Evidence against launching the treatment.
2027 2028 2029 2030 2031 2032 2033 |
# File 'lib/aws-sdk-appconfig/types.rb', line 2027 class ExperimentRunResult < Struct.new( :executive_summary, :reasons_to_launch, :reasons_not_to_launch) SENSITIVE = [] include Aws::Structure end |
#reasons_to_launch ⇒ String
Evidence in favor of launching the winning treatment.
2027 2028 2029 2030 2031 2032 2033 |
# File 'lib/aws-sdk-appconfig/types.rb', line 2027 class ExperimentRunResult < Struct.new( :executive_summary, :reasons_to_launch, :reasons_not_to_launch) SENSITIVE = [] include Aws::Structure end |