Class: Aws::AppConfig::Types::ExperimentRunSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::AppConfig::Types::ExperimentRunSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-appconfig/types.rb
Overview
Summary information about an experiment run.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#description ⇒ String
A description of the experiment run.
-
#ended_at ⇒ Time
The date and time the experiment run ended, in ISO 8601 format.
-
#experiment_definition_id ⇒ String
The experiment definition ID.
-
#run ⇒ Integer
The experiment run number.
-
#started_at ⇒ Time
The date and time the experiment run started, in ISO 8601 format.
-
#status ⇒ String
The current status of the experiment run.
-
#updated_at ⇒ Time
The date and time the experiment run was last updated, in ISO 8601 format.
Instance Attribute Details
#description ⇒ String
A description of the experiment run.
2068 2069 2070 2071 2072 2073 2074 2075 2076 2077 2078 |
# File 'lib/aws-sdk-appconfig/types.rb', line 2068 class ExperimentRunSummary < Struct.new( :experiment_definition_id, :run, :description, :status, :started_at, :updated_at, :ended_at) SENSITIVE = [] include Aws::Structure end |
#ended_at ⇒ Time
The date and time the experiment run ended, in ISO 8601 format.
2068 2069 2070 2071 2072 2073 2074 2075 2076 2077 2078 |
# File 'lib/aws-sdk-appconfig/types.rb', line 2068 class ExperimentRunSummary < Struct.new( :experiment_definition_id, :run, :description, :status, :started_at, :updated_at, :ended_at) SENSITIVE = [] include Aws::Structure end |
#experiment_definition_id ⇒ String
The experiment definition ID.
2068 2069 2070 2071 2072 2073 2074 2075 2076 2077 2078 |
# File 'lib/aws-sdk-appconfig/types.rb', line 2068 class ExperimentRunSummary < Struct.new( :experiment_definition_id, :run, :description, :status, :started_at, :updated_at, :ended_at) SENSITIVE = [] include Aws::Structure end |
#run ⇒ Integer
The experiment run number.
2068 2069 2070 2071 2072 2073 2074 2075 2076 2077 2078 |
# File 'lib/aws-sdk-appconfig/types.rb', line 2068 class ExperimentRunSummary < Struct.new( :experiment_definition_id, :run, :description, :status, :started_at, :updated_at, :ended_at) SENSITIVE = [] include Aws::Structure end |
#started_at ⇒ Time
The date and time the experiment run started, in ISO 8601 format.
2068 2069 2070 2071 2072 2073 2074 2075 2076 2077 2078 |
# File 'lib/aws-sdk-appconfig/types.rb', line 2068 class ExperimentRunSummary < Struct.new( :experiment_definition_id, :run, :description, :status, :started_at, :updated_at, :ended_at) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The current status of the experiment run.
2068 2069 2070 2071 2072 2073 2074 2075 2076 2077 2078 |
# File 'lib/aws-sdk-appconfig/types.rb', line 2068 class ExperimentRunSummary < Struct.new( :experiment_definition_id, :run, :description, :status, :started_at, :updated_at, :ended_at) SENSITIVE = [] include Aws::Structure end |
#updated_at ⇒ Time
The date and time the experiment run was last updated, in ISO 8601 format.
2068 2069 2070 2071 2072 2073 2074 2075 2076 2077 2078 |
# File 'lib/aws-sdk-appconfig/types.rb', line 2068 class ExperimentRunSummary < Struct.new( :experiment_definition_id, :run, :description, :status, :started_at, :updated_at, :ended_at) SENSITIVE = [] include Aws::Structure end |