Class: Aws::AppConfig::Types::Extension
- Inherits:
-
Struct
- Object
- Struct
- Aws::AppConfig::Types::Extension
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-appconfig/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#actions ⇒ Hash<String,Array<Types::Action>>
The actions defined in the extension.
-
#arn ⇒ String
The system-generated Amazon Resource Name (ARN) for the extension.
-
#description ⇒ String
Information about the extension.
-
#id ⇒ String
The system-generated ID of the extension.
-
#name ⇒ String
The extension name.
-
#parameters ⇒ Hash<String,Types::Parameter>
The parameters accepted by the extension.
-
#version_number ⇒ Integer
The extension version number.
Instance Attribute Details
#actions ⇒ Hash<String,Array<Types::Action>>
The actions defined in the extension.
2133 2134 2135 2136 2137 2138 2139 2140 2141 2142 2143 |
# File 'lib/aws-sdk-appconfig/types.rb', line 2133 class Extension < Struct.new( :id, :name, :version_number, :arn, :description, :actions, :parameters) SENSITIVE = [] include Aws::Structure end |
#arn ⇒ String
The system-generated Amazon Resource Name (ARN) for the extension.
2133 2134 2135 2136 2137 2138 2139 2140 2141 2142 2143 |
# File 'lib/aws-sdk-appconfig/types.rb', line 2133 class Extension < Struct.new( :id, :name, :version_number, :arn, :description, :actions, :parameters) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
Information about the extension.
2133 2134 2135 2136 2137 2138 2139 2140 2141 2142 2143 |
# File 'lib/aws-sdk-appconfig/types.rb', line 2133 class Extension < Struct.new( :id, :name, :version_number, :arn, :description, :actions, :parameters) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The system-generated ID of the extension.
2133 2134 2135 2136 2137 2138 2139 2140 2141 2142 2143 |
# File 'lib/aws-sdk-appconfig/types.rb', line 2133 class Extension < Struct.new( :id, :name, :version_number, :arn, :description, :actions, :parameters) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The extension name.
2133 2134 2135 2136 2137 2138 2139 2140 2141 2142 2143 |
# File 'lib/aws-sdk-appconfig/types.rb', line 2133 class Extension < Struct.new( :id, :name, :version_number, :arn, :description, :actions, :parameters) SENSITIVE = [] include Aws::Structure end |
#parameters ⇒ Hash<String,Types::Parameter>
The parameters accepted by the extension. You specify parameter
values when you associate the extension to an AppConfig resource by
using the CreateExtensionAssociation API action. For Lambda
extension actions, these parameters are included in the Lambda
request object.
2133 2134 2135 2136 2137 2138 2139 2140 2141 2142 2143 |
# File 'lib/aws-sdk-appconfig/types.rb', line 2133 class Extension < Struct.new( :id, :name, :version_number, :arn, :description, :actions, :parameters) SENSITIVE = [] include Aws::Structure end |
#version_number ⇒ Integer
The extension version number.
2133 2134 2135 2136 2137 2138 2139 2140 2141 2142 2143 |
# File 'lib/aws-sdk-appconfig/types.rb', line 2133 class Extension < Struct.new( :id, :name, :version_number, :arn, :description, :actions, :parameters) SENSITIVE = [] include Aws::Structure end |