Class: Aws::AppConfig::Types::FlagValue
- Inherits:
-
Struct
- Object
- Struct
- Aws::AppConfig::Types::FlagValue
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-appconfig/types.rb
Overview
The feature flag value configuration for a treatment, including the enabled state and attribute values.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#attribute_values ⇒ Hash<String,Types::AttributeValue>
The attribute values associated with this flag value.
-
#enabled ⇒ Boolean
Whether the feature flag is enabled for this treatment.
Instance Attribute Details
#attribute_values ⇒ Hash<String,Types::AttributeValue>
The attribute values associated with this flag value.
2300 2301 2302 2303 2304 2305 |
# File 'lib/aws-sdk-appconfig/types.rb', line 2300 class FlagValue < Struct.new( :enabled, :attribute_values) SENSITIVE = [] include Aws::Structure end |