Class: Aws::AppConfig::Types::Treatment
- Inherits:
-
Struct
- Object
- Struct
- Aws::AppConfig::Types::Treatment
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-appconfig/types.rb
Overview
Describes a treatment in an experiment, including its traffic allocation weight and feature flag value.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#description ⇒ String
A description of the treatment.
-
#flag_value ⇒ Types::FlagValue
The feature flag value served to users assigned to this treatment.
-
#key ⇒ String
The unique key that identifies this treatment.
-
#weight ⇒ Float
The traffic allocation weight for this treatment.
Instance Attribute Details
#description ⇒ String
A description of the treatment.
3418 3419 3420 3421 3422 3423 3424 3425 |
# File 'lib/aws-sdk-appconfig/types.rb', line 3418 class Treatment < Struct.new( :key, :weight, :description, :flag_value) SENSITIVE = [] include Aws::Structure end |
#flag_value ⇒ Types::FlagValue
The feature flag value served to users assigned to this treatment.
3418 3419 3420 3421 3422 3423 3424 3425 |
# File 'lib/aws-sdk-appconfig/types.rb', line 3418 class Treatment < Struct.new( :key, :weight, :description, :flag_value) SENSITIVE = [] include Aws::Structure end |