Class: Aws::AppConfig::Types::TreatmentInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::AppConfig::Types::TreatmentInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-appconfig/types.rb
Overview
Input structure for defining a treatment when creating or updating an experiment definition.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#description ⇒ String
A description of the treatment.
-
#flag_value ⇒ Types::FlagValue
The feature flag value to serve to users assigned to this treatment.
-
#weight ⇒ Float
The traffic allocation weight for this treatment.
Instance Attribute Details
#description ⇒ String
A description of the treatment.
3444 3445 3446 3447 3448 3449 3450 |
# File 'lib/aws-sdk-appconfig/types.rb', line 3444 class TreatmentInput < Struct.new( :weight, :description, :flag_value) SENSITIVE = [] include Aws::Structure end |
#flag_value ⇒ Types::FlagValue
The feature flag value to serve to users assigned to this treatment.
3444 3445 3446 3447 3448 3449 3450 |
# File 'lib/aws-sdk-appconfig/types.rb', line 3444 class TreatmentInput < Struct.new( :weight, :description, :flag_value) SENSITIVE = [] include Aws::Structure end |
#weight ⇒ Float
The traffic allocation weight for this treatment.
3444 3445 3446 3447 3448 3449 3450 |
# File 'lib/aws-sdk-appconfig/types.rb', line 3444 class TreatmentInput < Struct.new( :weight, :description, :flag_value) SENSITIVE = [] include Aws::Structure end |