Class: Aws::AppConfig::Types::TreatmentOverrides
- Inherits:
-
Struct
- Object
- Struct
- Aws::AppConfig::Types::TreatmentOverrides
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-appconfig/types.rb
Overview
Note:
TreatmentOverrides is a union - when making an API calls you must set exactly one of the members.
Note:
TreatmentOverrides is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of TreatmentOverrides corresponding to the set member.
Treatment assignment overrides that assign specific entity IDs to treatments, bypassing random assignment.
Defined Under Namespace
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#inline ⇒ Hash<String,String>
A map of entity IDs to treatment keys.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#inline ⇒ Hash<String,String>
A map of entity IDs to treatment keys. Each entry assigns the specified entity to the specified treatment, bypassing random assignment.
3467 3468 3469 3470 3471 3472 3473 3474 3475 3476 |
# File 'lib/aws-sdk-appconfig/types.rb', line 3467 class TreatmentOverrides < Struct.new( :inline, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Inline < TreatmentOverrides; end class Unknown < TreatmentOverrides; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
3467 3468 3469 |
# File 'lib/aws-sdk-appconfig/types.rb', line 3467 def unknown @unknown end |