Class: Aws::AppConfig::Types::UpdateExperimentRunRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-appconfig/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#application_identifierString

The application ID or name.

Returns:

  • (String)


3776
3777
3778
3779
3780
3781
3782
3783
3784
3785
3786
# File 'lib/aws-sdk-appconfig/types.rb', line 3776

class UpdateExperimentRunRequest < Struct.new(
  :application_identifier,
  :experiment_definition_identifier,
  :run,
  :description,
  :exposure_percentage,
  :treatment_overrides,
  :deployment_parameters)
  SENSITIVE = []
  include Aws::Structure
end

#deployment_parametersTypes::DeploymentParameters

The updated deployment parameters for the experiment run.



3776
3777
3778
3779
3780
3781
3782
3783
3784
3785
3786
# File 'lib/aws-sdk-appconfig/types.rb', line 3776

class UpdateExperimentRunRequest < Struct.new(
  :application_identifier,
  :experiment_definition_identifier,
  :run,
  :description,
  :exposure_percentage,
  :treatment_overrides,
  :deployment_parameters)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

An updated description for the experiment run.

Returns:

  • (String)


3776
3777
3778
3779
3780
3781
3782
3783
3784
3785
3786
# File 'lib/aws-sdk-appconfig/types.rb', line 3776

class UpdateExperimentRunRequest < Struct.new(
  :application_identifier,
  :experiment_definition_identifier,
  :run,
  :description,
  :exposure_percentage,
  :treatment_overrides,
  :deployment_parameters)
  SENSITIVE = []
  include Aws::Structure
end

#experiment_definition_identifierString

The experiment definition ID or name.

Returns:

  • (String)


3776
3777
3778
3779
3780
3781
3782
3783
3784
3785
3786
# File 'lib/aws-sdk-appconfig/types.rb', line 3776

class UpdateExperimentRunRequest < Struct.new(
  :application_identifier,
  :experiment_definition_identifier,
  :run,
  :description,
  :exposure_percentage,
  :treatment_overrides,
  :deployment_parameters)
  SENSITIVE = []
  include Aws::Structure
end

#exposure_percentageFloat

The new exposure percentage. This value can only be increased from the current setting.

Returns:

  • (Float)


3776
3777
3778
3779
3780
3781
3782
3783
3784
3785
3786
# File 'lib/aws-sdk-appconfig/types.rb', line 3776

class UpdateExperimentRunRequest < Struct.new(
  :application_identifier,
  :experiment_definition_identifier,
  :run,
  :description,
  :exposure_percentage,
  :treatment_overrides,
  :deployment_parameters)
  SENSITIVE = []
  include Aws::Structure
end

#runInteger

The run number to update.

Returns:

  • (Integer)


3776
3777
3778
3779
3780
3781
3782
3783
3784
3785
3786
# File 'lib/aws-sdk-appconfig/types.rb', line 3776

class UpdateExperimentRunRequest < Struct.new(
  :application_identifier,
  :experiment_definition_identifier,
  :run,
  :description,
  :exposure_percentage,
  :treatment_overrides,
  :deployment_parameters)
  SENSITIVE = []
  include Aws::Structure
end

#treatment_overridesTypes::TreatmentOverrides

The updated treatment assignment overrides that assign specific entity IDs to treatments, bypassing random assignment.



3776
3777
3778
3779
3780
3781
3782
3783
3784
3785
3786
# File 'lib/aws-sdk-appconfig/types.rb', line 3776

class UpdateExperimentRunRequest < Struct.new(
  :application_identifier,
  :experiment_definition_identifier,
  :run,
  :description,
  :exposure_percentage,
  :treatment_overrides,
  :deployment_parameters)
  SENSITIVE = []
  include Aws::Structure
end