Class: Aws::AppConfig::Waiters::DeploymentComplete
- Inherits:
-
Object
- Object
- Aws::AppConfig::Waiters::DeploymentComplete
- Defined in:
- sig/waiters.rbs,
lib/aws-sdk-appconfig/waiters.rb
Instance Attribute Summary collapse
- #waiter ⇒ Object readonly private
Instance Method Summary collapse
-
#initialize(options) ⇒ DeploymentComplete
constructor
A new instance of DeploymentComplete.
-
#wait(params = {}) ⇒ Types::Deployment
Returns a response object which responds to the following methods:.
Constructor Details
#initialize(options) ⇒ DeploymentComplete
Returns a new instance of DeploymentComplete.
85 86 |
# File 'lib/aws-sdk-appconfig/waiters.rb', line 85
def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void
|
Instance Attribute Details
#waiter ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
123 124 125 |
# File 'lib/aws-sdk-appconfig/waiters.rb', line 123 def waiter @waiter end |
Instance Method Details
#wait(params = {}) ⇒ Types::Deployment
Returns a response object which responds to the following methods:
- #application_id => String
- #environment_id => String
- #deployment_strategy_id => String
- #configuration_profile_id => String
- #deployment_number => Integer
- #configuration_name => String
- #configuration_location_uri => String
- #configuration_version => String
- #description => String
- #deployment_duration_in_minutes => Integer
- #growth_type => String
- #growth_factor => Float
- #final_bake_time_in_minutes => Integer
- #state => String
- #event_log => Array<Types::DeploymentEvent>
- #percentage_complete => Float
- #started_at => Time
- #completed_at => Time
- #applied_extensions => Array<Types::AppliedExtension>
- #kms_key_arn => String
- #kms_key_identifier => String
- #version_label => String
118 |
# File 'lib/aws-sdk-appconfig/waiters.rb', line 118
def wait: (
|