Class: Aws::AppConfig::Waiters::EnvironmentReadyForDeployment
- Inherits:
-
Object
- Object
- Aws::AppConfig::Waiters::EnvironmentReadyForDeployment
- Defined in:
- sig/waiters.rbs,
lib/aws-sdk-appconfig/waiters.rb
Instance Attribute Summary collapse
- #waiter ⇒ Object readonly private
Instance Method Summary collapse
-
#initialize(options) ⇒ EnvironmentReadyForDeployment
constructor
A new instance of EnvironmentReadyForDeployment.
-
#wait(params = {}) ⇒ Types::Environment
Returns a response object which responds to the following methods:.
Constructor Details
#initialize(options) ⇒ EnvironmentReadyForDeployment
Returns a new instance of EnvironmentReadyForDeployment.
135 136 |
# File 'lib/aws-sdk-appconfig/waiters.rb', line 135
def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void
|
Instance Attribute Details
#waiter ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
173 174 175 |
# File 'lib/aws-sdk-appconfig/waiters.rb', line 173 def waiter @waiter end |
Instance Method Details
#wait(params = {}) ⇒ Types::Environment
Returns a response object which responds to the following methods:
- #application_id => String
- #id => String
- #name => String
- #description => String
- #state => String
- #monitors => Array<Types::Monitor>
168 |
# File 'lib/aws-sdk-appconfig/waiters.rb', line 168
def wait: (
|